/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 04146
 |        NATIONAL DRUG ABUSE TREATMENT SYSTEM SURVEY, WAVES II-IV
 |                     (DATASET 0002: WAVE III, 1990)
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\04146-0002-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE v7004fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7005fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v7006fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7007fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 88='88. 1988' 89='89. 1989'
                  90='90. 1990' 91='91. 1991' ;
  VALUE v7008fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v7009fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7010fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 88='88. 1988' 89='89. 1989'
                  90='90. 1990' 91='91. 1991' ;
  VALUE v7011fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7012fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v7013fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7014fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7015fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7016fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 10='10. CHANGPOP'
                  11='11. AGERANGE' 12='12. OUTREACH' 13='13. LOINCOME'
                  14='14. MORECTRE' 19='19. OTHTARGT' 21='21. INCALCOH'
                  22='22. ALCO+OTH' 23='23. COCAINTX' 29='29. OTHDRUGS'
                  31='31. MAIN2FRE' 32='32. MOREMETH' 33='33. MOREFAMI'
                  34='34. TXMOREIN' 35='35. SELFHELP' 41='41. BROADTX'
                  42='42. >EDUCATN' 43='43. SATRTMT' 44='44. TARGET'
                  49='49. BRODPROG' 51='51. REFERRAL' 52='52. AIDS.ED'
                  53='53. DETOX' 81='81. REDUCED NON-SA INVOLV'
                  91='91. NOW/ALWAYS CHNG/IMPROVING' 97='97. OTHER' ;
  VALUE v7017fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 10='10. CHANGPOP'
                  11='11. AGERANGE' 12='12. OUTREACH' 13='13. LOINCOME'
                  14='14. MORECTRE' 19='19. OTHTARGT' 21='21. INCALCOH'
                  22='22. ALCO+OTH' 23='23. COCAINTX' 29='29. OTHDRUGS'
                  31='31. MAIN2FRE' 32='32. MOREMETH' 33='33. MOREFAMI'
                  34='34. TXMOREIN' 35='35. SELFHELP' 41='41. BROADTX'
                  42='42. >EDUCATN' 43='43. SATRTMT' 44='44. TARGET'
                  49='49. BRODPROG' 51='51. REFERRAL' 52='52. AIDS.ED'
                  53='53. DETOX' 81='81. REDUCED NON-SA INVOLV'
                  91='91. NOW/ALWAYS CHNG/IMPROVING' 97='97. OTHER' ;
  VALUE v7018fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7019fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7020fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7021fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7022fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7023fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7024fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7025fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7026fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7027fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7028fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7029fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7030fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7031fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7032fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7033fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7034fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7035fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7036fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v7037fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7038fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7039fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v7040fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7041fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7042fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7043fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7044fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7045fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v7046fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7047fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7048fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v7049fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7050fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7051fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7052fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7053fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7054fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7055fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7056fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7057fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7058fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7059fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7060fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7061fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7062fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7063fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7064fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7065fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7066fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7067fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7068fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7069fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7070fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7071fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7072fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7073fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7074fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7075fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7076fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7077fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7078fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7079fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7080fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7081fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7082fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7083fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7084fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7085fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7086fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7087fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7088fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7089fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7090fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7091fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7092fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7093fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7094fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7095fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7096fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7097fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7098fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7099fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7100fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7101fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7102fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7103fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7104fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7105fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7106fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7107fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7108fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7109fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7110fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7111fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7112fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7113fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7114fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7115fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7116fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7117fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7118fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7119fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7120fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7121fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7122fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7123fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7124fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7125fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7126fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7127fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7128fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7129fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7130fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7131fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7132fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7133fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7134fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7135fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7136fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7137fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7138fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7139fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7140fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7141fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7142fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7143fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VISITS' 2='2. TIME'
                  3='3. CLIENTS' 4='4. COMB 01&02' 5='5. COMB 02&03'
                  6='6. COMB 01&03' 7='7. ALL 1&2&3' 10='10. PER WK/MO'
                  11='11. PER DAY/DIEM' 12='12. PER MEDICAL'
                  13='13. PER DOSE METH' 14='14. PER UNIT COST'
                  15='15. PER PRGM' 21='21. MATCHING FUNDS' 22='22. GRANT'
                  23='23. CONTRACT' 24='24. PAY EXPENS' 25='25. DONATION'
                  26='26. TAX/FEE' 29='29. OTR GOVPAY' 61='61. INTEREST'
                  62='62. SALE GOODS' 63='63. SOLICITATION' 97='97. OTHER' ;
  VALUE v7144fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7145fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7146fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7147fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7148fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7149fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7150fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7151fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7152fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7153fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7154fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7155fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7156fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7157fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7158fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7159fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7160fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7161fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7162fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7163fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO B2' 1='1. YES B2' ;
  VALUE v7164fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7165fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7166fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7167fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7168fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7169fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7170fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7171fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7172fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7173fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7174fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7175fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7176fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7177fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7178fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7179fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7180fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7181fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7182fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7183fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7184fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7185fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7186fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7187fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7188fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7189fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7190fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7191fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. RENT' 2='2. OWN'
                  3='3. NEITHER' 4='4. BOTH 1 & 2' ;
  VALUE v7192fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7193fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7194fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7195fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7196fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7197fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7198fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7199fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7200fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7201fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7202fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7203fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7204fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7205fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7206fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7207fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7208fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 994='994. FLATRATE'
                  995='995. SLIDSCAL' 996='996. NOCHARGE' ;
  VALUE v7209fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7210fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7211fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7212fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MD' 2='2. RN' 3='3. LPN'
                  7='7. OTHHCP' 9='9. HCPUNSP' 11='11. PHDSOCWK'
                  17='17. PHD.OTH' 19='19. PHD.UNSP' 27='27. MA.ANY'
                  29='29. MA.UNSP' 31='31. BA.SWPS' 37='37. BA.OTH'
                  39='39. BA.UNSP' 41='41. AA.ANY' 51='51. CERTALDA'
                  57='57. CERT.OTH' 59='59. CERTUNSP' 61='61. NODEGREE'
                  81='81. ALSACOUN' 82='82. ALSASENR' 97='97. OTHER' ;
  VALUE v7213fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7214fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MD' 2='2. RN' 3='3. LPN'
                  7='7. OTHHCP' 9='9. HCPUNSP' 11='11. PHDSOCWK'
                  17='17. PHD.OTH' 19='19. PHD.UNSP' 27='27. MA.ANY'
                  29='29. MA.UNSP' 31='31. BA.SWPS' 37='37. BA.OTH'
                  39='39. BA.UNSP' 41='41. AA.ANY' 51='51. CERTALDA'
                  57='57. CERT.OTH' 59='59. CERTUNSP' 61='61. NODEGREE'
                  81='81. ALSACOUN' 82='82. ALSASENR' 97='97. OTHER' ;
  VALUE v7215fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7216fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MD' 2='2. RN' 3='3. LPN'
                  7='7. OTHHCP' 9='9. HCPUNSP' 11='11. PHDSOCWK'
                  17='17. PHD.OTH' 19='19. PHD.UNSP' 27='27. MA.ANY'
                  29='29. MA.UNSP' 31='31. BA.SWPS' 37='37. BA.OTH'
                  39='39. BA.UNSP' 41='41. AA.ANY' 51='51. CERTALDA'
                  57='57. CERT.OTH' 59='59. CERTUNSP' 61='61. NODEGREE'
                  81='81. ALSACOUN' 82='82. ALSASENR' 97='97. OTHER' ;
  VALUE v7217fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7218fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7219fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7220fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7221fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7222fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7223fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7224fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7225fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 994='994. FLATRATE'
                  995='995. SLIDSCAL' 996='996. NOCHARGE' ;
  VALUE v7226fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7227fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7228fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7229fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7230fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7231fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MD' 2='2. RN' 3='3. LPN'
                  7='7. OTHHCP' 9='9. HCPUNSP' 11='11. PHDSOCWK'
                  17='17. PHD.OTH' 19='19. PHD.UNSP' 27='27. MA.ANY'
                  29='29. MA.UNSP' 31='31. BA.SWPS' 37='37. BA.OTH'
                  39='39. BA.UNSP' 41='41. AA.ANY' 51='51. CERTALDA'
                  57='57. CERT.OTH' 59='59. CERTUNSP' 61='61. NODEGREE'
                  81='81. ALSACOUN' 82='82. ALSASENR' 97='97. OTHER' ;
  VALUE v7232fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7233fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MD' 2='2. RN' 3='3. LPN'
                  7='7. OTHHCP' 9='9. HCPUNSP' 11='11. PHDSOCWK'
                  17='17. PHD.OTH' 19='19. PHD.UNSP' 27='27. MA.ANY'
                  29='29. MA.UNSP' 31='31. BA.SWPS' 37='37. BA.OTH'
                  39='39. BA.UNSP' 41='41. AA.ANY' 51='51. CERTALDA'
                  57='57. CERT.OTH' 59='59. CERTUNSP' 61='61. NODEGREE'
                  81='81. ALSACOUN' 82='82. ALSASENR' 97='97. OTHER' ;
  VALUE v7234fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7235fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MD' 2='2. RN' 3='3. LPN'
                  7='7. OTHHCP' 9='9. HCPUNSP' 11='11. PHDSOCWK'
                  17='17. PHD.OTH' 19='19. PHD.UNSP' 27='27. MA.ANY'
                  29='29. MA.UNSP' 31='31. BA.SWPS' 37='37. BA.OTH'
                  39='39. BA.UNSP' 41='41. AA.ANY' 51='51. CERTALDA'
                  57='57. CERT.OTH' 59='59. CERTUNSP' 61='61. NODEGREE'
                  81='81. ALSACOUN' 82='82. ALSASENR' 97='97. OTHER' ;
  VALUE v7236fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7237fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7238fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7239fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7240fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7241fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7242fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7243fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7244fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 994='994. FLATRATE'
                  995='995. SLIDSCAL' 996='996. NOCHARGE' ;
  VALUE v7245fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7246fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7247fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7248fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7249fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7250fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MD' 2='2. RN' 3='3. LPN'
                  7='7. OTHHCP' 9='9. HCPUNSP' 11='11. PHDSOCWK'
                  17='17. PHD.OTH' 19='19. PHD.UNSP' 27='27. MA.ANY'
                  29='29. MA.UNSP' 31='31. BA.SWPS' 37='37. BA.OTH'
                  39='39. BA.UNSP' 41='41. AA.ANY' 51='51. CERTALDA'
                  57='57. CERT.OTH' 59='59. CERTUNSP' 61='61. NODEGREE'
                  81='81. ALSACOUN' 82='82. ALSASENR' 97='97. OTHER' ;
  VALUE v7251fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7252fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MD' 2='2. RN' 3='3. LPN'
                  7='7. OTHHCP' 9='9. HCPUNSP' 11='11. PHDSOCWK'
                  17='17. PHD.OTH' 19='19. PHD.UNSP' 27='27. MA.ANY'
                  29='29. MA.UNSP' 31='31. BA.SWPS' 37='37. BA.OTH'
                  39='39. BA.UNSP' 41='41. AA.ANY' 51='51. CERTALDA'
                  57='57. CERT.OTH' 59='59. CERTUNSP' 61='61. NODEGREE'
                  81='81. ALSACOUN' 82='82. ALSASENR' 97='97. OTHER' ;
  VALUE v7253fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7254fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MD' 2='2. RN' 3='3. LPN'
                  7='7. OTHHCP' 9='9. HCPUNSP' 11='11. PHDSOCWK'
                  17='17. PHD.OTH' 19='19. PHD.UNSP' 27='27. MA.ANY'
                  29='29. MA.UNSP' 31='31. BA.SWPS' 37='37. BA.OTH'
                  39='39. BA.UNSP' 41='41. AA.ANY' 51='51. CERTALDA'
                  57='57. CERT.OTH' 59='59. CERTUNSP' 61='61. NODEGREE'
                  81='81. ALSACOUN' 82='82. ALSASENR' 97='97. OTHER' ;
  VALUE v7255fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7256fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7257fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7258fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7259fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7260fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7261fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7262fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7263fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7264fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7265fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7266fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Private For-Profit'
                  2='2. Private Not-For-Profit' 3='3. Public' ;
  VALUE v7267fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7268fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7269fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7270fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. ALL OTHER' 1='1. YES TO C1' ;
  VALUE v7271fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Public'
                  2='2. Private For-Profit' 3='3. Private Not-For-Profit' ;
  VALUE v7272fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. FEDERAL' 2='2. STATE'
                  3='3. LOCAL' ;
  VALUE v7273fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HOSPITAL'
                  2='2. MENTAL HEALTH CENTER'
                  3='3. (Free standing) Substance Abuse Treatment Facility'
                  4='4. City/county/state department'
                  5='5. Multi-service social service agency'
                  7='7. OTHER ORG (SPECIFY)' ;
  VALUE v7274fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7275fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7276fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. ALL OTHER' 1='1. YES TO C6' ;
  VALUE v7277fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Public'
                  2='2. Private For-Profit' 3='3. Private Not-For-Profit' ;
  VALUE v7278fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. FEDERAL' 2='2. STATE'
                  3='3. LOCAL' ;
  VALUE v7279fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HOSPITAL'
                  2='2. MENTAL HEALTH CENTER'
                  3='3. (Free standing) Substance Abuse Treatment Facility'
                  4='4. City/county/state department'
                  5='5. Multi-service social service agency'
                  7='7. OTHER ORG (SPECIFY)' ;
  VALUE v7280fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7281fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7282fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. ALL OTHER'
                  1='1. YES TO C11' ;
  VALUE v7283fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Public'
                  2='2. Private For-Profit' 3='3. Private Not-For-Profit' ;
  VALUE v7284fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. FEDERAL' 2='2. STATE'
                  3='3. LOCAL' ;
  VALUE v7285fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HOSPITAL'
                  2='2. MENTAL HEALTH CENTER'
                  3='3. (Free standing) Substance Abuse Treatment Facility'
                  4='4. City/county/state department'
                  5='5. Multi-service social service agency'
                  7='7. OTHER ORG (SPECIFY)' ;
  VALUE v7286fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. ALL OTHER' 1='1. Y/PARENT' ;
  VALUE v7287fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NO ACCCEPTANCE'
                  2='2. LITTLE ACCEPTANCE' 3='3. SOME ACCEPTANCE'
                  4='4. CONSIDERABLE ACCEPTANCE' 5='5. COMPLETE ACCEPTANCE' ;
  VALUE v7288fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7289fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7290fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7291fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7292fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 40='40. PHARMACY' 41='41. COURT'
                  42='42. HEALTH' 43='43. SOCSERVC' 44='44. ALCOHOL'
                  46='46. 508509FD' 47='47. OTHSTATE' 48='48. LICUNSP'
                  49='49. STATEAGC' ;
  VALUE v7293fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 40='40. PHARMACY' 41='41. COURT'
                  42='42. HEALTH' 43='43. SOCSERVC' 44='44. ALCOHOL'
                  46='46. 508509FD' 47='47. OTHSTATE' 48='48. LICUNSP'
                  49='49. STATEAGC' ;
  VALUE v7294fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7295fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 51='51. CITYCRT' 52='52. HEALTH'
                  53='53. SOCSERVC' 54='54. ALCOHOL' 57='57. OTHCTYCT'
                  58='58. CITYLIC' 59='59. CITYAGC' ;
  VALUE v7296fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 51='51. CITYCRT' 52='52. HEALTH'
                  53='53. SOCSERVC' 54='54. ALCOHOL' 57='57. OTHCTYCT'
                  58='58. CITYLIC' 59='59. CITYAGC' ;
  VALUE v7297fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7298fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7299fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7300fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7301fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 40='40. PHARMACY' 41='41. COURT'
                  42='42. HEALTH' 43='43. SOCSERVC' 44='44. ALCOHOL'
                  46='46. 508509FD' 47='47. OTHSTATE' 48='48. LICUNSP'
                  49='49. STATEAGC' ;
  VALUE v7302fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 40='40. PHARMACY' 41='41. COURT'
                  42='42. HEALTH' 43='43. SOCSERVC' 44='44. ALCOHOL'
                  46='46. 508509FD' 47='47. OTHSTATE' 48='48. LICUNSP'
                  49='49. STATEAGC' ;
  VALUE v7303fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7304fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7305fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7306fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7307fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7308fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7309fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7310fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7311fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 2 YR OR LESS'
                  2='2. ANNUALLY' 3='3. SEMI-ANNUAL' 4='4. QUARTERLY'
                  5='5. MONTHLY' 6='6. RANDOM' 7='7. OTHER' ;
  VALUE v7312fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7313fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 2 YR OR LESS'
                  2='2. ANNUALLY' 3='3. SEMI-ANNUAL' 4='4. QUARTERLY'
                  5='5. MONTHLY' 6='6. RANDOM' 7='7. OTHER' ;
  VALUE v7314fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7315fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 2 YR OR LESS'
                  2='2. ANNUALLY' 3='3. SEMI-ANNUAL' 4='4. QUARTERLY'
                  5='5. MONTHLY' 6='6. RANDOM' 7='7. OTHER' ;
  VALUE v7316fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7317fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 2 YR OR LESS'
                  2='2. ANNUALLY' 3='3. SEMI-ANNUAL' 4='4. QUARTERLY'
                  5='5. MONTHLY' 6='6. RANDOM' 7='7. OTHER' ;
  VALUE v7318fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7319fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 2 YR OR LESS'
                  2='2. ANNUALLY' 3='3. SEMI-ANNUAL' 4='4. QUARTERLY'
                  5='5. MONTHLY' 6='6. RANDOM' 7='7. OTHER' ;
  VALUE v7320fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7321fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 2 YR OR LESS'
                  2='2. ANNUALLY' 3='3. SEMI-ANNUAL' 4='4. QUARTERLY'
                  5='5. MONTHLY' 6='6. RANDOM' 7='7. OTHER' ;
  VALUE v7322fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7323fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7324fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 2 YR OR LESS'
                  2='2. ANNUALLY' 3='3. SEMI-ANNUAL' 4='4. QUARTERLY'
                  5='5. MONTHLY' 6='6. RANDOM' 7='7. OTHER' ;
  VALUE v7325fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7326fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7327fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7328fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7329fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7330fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7331fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7332fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7333fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7334fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7335fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7336fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7337fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7338fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7339fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7340fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7341fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7342fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7343fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7344fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7345fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7346fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7347fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7348fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v7349fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7350fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7351fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7352fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7353fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7354fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v7355fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7356fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7357fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7358fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7359fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7360fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v7361fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7362fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7363fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7364fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7365fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7366fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7367fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7368fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7369fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v7370fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7371fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7372fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7373fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7374fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v7375fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7376fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7377fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7378fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7379fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v7380fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7381fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7382fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7383fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7384fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7385fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7386fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7387fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7388fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7389fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7390fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v7391fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7392fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7393fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7394fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7395fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7396fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v7397fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7398fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7399fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7400fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7401fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7402fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v7403fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7404fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7405fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7406fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7407fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7408fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7409fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7410fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7411fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v7412fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7413fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7414fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7415fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7416fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v7417fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7418fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7419fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7420fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7421fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v7422fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7423fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7424fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7425fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7426fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7427fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7428fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7429fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7430fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7431fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7432fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v7433fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7434fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7435fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7436fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7437fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7438fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v7439fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7440fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7441fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7442fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7443fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7444fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v7445fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7446fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7447fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7448fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7449fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7450fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7451fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7452fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7453fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v7454fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7455fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7456fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7457fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7458fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v7459fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v7460fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7461fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7462fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7463fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v7464fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7465fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7466fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7467fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7468fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PUBLIC' 2='2. PRIVATE'
                  3='3. BOTH' ;
  VALUE v7469fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. FOR-PROFIT'
                  2='2. NOT-FOR-PROFIT' 3='3. BOTH' ;
  VALUE v7470fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7471fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PUBLIC' 2='2. PRIVATE'
                  3='3. BOTH' ;
  VALUE v7472fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. FOR-PROFIT'
                  2='2. NOT-FOR-PROFIT' 3='3. BOTH' ;
  VALUE v7473fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7474fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PUBLIC' 2='2. PRIVATE'
                  3='3. BOTH' ;
  VALUE v7475fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. FOR-PROFIT'
                  2='2. NOT-FOR-PROFIT' 3='3. BOTH' ;
  VALUE v7476fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7477fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7478fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7479fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7480fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7481fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7482fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7483fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7484fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7485fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7486fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7487fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7488fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7489fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7490fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7491fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7492fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7493fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7494fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Increased a great deal'
                  2='2. Increased some' 3='3. Remained the same'
                  4='4. Decreased some' 5='5. Decreased a great deal' ;
  VALUE v7495fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LESS $' 2='2. MORE $'
                  3='3. PROFITS' 4='4. MARKETNG' 11='11. MOREWORK'
                  12='12. MORE AGY' 13='13. FEWRSTAF' 14='14. FEWERAGY'
                  21='21. MORE COOPERAT' 97='97. OTHER' ;
  VALUE v7496fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LESS $' 2='2. MORE $'
                  3='3. PROFITS' 4='4. MARKETNG' 11='11. MOREWORK'
                  12='12. MORE AGY' 13='13. FEWRSTAF' 14='14. FEWERAGY'
                  21='21. MORE COOPERAT' 97='97. OTHER' ;
  VALUE v7497fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 1 HR OR LESS' ;
  VALUE v7498fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 1 HR OR LESS' ;
  VALUE v7499fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 1 HR OR LESS' ;
  VALUE v7500fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 1 HR OR LESS' ;
  VALUE v7501fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 1 HR OR LESS' ;
  VALUE v7502fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 1 HR OR LESS' ;
  VALUE v7503fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 1 HR OR LESS' ;
  VALUE v7504fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 1 HR OR LESS' ;
  VALUE v7505fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. POLICE' 2='2. MHC'
                  3='3. HOSPITAL' 4='4. RESID FAC (EXC 03)' 5='5. CHURCH'
                  6='6. SCHOOL' 7='7. EAP/EMPLOYER/CO' 8='8. DEPT SOC SVC'
                  9='9. DEPT VOC REHAB' 10='10. AA/NA' 11='11. HMO'
                  12='12. REFERL CENTER' 61='61. ST/LOC GOV'
                  62='62. OTR OUTPT UNIT' 96='96. NO REF' 97='97. OTHER' ;
  VALUE v7506fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7507fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7508fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7509fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7510fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7511fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7512fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7513fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7514fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. REPORTNG' 2='2. REQUIRED'
                  3='3. OPTREFUS' 4='4. QUALITY' 5='5. PAYMENT'
                  21='21. EVALUATN' 22='22. SEECLJAL' 23='23. URINAL'
                  24='24. DRUGEDUC' 51='51. COOPERAT' 52='52. MUSTREFR'
                  95='95. INFAGREE' 96='96. NONE' 97='97. OTHER' ;
  VALUE v7515fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. REPORTNG' 2='2. REQUIRED'
                  3='3. OPTREFUS' 4='4. QUALITY' 5='5. PAYMENT'
                  21='21. EVALUATN' 22='22. SEECLJAL' 23='23. URINAL'
                  24='24. DRUGEDUC' 51='51. COOPERAT' 52='52. MUSTREFR'
                  95='95. INFAGREE' 96='96. NONE' 97='97. OTHER' ;
  VALUE v7516fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7517fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7518fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7519fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7520fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7521fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7522fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7523fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7524fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7525fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7526fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7527fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7528fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7529fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7530fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7531fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7532fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7533fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7534fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v7535fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7536fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7537fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7538fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7539fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INCRREV' 2='2. REDUCECT'
                  9='9. FINUNSPE' 11='11. INCRSERV' 12='12. REDDUP'
                  19='19. EFFIUNSP' 21='21. MO43DLI' 22='22. 43EDOMP'
                  97='97. OTHER' ;
  VALUE v7540fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INCRREV' 2='2. REDUCECT'
                  9='9. FINUNSPE' 11='11. INCRSERV' 12='12. REDDUP'
                  19='19. EFFIUNSP' 21='21. MO43DLI' 22='22. 43EDOMP'
                  97='97. OTHER' ;
  VALUE v7541fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7542fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7543fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7544fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7545fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7546fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7547fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7548fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7549fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7550fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7551fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7552fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7553fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7554fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. GEN PUBLIC'
                  2='2. SEG PUB DEAL DRUG PROBS' 3='3. ALL CLIENTS'
                  6='6. CHILDREN' 7='7. OLDER CLIENTS' 8='8. CODEPENDS'
                  9='9. LOW INCOME' 10='10. MEN' 12='12. BLACKS'
                  13='13. GAYS/LESBIANS' 14='14. PARENT GRPS'
                  15='15. MINORITIES EXC BLACKS' 16='16. HANDICAP'
                  17='17. PREG WOMEN/TEENS' 18='18. OTR PROGS FOR WOMEN'
                  19='19. TEENS' 20='20. SPOUSE/SIG OTHR/CLOSE FAM'
                  21='21. ALCOHOL' 22='22. COCAINE' 23='23. HEROIN/OPIATES'
                  27='27. DUAL DIAGNOSIS' 28='28. SEVERE ADDICT CLNTS'
                  29='29. EARLY STAGE ADDICTION' 31='31. CHRONIC PAIN'
                  32='32. METH RECIPIENTS' 33='33. AIDS RELATED'
                  34='34. MENTAL HLTH PROBS' 35='35. DUI/DWI CLIENTS'
                  37='37. PERIPHERAL PROBS' 41='41. AFTERCARE' 97='97. OTHER' ;
  VALUE v7555fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7556fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7557fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7558fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. GEN PUBLIC'
                  2='2. SEG PUB DEAL DRUG PROBS' 3='3. ALL CLIENTS'
                  6='6. CHILDREN' 7='7. OLDER CLIENTS' 8='8. CODEPENDS'
                  9='9. LOW INCOME' 10='10. MEN' 12='12. BLACKS'
                  13='13. GAYS/LESBIANS' 14='14. PARENT GRPS'
                  15='15. MINORITIES EXC BLACKS' 16='16. HANDICAP'
                  17='17. PREG WOMEN/TEENS' 18='18. OTR PROGS FOR WOMEN'
                  19='19. TEENS' 20='20. SPOUSE/SIG OTHR/CLOSE FAM'
                  21='21. ALCOHOL' 22='22. COCAINE' 23='23. HEROIN/OPIATES'
                  27='27. DUAL DIAGNOSIS' 28='28. SEVERE ADDICT CLNTS'
                  29='29. EARLY STAGE ADDICTION' 31='31. CHRONIC PAIN'
                  32='32. METH RECIPIENTS' 33='33. AIDS RELATED'
                  34='34. MENTAL HLTH PROBS' 35='35. DUI/DWI CLIENTS'
                  37='37. PERIPHERAL PROBS' 41='41. AFTERCARE' 97='97. OTHER' ;
  VALUE v7559fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7560fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7561fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7562fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. GEN PUBLIC'
                  2='2. SEG PUB DEAL DRUG PROBS' 3='3. ALL CLIENTS'
                  6='6. CHILDREN' 7='7. OLDER CLIENTS' 8='8. CODEPENDS'
                  9='9. LOW INCOME' 10='10. MEN' 12='12. BLACKS'
                  13='13. GAYS/LESBIANS' 14='14. PARENT GRPS'
                  15='15. MINORITIES EXC BLACKS' 16='16. HANDICAP'
                  17='17. PREG WOMEN/TEENS' 18='18. OTR PROGS FOR WOMEN'
                  19='19. TEENS' 20='20. SPOUSE/SIG OTHR/CLOSE FAM'
                  21='21. ALCOHOL' 22='22. COCAINE' 23='23. HEROIN/OPIATES'
                  27='27. DUAL DIAGNOSIS' 28='28. SEVERE ADDICT CLNTS'
                  29='29. EARLY STAGE ADDICTION' 31='31. CHRONIC PAIN'
                  32='32. METH RECIPIENTS' 33='33. AIDS RELATED'
                  34='34. MENTAL HLTH PROBS' 35='35. DUI/DWI CLIENTS'
                  37='37. PERIPHERAL PROBS' 41='41. AFTERCARE' 97='97. OTHER' ;
  VALUE v7563fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7564fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7565fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7566fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. GEN PUBLIC'
                  2='2. SEG PUB DEAL DRUG PROBS' 3='3. ALL CLIENTS'
                  6='6. CHILDREN' 7='7. OLDER CLIENTS' 8='8. CODEPENDS'
                  9='9. LOW INCOME' 10='10. MEN' 12='12. BLACKS'
                  13='13. GAYS/LESBIANS' 14='14. PARENT GRPS'
                  15='15. MINORITIES EXC BLACKS' 16='16. HANDICAP'
                  17='17. PREG WOMEN/TEENS' 18='18. OTR PROGS FOR WOMEN'
                  19='19. TEENS' 20='20. SPOUSE/SIG OTHR/CLOSE FAM'
                  21='21. ALCOHOL' 22='22. COCAINE' 23='23. HEROIN/OPIATES'
                  27='27. DUAL DIAGNOSIS' 28='28. SEVERE ADDICT CLNTS'
                  29='29. EARLY STAGE ADDICTION' 31='31. CHRONIC PAIN'
                  32='32. METH RECIPIENTS' 33='33. AIDS RELATED'
                  34='34. MENTAL HLTH PROBS' 35='35. DUI/DWI CLIENTS'
                  37='37. PERIPHERAL PROBS' 41='41. AFTERCARE' 97='97. OTHER' ;
  VALUE v7567fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7568fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7569fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7570fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7571fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7572fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7573fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v7574fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7575fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. GEN PUBLIC'
                  2='2. SEG PUB DEAL DRUG PROBS' 3='3. ALL CLIENTS'
                  6='6. CHILDREN' 7='7. OLDER CLIENTS' 8='8. CODEPENDS'
                  9='9. LOW INCOME' 10='10. MEN' 12='12. BLACKS'
                  13='13. GAYS/LESBIANS' 14='14. PARENT GRPS'
                  15='15. MINORITIES EXC BLACKS' 16='16. HANDICAP'
                  17='17. PREG WOMEN/TEENS' 18='18. OTR PROGS FOR WOMEN'
                  19='19. TEENS' 20='20. SPOUSE/SIG OTHR/CLOSE FAM'
                  21='21. ALCOHOL' 22='22. COCAINE' 23='23. HEROIN/OPIATES'
                  27='27. DUAL DIAGNOSIS' 28='28. SEVERE ADDICT CLNTS'
                  29='29. EARLY STAGE ADDICTION' 31='31. CHRONIC PAIN'
                  32='32. METH RECIPIENTS' 33='33. AIDS RELATED'
                  34='34. MENTAL HLTH PROBS' 35='35. DUI/DWI CLIENTS'
                  37='37. PERIPHERAL PROBS' 41='41. AFTERCARE' 97='97. OTHER' ;
  VALUE v7576fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. GEN PUBLIC'
                  2='2. SEG PUB DEAL DRUG PROBS' 3='3. ALL CLIENTS'
                  6='6. CHILDREN' 7='7. OLDER CLIENTS' 8='8. CODEPENDS'
                  9='9. LOW INCOME' 10='10. MEN' 12='12. BLACKS'
                  13='13. GAYS/LESBIANS' 14='14. PARENT GRPS'
                  15='15. MINORITIES EXC BLACKS' 16='16. HANDICAP'
                  17='17. PREG WOMEN/TEENS' 18='18. OTR PROGS FOR WOMEN'
                  19='19. TEENS' 20='20. SPOUSE/SIG OTHR/CLOSE FAM'
                  21='21. ALCOHOL' 22='22. COCAINE' 23='23. HEROIN/OPIATES'
                  27='27. DUAL DIAGNOSIS' 28='28. SEVERE ADDICT CLNTS'
                  29='29. EARLY STAGE ADDICTION' 31='31. CHRONIC PAIN'
                  32='32. METH RECIPIENTS' 33='33. AIDS RELATED'
                  34='34. MENTAL HLTH PROBS' 35='35. DUI/DWI CLIENTS'
                  37='37. PERIPHERAL PROBS' 41='41. AFTERCARE' 97='97. OTHER' ;
  VALUE v7577fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. GEN PUBLIC'
                  2='2. SEG PUB DEAL DRUG PROBS' 3='3. ALL CLIENTS'
                  6='6. CHILDREN' 7='7. OLDER CLIENTS' 8='8. CODEPENDS'
                  9='9. LOW INCOME' 10='10. MEN' 12='12. BLACKS'
                  13='13. GAYS/LESBIANS' 14='14. PARENT GRPS'
                  15='15. MINORITIES EXC BLACKS' 16='16. HANDICAP'
                  17='17. PREG WOMEN/TEENS' 18='18. OTR PROGS FOR WOMEN'
                  19='19. TEENS' 20='20. SPOUSE/SIG OTHR/CLOSE FAM'
                  21='21. ALCOHOL' 22='22. COCAINE' 23='23. HEROIN/OPIATES'
                  27='27. DUAL DIAGNOSIS' 28='28. SEVERE ADDICT CLNTS'
                  29='29. EARLY STAGE ADDICTION' 31='31. CHRONIC PAIN'
                  32='32. METH RECIPIENTS' 33='33. AIDS RELATED'
                  34='34. MENTAL HLTH PROBS' 35='35. DUI/DWI CLIENTS'
                  37='37. PERIPHERAL PROBS' 41='41. AFTERCARE' 97='97. OTHER' ;
  VALUE v7578fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. GEN PUBLIC'
                  2='2. SEG PUB DEAL DRUG PROBS' 3='3. ALL CLIENTS'
                  6='6. CHILDREN' 7='7. OLDER CLIENTS' 8='8. CODEPENDS'
                  9='9. LOW INCOME' 10='10. MEN' 12='12. BLACKS'
                  13='13. GAYS/LESBIANS' 14='14. PARENT GRPS'
                  15='15. MINORITIES EXC BLACKS' 16='16. HANDICAP'
                  17='17. PREG WOMEN/TEENS' 18='18. OTR PROGS FOR WOMEN'
                  19='19. TEENS' 20='20. SPOUSE/SIG OTHR/CLOSE FAM'
                  21='21. ALCOHOL' 22='22. COCAINE' 23='23. HEROIN/OPIATES'
                  27='27. DUAL DIAGNOSIS' 28='28. SEVERE ADDICT CLNTS'
                  29='29. EARLY STAGE ADDICTION' 31='31. CHRONIC PAIN'
                  32='32. METH RECIPIENTS' 33='33. AIDS RELATED'
                  34='34. MENTAL HLTH PROBS' 35='35. DUI/DWI CLIENTS'
                  37='37. PERIPHERAL PROBS' 41='41. AFTERCARE' 97='97. OTHER' ;
  VALUE v7579fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7580fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7581fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7582fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7583fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7584fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7585fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7586fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7587fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7588fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v7589fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7590fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7591fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7592fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7593fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7594fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7595fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7596fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7597fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7598fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7599fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7600fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. OTHER CLI TRT'
                  2='2. CHANGE IN FAM' 3='3. FAM INFO' 11='11. AIDS INFO'
                  12='12. MENTAL HEALTH' 97='97. OTHER' ;
  VALUE v7601fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. OTHER CLI TRT'
                  2='2. CHANGE IN FAM' 3='3. FAM INFO' 11='11. AIDS INFO'
                  12='12. MENTAL HEALTH' 97='97. OTHER' ;
  VALUE v7602fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. OTHER CLI TRT'
                  2='2. CHANGE IN FAM' 3='3. FAM INFO' 11='11. AIDS INFO'
                  12='12. MENTAL HEALTH' 97='97. OTHER' ;
  VALUE v7603fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7604fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7605fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7606fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LETTERS' 2='2. FRND/REL'
                  3='3. CLIENTS' 11='11. OTHER AGY' 97='97. OTHER' ;
  VALUE v7607fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LETTERS' 2='2. FRND/REL'
                  3='3. CLIENTS' 11='11. OTHER AGY' 97='97. OTHER' ;
  VALUE v7608fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LETTERS' 2='2. FRND/REL'
                  3='3. CLIENTS' 11='11. OTHER AGY' 97='97. OTHER' ;
  VALUE v7609fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7610fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7611fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7612fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7613fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7614fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7615fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7616fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7617fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7618fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7619fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7620fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7621fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7622fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7623fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7624fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7625fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7626fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7627fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7628fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7629fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7630fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v7631fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 9996='9996. NONE OR LT 1HR' ;
  VALUE v7632fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7633fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7634fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7635fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7636fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7637fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7638fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7639fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7640fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7641fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7642fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. PERS ON DIR LABEL'
                  2='2. PROXY #1' 3='3. PROXY #2' 4='4. PROXY #3'
                  5='5. PROXY #4' ;
  VALUE v7643fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. ALL OTHER'
                  1='1. DEM IN SUPV' ;
  VALUE v7644fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7645fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7646fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7647fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7648fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. DIRECTOR' 2='2. DEPUTY'
                  3='3. CONTROLL' 4='4. ADMIUNSP' 5='5. ADMASST'
                  6='6. OFFMANA' 7='7. SECTARY' 9='9. PUBRELAT'
                  10='10. LEGALSER' 19='19. OTHRADM' 21='21. ANYHEAD'
                  22='22. ASSTGEAD' 23='23. SUPERVISOR' 31='31. PROBOFFC'
                  32='32. COUNSELR' 34='34. CLERGY' 38='38. ADVISOR'
                  41='41. PHYSICN' 42='42. NURSE' 43='43. OTHHCP'
                  44='44. PSYCHOL' 45='45. SOCWORK' 71='71. VOLUNTR'
                  72='72. STUDENT' 73='73. PUBOFFIC' 74='74. TEACHER'
                  97='97. OTHER' ;
  VALUE v7649fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7650fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7651fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 29 YEARS OLD OR YOUNGER'
                  2='2. 30-34 YEARS OLD' 3='3. 35-39 YEARS OLD'
                  4='4. 40-44 YEARS OLD' 5='5. 45-49 YEARS OLD'
                  6='6. 50-54 YEARS OLD' 7='7. 55-59 YEARS OLD'
                  8='8. 60 YEARS OLD OR OLDER' ;
  VALUE v7652fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. Female' 1='1. Male' ;
  VALUE v7653fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. WHITE' 2='2. BLACK'
                  5='5. OTHER' ;
  VALUE v7654fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7655fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7656fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7657fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7658fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v7659fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7660fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v7661fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v7662fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v7663fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v7664fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v7665fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v7666fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v7667fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v7668fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v7669fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8004fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8005fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v8006fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8007fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 88='88. 1988' 89='89. 1989'
                  90='90. 1990' 91='91. 1991' ;
  VALUE v8008fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v8009fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8010fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 88='88. 1988' 89='89. 1989'
                  90='90. 1990' 91='91. 1991' ;
  VALUE v8011fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8012fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8013fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8014fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8015fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8016fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8017fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8018fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8019fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8020fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VOCREHAB' 2='2. COURTS'
                  3='3. HOSPITAL' 4='4. PRIVCLIN' 5='5. PHYSICAN' 6='6. DSS'
                  7='7. MH AGNCY' 8='8. EAP' 9='9. POLICE' 10='10. SCHOOLS'
                  11='11. CHURCHES' 12='12. SELF_REF' 13='13. FRIENDS'
                  14='14. FAMILY' 51='51. INPT FAC' 52='52. AA' 53='53. HMO'
                  54='54. HOTLINE' 61='61. DUI/DWI' 62='62. PAROLE'
                  63='63. DEPT CHILD' 71='71. PROFCNSL' 72='72. LAWYERS'
                  73='73. OTHOSAT' 74='74. INTAKERE' 75='75. SERVPROV'
                  97='97. OTHER' ;
  VALUE v8021fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8022fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VOCREHAB' 2='2. COURTS'
                  3='3. HOSPITAL' 4='4. PRIVCLIN' 5='5. PHYSICAN' 6='6. DSS'
                  7='7. MH AGNCY' 8='8. EAP' 9='9. POLICE' 10='10. SCHOOLS'
                  11='11. CHURCHES' 12='12. SELF_REF' 13='13. FRIENDS'
                  14='14. FAMILY' 51='51. INPT FAC' 52='52. AA' 53='53. HMO'
                  54='54. HOTLINE' 61='61. DUI/DWI' 62='62. PAROLE'
                  63='63. DEPT CHILD' 71='71. PROFCNSL' 72='72. LAWYERS'
                  73='73. OTHOSAT' 74='74. INTAKERE' 75='75. SERVPROV'
                  97='97. OTHER' ;
  VALUE v8023fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8024fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VOCREHAB' 2='2. COURTS'
                  3='3. HOSPITAL' 4='4. PRIVCLIN' 5='5. PHYSICAN' 6='6. DSS'
                  7='7. MH AGNCY' 8='8. EAP' 9='9. POLICE' 10='10. SCHOOLS'
                  11='11. CHURCHES' 12='12. SELF_REF' 13='13. FRIENDS'
                  14='14. FAMILY' 51='51. INPT FAC' 52='52. AA' 53='53. HMO'
                  54='54. HOTLINE' 61='61. DUI/DWI' 62='62. PAROLE'
                  63='63. DEPT CHILD' 71='71. PROFCNSL' 72='72. LAWYERS'
                  73='73. OTHOSAT' 74='74. INTAKERE' 75='75. SERVPROV'
                  97='97. OTHER' ;
  VALUE v8025fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8026fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VOCREHAB' 2='2. COURTS'
                  3='3. HOSPITAL' 4='4. PRIVCLIN' 5='5. PHYSICAN' 6='6. DSS'
                  7='7. MH AGNCY' 8='8. EAP' 9='9. POLICE' 10='10. SCHOOLS'
                  11='11. CHURCHES' 12='12. SELF_REF' 13='13. FRIENDS'
                  14='14. FAMILY' 51='51. INPT FAC' 52='52. AA' 53='53. HMO'
                  54='54. HOTLINE' 61='61. DUI/DWI' 62='62. PAROLE'
                  63='63. DEPT CHILD' 71='71. PROFCNSL' 72='72. LAWYERS'
                  73='73. OTHOSAT' 74='74. INTAKERE' 75='75. SERVPROV'
                  97='97. OTHER' ;
  VALUE v8027fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8028fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VOCREHAB' 2='2. COURTS'
                  3='3. HOSPITAL' 4='4. PRIVCLIN' 5='5. PHYSICAN' 6='6. DSS'
                  7='7. MH AGNCY' 8='8. EAP' 9='9. POLICE' 10='10. SCHOOLS'
                  11='11. CHURCHES' 12='12. SELF_REF' 13='13. FRIENDS'
                  14='14. FAMILY' 51='51. INPT FAC' 52='52. AA' 53='53. HMO'
                  54='54. HOTLINE' 61='61. DUI/DWI' 62='62. PAROLE'
                  63='63. DEPT CHILD' 71='71. PROFCNSL' 72='72. LAWYERS'
                  73='73. OTHOSAT' 74='74. INTAKERE' 75='75. SERVPROV'
                  97='97. OTHER' ;
  VALUE v8029fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8030fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. VOCREHAB' 2='2. COURTS'
                  3='3. HOSPITAL' 4='4. PRIVCLIN' 5='5. PHYSICAN' 6='6. DSS'
                  7='7. MH AGNCY' 8='8. EAP' 9='9. POLICE' 10='10. SCHOOLS'
                  11='11. CHURCHES' 12='12. SELF_REF' 13='13. FRIENDS'
                  14='14. FAMILY' 51='51. INPT FAC' 52='52. AA' 53='53. HMO'
                  54='54. HOTLINE' 61='61. DUI/DWI' 62='62. PAROLE'
                  63='63. DEPT CHILD' 71='71. PROFCNSL' 72='72. LAWYERS'
                  73='73. OTHOSAT' 74='74. INTAKERE' 75='75. SERVPROV'
                  97='97. OTHER' ;
  VALUE v8031fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. FEWSOURC' 2='2. LARGE %'
                  3='3. EXCHANGE' 4='4. GOODCAND' 5='5. QUALREFR'
                  6='6. MOTIV CL' 7='7. FUNDING' 8='8. GOOD REP'
                  9='9. TARGTPOP' 21='21. ONLYAVAL' 22='22. CL REFRL'
                  29='29. OTHER CL' 51='51. FINANCAL' 95='95. NOT CRIT'
                  97='97. OTHR AGY' ;
  VALUE v8032fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. FEWSOURC' 2='2. LARGE %'
                  3='3. EXCHANGE' 4='4. GOODCAND' 5='5. QUALREFR'
                  6='6. MOTIV CL' 7='7. FUNDING' 8='8. GOOD REP'
                  9='9. TARGTPOP' 21='21. ONLYAVAL' 22='22. CL REFRL'
                  29='29. OTHER CL' 51='51. FINANCAL' 95='95. NOT CRIT'
                  97='97. OTHR AGY' ;
  VALUE v8033fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8034fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8035fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8036fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8037fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8038fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8039fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8040fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HOSPITAL' 2='2. PRIVCLIN'
                  3='3. PHYSICAN' 4='4. VOCREHAB' 5='5. DSS' 6='6. MH AGNCY'
                  7='7. OTHROSAT' 8='8. SCHOOLS' 9='9. CHURCHES'
                  10='10. AA/NA' 51='51. SELFHELP' 52='52. INPATENT'
                  53='53. SUPPORT' 54='54. CRISIS' 61='61. AIDS'
                  62='62. MH TRMT' 71='71. MEDICAL' 72='72. LEGAL'
                  73='73. EMPLOYMT' 74='74. HOUSING' 75='75. PAROLE'
                  76='76. FINANCAL' 77='77. EDUCATON' 97='97. OTHER' ;
  VALUE v8041fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8042fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HOSPITAL' 2='2. PRIVCLIN'
                  3='3. PHYSICAN' 4='4. VOCREHAB' 5='5. DSS' 6='6. MH AGNCY'
                  7='7. OTHROSAT' 8='8. SCHOOLS' 9='9. CHURCHES'
                  10='10. AA/NA' 51='51. SELFHELP' 52='52. INPATENT'
                  53='53. SUPPORT' 54='54. CRISIS' 61='61. AIDS'
                  62='62. MH TRMT' 71='71. MEDICAL' 72='72. LEGAL'
                  73='73. EMPLOYMT' 74='74. HOUSING' 75='75. PAROLE'
                  76='76. FINANCAL' 77='77. EDUCATON' 97='97. OTHER' ;
  VALUE v8043fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8044fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HOSPITAL' 2='2. PRIVCLIN'
                  3='3. PHYSICAN' 4='4. VOCREHAB' 5='5. DSS' 6='6. MH AGNCY'
                  7='7. OTHROSAT' 8='8. SCHOOLS' 9='9. CHURCHES'
                  10='10. AA/NA' 51='51. SELFHELP' 52='52. INPATENT'
                  53='53. SUPPORT' 54='54. CRISIS' 61='61. AIDS'
                  62='62. MH TRMT' 71='71. MEDICAL' 72='72. LEGAL'
                  73='73. EMPLOYMT' 74='74. HOUSING' 75='75. PAROLE'
                  76='76. FINANCAL' 77='77. EDUCATON' 97='97. OTHER' ;
  VALUE v8045fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8046fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HOSPITAL' 2='2. PRIVCLIN'
                  3='3. PHYSICAN' 4='4. VOCREHAB' 5='5. DSS' 6='6. MH AGNCY'
                  7='7. OTHROSAT' 8='8. SCHOOLS' 9='9. CHURCHES'
                  10='10. AA/NA' 51='51. SELFHELP' 52='52. INPATENT'
                  53='53. SUPPORT' 54='54. CRISIS' 61='61. AIDS'
                  62='62. MH TRMT' 71='71. MEDICAL' 72='72. LEGAL'
                  73='73. EMPLOYMT' 74='74. HOUSING' 75='75. PAROLE'
                  76='76. FINANCAL' 77='77. EDUCATON' 97='97. OTHER' ;
  VALUE v8047fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8048fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HOSPITAL' 2='2. PRIVCLIN'
                  3='3. PHYSICAN' 4='4. VOCREHAB' 5='5. DSS' 6='6. MH AGNCY'
                  7='7. OTHROSAT' 8='8. SCHOOLS' 9='9. CHURCHES'
                  10='10. AA/NA' 51='51. SELFHELP' 52='52. INPATENT'
                  53='53. SUPPORT' 54='54. CRISIS' 61='61. AIDS'
                  62='62. MH TRMT' 71='71. MEDICAL' 72='72. LEGAL'
                  73='73. EMPLOYMT' 74='74. HOUSING' 75='75. PAROLE'
                  76='76. FINANCAL' 77='77. EDUCATON' 97='97. OTHER' ;
  VALUE v8049fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8050fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HOSPTL' 2='2. RESTXUNT'
                  3='3. PHYSICAN' 4='4. VOCREHAB' 5='5. DSS' 6='6. MT.AGN'
                  7='7. OTH.OSAT' 8='8. SCHOOLS' 9='9. CHURCHES'
                  10='10. SELFHELP' 51='51. SELFHELP-NA' 52='52. INPT.TX'
                  53='53. SUPPORT' 54='54. CRISIS' 61='61. AIDS'
                  62='62. MH.TX' 71='71. OTH.MED' 72='72. LEGAL'
                  73='73. EMPLOYMT' 74='74. HOUSING' 75='75. PAROLE'
                  76='76. FINANCE' 77='77. EDUCATN' 97='97. OTHER' ;
  VALUE v8051fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LIKE.US' 2='2. COMPSERV'
                  3='3. MORECOMP' 11='11. INPATN' 12='12. METHMAIN'
                  14='14. MEDCARE' 15='15. HOUSING' 16='16. EMPLYMT'
                  17='17. MT.THPY' 31='31. LOW.COST' 32='32. GOODSERV'
                  33='33. QUALSTAF' 34='34. CONVIENT' 35='35. ROUTINE'
                  36='36. SUPP.AVL' 39='39. GOOD.GEN' 41='41. STRUCENV'
                  42='42. NEW.ENV' 43='43. WORKS' 97='97. OTHER' ;
  VALUE v8052fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LIKE.US' 2='2. COMPSERV'
                  3='3. MORECOMP' 11='11. INPATN' 12='12. METHMAIN'
                  14='14. MEDCARE' 15='15. HOUSING' 16='16. EMPLYMT'
                  17='17. MT.THPY' 31='31. LOW.COST' 32='32. GOODSERV'
                  33='33. QUALSTAF' 34='34. CONVIENT' 35='35. ROUTINE'
                  36='36. SUPP.AVL' 39='39. GOOD.GEN' 41='41. STRUCENV'
                  42='42. NEW.ENV' 43='43. WORKS' 97='97. OTHER' ;
  VALUE v8053fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NEVER' 2='2. RARELY'
                  3='3. SOMETIME' 4='4. OFTEN' 5='5. ALWAYS' ;
  VALUE v8054fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NEVER' 2='2. RARELY'
                  3='3. SOMETIME' 4='4. OFTEN' 5='5. ALWAYS' ;
  VALUE v8055fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NEVER' 2='2. RARELY'
                  3='3. SOMETIME' 4='4. OFTEN' 5='5. ALWAYS' ;
  VALUE v8056fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NEVER' 2='2. RARELY'
                  3='3. SOMETIME' 4='4. OFTEN' 5='5. ALWAYS' ;
  VALUE v8057fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MONTMETH' 2='2. MAINTNCL'
                  3='3. INTRO CL' 4='4. STAF_STF' 5='5. RECORDS'
                  6='6. CLRELEAS' 11='11. MAKEAPPT' 12='12. GETREPRT'
                  97='97. OTHER' ;
  VALUE v8058fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NEVER' 2='2. RARELY'
                  3='3. SOMETIME' 4='4. OFTEN' 5='5. ALWAYS' ;
  VALUE v8059fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MONTMETH' 2='2. MAINTNCL'
                  3='3. INTRO CL' 4='4. STAF_STF' 5='5. RECORDS'
                  6='6. CLRELEAS' 11='11. MAKEAPPT' 12='12. GETREPRT'
                  97='97. OTHER' ;
  VALUE v8060fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NEVER' 2='2. RARELY'
                  3='3. SOMETIME' 4='4. OFTEN' 5='5. ALWAYS' ;
  VALUE v8061fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MONTMETH' 2='2. MAINTNCL'
                  3='3. INTRO CL' 4='4. STAF_STF' 5='5. RECORDS'
                  6='6. CLRELEAS' 11='11. MAKEAPPT' 12='12. GETREPRT'
                  97='97. OTHER' ;
  VALUE v8062fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NEVER' 2='2. RARELY'
                  3='3. SOMETIME' 4='4. OFTEN' 5='5. ALWAYS' ;
  VALUE v8063fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MONTMETH' 2='2. MAINTNCL'
                  3='3. INTRO CL' 4='4. STAF_STF' 5='5. RECORDS'
                  6='6. CLRELEAS' 11='11. MAKEAPPT' 12='12. GETREPRT'
                  97='97. OTHER' ;
  VALUE v8064fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NEVER' 2='2. RARELY'
                  3='3. SOMETIME' 4='4. OFTEN' 5='5. ALWAYS' ;
  VALUE v8065fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MONTMETH' 2='2. MAINTNCL'
                  3='3. INTRO CL' 4='4. STAF_STF' 5='5. RECORDS'
                  6='6. CLRELEAS' 11='11. MAKEAPPT' 12='12. GETREPRT'
                  97='97. OTHER' ;
  VALUE v8066fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NEVER' 2='2. RARELY'
                  3='3. SOMETIME' 4='4. OFTEN' 5='5. ALWAYS' ;
  VALUE v8067fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8068fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8069fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8070fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8071fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8072fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8073fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8074fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8075fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8076fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8077fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8078fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8079fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8080fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8081fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8082fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8083fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8084fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8085fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8086fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8087fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8088fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8089fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8090fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8091fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8092fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8093fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8094fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8095fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8096fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8097fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8098fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8099fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO TX PROV BY X-ADDICTS'
                  1='1. YES TX PROV BY X-ADDICTS' ;
  VALUE v8100fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8101fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8102fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO PROF STAFF'
                  1='1. MASTERS DEG +' ;
  VALUE v8103fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8104fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8105fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v8106fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8107fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8108fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8109fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8110fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v8111fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v8112fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8113fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8114fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8115fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8116fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v8117fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v8118fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8119fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8120fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8121fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8122fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v8123fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8124fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8125fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8126fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8127fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v8128fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8129fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8130fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8131fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v8132fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v8133fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8134fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8135fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8136fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v8137fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v8138fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8139fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8140fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8141fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v8142fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8143fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8144fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8145fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 1 MO OR LESS' ;
  VALUE v8146fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. Not Done/Never'
                  1='1. LT Once/Yr' 2='2. Annual' 3='3. Semi-annual'
                  4='4. Quarterly' 5='5. Monthly' ;
  VALUE v8147fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Much Too Low'
                  2='2. Too Low' 3='3. About Right' 4='4. Too High'
                  5='5. Much Too High' ;
  VALUE v8148fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8149fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8150fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8151fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8152fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8153fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8154fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8155fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8156fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8157fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8158fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8159fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8160fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8161fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8162fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8163fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8164fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v8165fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8166fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 88='88. 1988' 89='89. 1989'
                  90='90. 1990' 91='91. 1991' ;
  VALUE v8167fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='01. January' 2='02. February'
                  3='03. March' 4='04. April' 5='05. May' 6='06. June'
                  7='07. July' 8='08. August' 9='09. September'
                  10='10. October' 11='11. November' 12='12. December' ;
  VALUE v8168fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8169fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 88='88. 1988' 89='89. 1989'
                  90='90. 1990' 91='91. 1991' ;
  VALUE v8170fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8171fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8172fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8173fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8174fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8175fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8176fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8177fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8178fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8179fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8180fff  -6='-6. CRACK INCLUDED W/COCAINE' -5='-5. NO INTERVIEW'
                  -4='-4. PARTIAL INTERVIEW' -3='-3. REFUSED/NA'
                  -2='-2. DONT KNOW' -1='-1. SKIPPED QUESTION' ;
  VALUE v8181fff  -6='-6. CRACK INCLUDED W/COCAINE' -5='-5. NO INTERVIEW'
                  -4='-4. PARTIAL INTERVIEW' -3='-3. REFUSED/NA'
                  -2='-2. DONT KNOW' -1='-1. SKIPPED QUESTION' ;
  VALUE v8182fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8183fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8184fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8185fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8186fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8187fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8188fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8189fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. ALCOHOL' 2='2. STEROIDS'
                  3='3. INHALNT' 4='4. QUAALUDE' 31='31. AMPHET/MARIJUANA'
                  32='32. MARIJUANA/HALLUC' 41='41. HEROIN/OTR EXC 55,61'
                  51='51. ALCOHOL/MARIJUANA' 52='52. ALCO/COCAINE'
                  53='53. ALC/MARI/COC' 54='54. ALC/TRANQ'
                  55='55. ALC/HEROIN' 56='56. ALC/AMPHET'
                  59='59. ALC&ANY/EVERYTHG' 61='61. COCA/HEROIN'
                  62='62. COCA/MARIJ' 63='63. COCA/OTH' 71='71. OVER COUNTER'
                  72='72. PRESCRIP' 73='73. DESIGNER' 81='81. CAFFEINE'
                  82='82. NICOTINE' 91='91. OPIATE' 92='92. BARB/TRANQ'
                  93='93. SEDATIVE/HYPNO' 94='94. AMPHETA' 95='95. HALLUC'
                  96='96. PAINKILL' 97='97. OTHERS' ;
  VALUE v8190fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8191fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. ALCOHOL' 2='2. STEROIDS'
                  3='3. INHALNT' 4='4. QUAALUDE' 31='31. AMPHET/MARIJUANA'
                  32='32. MARIJUANA/HALLUC' 41='41. HEROIN/OTR EXC 55,61'
                  51='51. ALCOHOL/MARIJUANA' 52='52. ALCO/COCAINE'
                  53='53. ALC/MARI/COC' 54='54. ALC/TRANQ'
                  55='55. ALC/HEROIN' 56='56. ALC/AMPHET'
                  59='59. ALC&ANY/EVERYTHG' 61='61. COCA/HEROIN'
                  62='62. COCA/MARIJ' 63='63. COCA/OTH' 71='71. OVER COUNTER'
                  72='72. PRESCRIP' 73='73. DESIGNER' 81='81. CAFFEINE'
                  82='82. NICOTINE' 91='91. OPIATE' 92='92. BARB/TRANQ'
                  93='93. SEDATIVE/HYPNO' 94='94. AMPHETA' 95='95. HALLUC'
                  96='96. PAINKILL' 97='97. OTHERS' ;
  VALUE v8192fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8193fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. ALCOHOL' 2='2. STEROIDS'
                  3='3. INHALNT' 4='4. QUAALUDE' 31='31. AMPHET/MARIJUANA'
                  32='32. MARIJUANA/HALLUC' 41='41. HEROIN/OTR EXC 55,61'
                  51='51. ALCOHOL/MARIJUANA' 52='52. ALCO/COCAINE'
                  53='53. ALC/MARI/COC' 54='54. ALC/TRANQ'
                  55='55. ALC/HEROIN' 56='56. ALC/AMPHET'
                  59='59. ALC&ANY/EVERYTHG' 61='61. COCA/HEROIN'
                  62='62. COCA/MARIJ' 63='63. COCA/OTH' 71='71. OVER COUNTER'
                  72='72. PRESCRIP' 73='73. DESIGNER' 81='81. CAFFEINE'
                  82='82. NICOTINE' 91='91. OPIATE' 92='92. BARB/TRANQ'
                  93='93. SEDATIVE/HYPNO' 94='94. AMPHETA' 95='95. HALLUC'
                  96='96. PAINKILL' 97='97. OTHERS' ;
  VALUE v8194fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8195fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. ALCOHOL' 2='2. STEROIDS'
                  3='3. INHALNT' 4='4. QUAALUDE' 31='31. AMPHET/MARIJUANA'
                  32='32. MARIJUANA/HALLUC' 41='41. HEROIN/OTR EXC 55,61'
                  51='51. ALCOHOL/MARIJUANA' 52='52. ALCO/COCAINE'
                  53='53. ALC/MARI/COC' 54='54. ALC/TRANQ'
                  55='55. ALC/HEROIN' 56='56. ALC/AMPHET'
                  59='59. ALC&ANY/EVERYTHG' 61='61. COCA/HEROIN'
                  62='62. COCA/MARIJ' 63='63. COCA/OTH' 71='71. OVER COUNTER'
                  72='72. PRESCRIP' 73='73. DESIGNER' 81='81. CAFFEINE'
                  82='82. NICOTINE' 91='91. OPIATE' 92='92. BARB/TRANQ'
                  93='93. SEDATIVE/HYPNO' 94='94. AMPHETA' 95='95. HALLUC'
                  96='96. PAINKILL' 97='97. OTHERS' ;
  VALUE v8196fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8197fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8198fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8199fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8200fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8201fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8202fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8203fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8204fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8205fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8206fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8207fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8208fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8209fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8210fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8211fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8212fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8213fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8214fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8215fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8216fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8217fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8218fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT' 2='2. FORGE CHEK'
                  3='3. FORGE RX' 4='4. CON GAME' 5='5. SELLDRUG'
                  6='6. SELLOTHR' 7='7. ASSAULT/MURDER' 8='8. GAMBLE'
                  9='9. PROSTIT' 96='96. OTHER ILLEG BEHVR' 97='97. OTHER' ;
  VALUE v8219fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8220fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT' 2='2. FORGE CHEK'
                  3='3. FORGE RX' 4='4. CON GAME' 5='5. SELLDRUG'
                  6='6. SELLOTHR' 7='7. ASSAULT/MURDER' 8='8. GAMBLE'
                  9='9. PROSTIT' 96='96. OTHER ILLEG BEHVR' 97='97. OTHER' ;
  VALUE v8221fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8222fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT' 2='2. FORGE CHEK'
                  3='3. FORGE RX' 4='4. CON GAME' 5='5. SELLDRUG'
                  6='6. SELLOTHR' 7='7. ASSAULT/MURDER' 8='8. GAMBLE'
                  9='9. PROSTIT' 96='96. OTHER ILLEG BEHVR' 97='97. OTHER' ;
  VALUE v8223fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8224fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT' 2='2. FORGE CHEK'
                  3='3. FORGE RX' 4='4. CON GAME' 5='5. SELLDRUG'
                  6='6. SELLOTHR' 7='7. ASSAULT/MURDER' 8='8. GAMBLE'
                  9='9. PROSTIT' 96='96. OTHER ILLEG BEHVR' 97='97. OTHER' ;
  VALUE v8225fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8226fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT' 2='2. FORGE CHEK'
                  3='3. FORGE RX' 4='4. CON GAME' 5='5. SELLDRUG'
                  6='6. SELLOTHR' 7='7. ASSAULT/MURDER' 8='8. GAMBLE'
                  9='9. PROSTIT' 96='96. OTHER ILLEG BEHVR' 97='97. OTHER' ;
  VALUE v8227fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8228fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8229fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8230fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8231fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8232fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8233fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8234fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8235fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8236fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8237fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8238fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8239fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8240fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8241fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8242fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8243fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8244fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8245fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8246fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8247fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8248fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8249fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8250fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8251fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8252fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8253fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8254fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8255fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8256fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8257fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8258fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8259fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Under 3 mos'
                  2='2. 3 to 6 mos' 3='3. 7 to 12 mos' 4='4. 13 to 18 mos'
                  5='5. 19 to 24 mos' 6='6. 25 to 36 mos'
                  7='7. 37 mos or more' ;
  VALUE v8260fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8261fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. Under 3 mos'
                  2='2. 3 to 6 mos' 3='3. 7 to 12 mos' 4='4. 13 to 18 mos'
                  5='5. 19 to 24 mos' 6='6. 25 to 36 mos'
                  7='7. 37 mos or more' ;
  VALUE v8262fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8263fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8264fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8265fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8266fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8267fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8268fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v8269fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8270fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8271fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8272fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v8273fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v8274fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8275fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8276fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8277fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v8278fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MEDICAID' 2='2. MEDICARE'
                  3='3. MED ASST' 4='4. CHAMPUS' 10='10. BC/BS' 11='11. HMO'
                  12='12. OTHER INSUR' 15='15. MULTI INSUR' 16='16. CO INS'
                  17='17. OTHER PAYER' 21='21. FED COURT'
                  22='22. AMER INDIAN' 23='23. NIDA' 24='24. NIAAA'
                  25='25. NIMH' 26='26. FDA' 27='27. DEA' 28='28. VA'
                  29='29. FOODSTMP' 30='30. HHS' 31='31. ADAMHA'
                  32='32. FED REGISTER' 33='33. CDC' 37='37. OTHR FED'
                  38='38. TITLE 20' 39='39. BLKGRANT' 40='40. ST BOARD PHARM'
                  41='41. STATE COURT' 42='42. DEPT HEALTH'
                  43='43. DEPT SOC SRV' 44='44. SA UNIT'
                  46='46. ST 508/509 Funds' 47='47. OTHER STATE'
                  48='48. LIC DEPT' 49='49. ST LEVEL-NA AGY'
                  51='51. COUNTY CRT' 52='52. CITY CRT' 53='53. COURTS-NA'
                  54='54. LOC ALC AGCY' 55='55. COUNTY' 56='56. CITY'
                  57='57. REGIONAL' 58='58. LOCAL' 61='61. OTHER GOVT'
                  71='71. BUSINESS' 72='72. UNITED WAY' 73='73. JCAHO'
                  74='74. HOSPITALS-NFS' 75='75. CODAP'
                  76='76. OTHER COMM ORG' 77='77. PROF ORG' 81='81. INTEREST'
                  82='82. SALES' 83='83. FUND RAISING'
                  96='96. NONE/NO OTR MENT' 97='97. OTHER FUND SRC' ;
  VALUE v8279fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8280fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8281fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO CHECK' 1='1. CHECKED' ;
  VALUE v8282fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. LOCAL' 2='2. STATE'
                  3='3. FEDERAL' 4='4. NATIONAL' ;
  VALUE v8283fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8284fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8285fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8286fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8287fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8288fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8289fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8290fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8291fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8292fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NO' 1='1. YES'
                  6='6. R VOL: REF OTR ORG' ;
  VALUE v8293fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 6='6. 16 PERS FACTORS (16PF)'
                  7='7. BECK DEP INV' 8='8. DRAW PICT' 9='9. MILLON TESTS'
                  10='10. MMPI/MMP' 11='11. RORSCHACH' 12='12. TAT'
                  13='13. HOUSE TREE PERS' 14='14. WPI' 15='15. SCL 90R'
                  16='16. OTR PROJECTIVE' 17='17. OTR PERS PROFIL'
                  19='19. OTR NOT 16,17' 20='20. WAIS' 21='21. WISC'
                  22='22. GESTALT' 23='23. SHIPLEY' 24='24. SENTCOMP'
                  25='25. WECH MEM' 27='27. IQ TESTS' 28='28. ACHIEVE'
                  29='29. OTHER IQ' 30='30. MAST' 31='31. MORT_FIL'
                  32='32. MANSON' 33='33. WASI' 39='39. OTR ALC/DRUG'
                  40='40. HISTORIES' 50='50. UNIT OWN QNAIRE'
                  60='60. Employ/Vocational' 96='96. DK TEST OUTSIDE'
                  97='97. OTHER' ;
  VALUE v8294fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 6='6. 16 PERS FACTORS (16PF)'
                  7='7. BECK DEP INV' 8='8. DRAW PICT' 9='9. MILLON TESTS'
                  10='10. MMPI/MMP' 11='11. RORSCHACH' 12='12. TAT'
                  13='13. HOUSE TREE PERS' 14='14. WPI' 15='15. SCL 90R'
                  16='16. OTR PROJECTIVE' 17='17. OTR PERS PROFIL'
                  19='19. OTR NOT 16,17' 20='20. WAIS' 21='21. WISC'
                  22='22. GESTALT' 23='23. SHIPLEY' 24='24. SENTCOMP'
                  25='25. WECH MEM' 27='27. IQ TESTS' 28='28. ACHIEVE'
                  29='29. OTHER IQ' 30='30. MAST' 31='31. MORT_FIL'
                  32='32. MANSON' 33='33. WASI' 39='39. OTR ALC/DRUG'
                  40='40. HISTORIES' 50='50. UNIT OWN QNAIRE'
                  60='60. Employ/Vocational' 96='96. DK TEST OUTSIDE'
                  97='97. OTHER' ;
  VALUE v8295fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 6='6. 16 PERS FACTORS (16PF)'
                  7='7. BECK DEP INV' 8='8. DRAW PICT' 9='9. MILLON TESTS'
                  10='10. MMPI/MMP' 11='11. RORSCHACH' 12='12. TAT'
                  13='13. HOUSE TREE PERS' 14='14. WPI' 15='15. SCL 90R'
                  16='16. OTR PROJECTIVE' 17='17. OTR PERS PROFIL'
                  19='19. OTR NOT 16,17' 20='20. WAIS' 21='21. WISC'
                  22='22. GESTALT' 23='23. SHIPLEY' 24='24. SENTCOMP'
                  25='25. WECH MEM' 27='27. IQ TESTS' 28='28. ACHIEVE'
                  29='29. OTHER IQ' 30='30. MAST' 31='31. MORT_FIL'
                  32='32. MANSON' 33='33. WASI' 39='39. OTR ALC/DRUG'
                  40='40. HISTORIES' 50='50. UNIT OWN QNAIRE'
                  60='60. Employ/Vocational' 96='96. DK TEST OUTSIDE'
                  97='97. OTHER' ;
  VALUE v8296fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8297fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8298fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8299fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8300fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8301fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8302fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8303fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8304fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. COUNSLOR' 2='2. CLINICAN'
                  3='3. CLNC.SUP' 4='4. MA.PERS' 95='95. ANY/ALL'
                  97='97. OTHER' ;
  VALUE v8305fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8306fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8307fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8308fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8309fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8310fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AA/NA' 2='2. DRUGFREE'
                  3='3. AWARENES' 4='4. BEHAVIOR' 5='5. CL_CENTR'
                  6='6. CODEPEND' 7='7. COGNITVE' 8='8. CONFRONT'
                  9='9. COUNSEL' 10='10. COUPLES' 11='11. CREATIVE'
                  12='12. CRITICAL' 13='13. ECLECTIC' 14='14. EDUCATON'
                  15='15. EGO_PSY' 16='16. EMPATHTC' 17='17. ENCOUNTR'
                  18='18. FAMILY' 19='19. FEEDBACK' 20='20. GESTALT'
                  21='21. GROUP' 22='22. HERE&NOW' 23='23. HOLISTIC'
                  24='24. HUMANIST' 25='25. INDIVUAL' 26='26. INSIGHT'
                  27='27. INTRVENT' 28='28. MARRIAGE' 29='29. MEDICAL'
                  30='30. NON_CONF' 31='31. PEER GRP' 32='32. PROCESS'
                  33='33. PSYCHOAN' 34='34. PSYCHOLG' 35='35. PSY_SOCL'
                  36='36. RATIONAL' 37='37. REALITY' 38='38. RECOVERY'
                  39='39. ROGERIAN' 40='40. ROLEPLAY' 41='41. SLF_ASES'
                  42='42. SELFHELP' 43='43. SPIRITUL' 44='44. SUPPORT'
                  45='45. SYSTEMS' 46='46. TASK_CEN' 47='47. TRANSACT'
                  48='48. RELAXATN' 49='49. ADLERIAN' 50='50. PROBSOLV'
                  51='51. PSYDYNMC' 52='52. INTERACT' 53='53. HYPNOSIS'
                  54='54. EXPRIENT' 55='55. PSYCHOED' 95='95. CL NEEDS'
                  97='97. OTHER' ;
  VALUE v8311fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AA/NA' 2='2. DRUGFREE'
                  3='3. AWARENES' 4='4. BEHAVIOR' 5='5. CL_CENTR'
                  6='6. CODEPEND' 7='7. COGNITVE' 8='8. CONFRONT'
                  9='9. COUNSEL' 10='10. COUPLES' 11='11. CREATIVE'
                  12='12. CRITICAL' 13='13. ECLECTIC' 14='14. EDUCATON'
                  15='15. EGO_PSY' 16='16. EMPATHTC' 17='17. ENCOUNTR'
                  18='18. FAMILY' 19='19. FEEDBACK' 20='20. GESTALT'
                  21='21. GROUP' 22='22. HERE&NOW' 23='23. HOLISTIC'
                  24='24. HUMANIST' 25='25. INDIVUAL' 26='26. INSIGHT'
                  27='27. INTRVENT' 28='28. MARRIAGE' 29='29. MEDICAL'
                  30='30. NON_CONF' 31='31. PEER GRP' 32='32. PROCESS'
                  33='33. PSYCHOAN' 34='34. PSYCHOLG' 35='35. PSY_SOCL'
                  36='36. RATIONAL' 37='37. REALITY' 38='38. RECOVERY'
                  39='39. ROGERIAN' 40='40. ROLEPLAY' 41='41. SLF_ASES'
                  42='42. SELFHELP' 43='43. SPIRITUL' 44='44. SUPPORT'
                  45='45. SYSTEMS' 46='46. TASK_CEN' 47='47. TRANSACT'
                  48='48. RELAXATN' 49='49. ADLERIAN' 50='50. PROBSOLV'
                  51='51. PSYDYNMC' 52='52. INTERACT' 53='53. HYPNOSIS'
                  54='54. EXPRIENT' 55='55. PSYCHOED' 95='95. CL NEEDS'
                  97='97. OTHER' ;
  VALUE v8312fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AA/NA' 2='2. DRUGFREE'
                  3='3. AWARENES' 4='4. BEHAVIOR' 5='5. CL_CENTR'
                  6='6. CODEPEND' 7='7. COGNITVE' 8='8. CONFRONT'
                  9='9. COUNSEL' 10='10. COUPLES' 11='11. CREATIVE'
                  12='12. CRITICAL' 13='13. ECLECTIC' 14='14. EDUCATON'
                  15='15. EGO_PSY' 16='16. EMPATHTC' 17='17. ENCOUNTR'
                  18='18. FAMILY' 19='19. FEEDBACK' 20='20. GESTALT'
                  21='21. GROUP' 22='22. HERE&NOW' 23='23. HOLISTIC'
                  24='24. HUMANIST' 25='25. INDIVUAL' 26='26. INSIGHT'
                  27='27. INTRVENT' 28='28. MARRIAGE' 29='29. MEDICAL'
                  30='30. NON_CONF' 31='31. PEER GRP' 32='32. PROCESS'
                  33='33. PSYCHOAN' 34='34. PSYCHOLG' 35='35. PSY_SOCL'
                  36='36. RATIONAL' 37='37. REALITY' 38='38. RECOVERY'
                  39='39. ROGERIAN' 40='40. ROLEPLAY' 41='41. SLF_ASES'
                  42='42. SELFHELP' 43='43. SPIRITUL' 44='44. SUPPORT'
                  45='45. SYSTEMS' 46='46. TASK_CEN' 47='47. TRANSACT'
                  48='48. RELAXATN' 49='49. ADLERIAN' 50='50. PROBSOLV'
                  51='51. PSYDYNMC' 52='52. INTERACT' 53='53. HYPNOSIS'
                  54='54. EXPRIENT' 55='55. PSYCHOED' 95='95. CL NEEDS'
                  97='97. OTHER' ;
  VALUE v8313fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AA/NA' 2='2. DRUGFREE'
                  3='3. AWARENES' 4='4. BEHAVIOR' 5='5. CL_CENTR'
                  6='6. CODEPEND' 7='7. COGNITVE' 8='8. CONFRONT'
                  9='9. COUNSEL' 10='10. COUPLES' 11='11. CREATIVE'
                  12='12. CRITICAL' 13='13. ECLECTIC' 14='14. EDUCATON'
                  15='15. EGO_PSY' 16='16. EMPATHTC' 17='17. ENCOUNTR'
                  18='18. FAMILY' 19='19. FEEDBACK' 20='20. GESTALT'
                  21='21. GROUP' 22='22. HERE&NOW' 23='23. HOLISTIC'
                  24='24. HUMANIST' 25='25. INDIVUAL' 26='26. INSIGHT'
                  27='27. INTRVENT' 28='28. MARRIAGE' 29='29. MEDICAL'
                  30='30. NON_CONF' 31='31. PEER GRP' 32='32. PROCESS'
                  33='33. PSYCHOAN' 34='34. PSYCHOLG' 35='35. PSY_SOCL'
                  36='36. RATIONAL' 37='37. REALITY' 38='38. RECOVERY'
                  39='39. ROGERIAN' 40='40. ROLEPLAY' 41='41. SLF_ASES'
                  42='42. SELFHELP' 43='43. SPIRITUL' 44='44. SUPPORT'
                  45='45. SYSTEMS' 46='46. TASK_CEN' 47='47. TRANSACT'
                  48='48. RELAXATN' 49='49. ADLERIAN' 50='50. PROBSOLV'
                  51='51. PSYDYNMC' 52='52. INTERACT' 53='53. HYPNOSIS'
                  54='54. EXPRIENT' 55='55. PSYCHOED' 95='95. CL NEEDS'
                  97='97. OTHER' ;
  VALUE v8314fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. AA/NA' 2='2. DRUGFREE'
                  3='3. AWARENES' 4='4. BEHAVIOR' 5='5. CL_CENTR'
                  6='6. CODEPEND' 7='7. COGNITVE' 8='8. CONFRONT'
                  9='9. COUNSEL' 10='10. COUPLES' 11='11. CREATIVE'
                  12='12. CRITICAL' 13='13. ECLECTIC' 14='14. EDUCATON'
                  15='15. EGO_PSY' 16='16. EMPATHTC' 17='17. ENCOUNTR'
                  18='18. FAMILY' 19='19. FEEDBACK' 20='20. GESTALT'
                  21='21. GROUP' 22='22. HERE&NOW' 23='23. HOLISTIC'
                  24='24. HUMANIST' 25='25. INDIVUAL' 26='26. INSIGHT'
                  27='27. INTRVENT' 28='28. MARRIAGE' 29='29. MEDICAL'
                  30='30. NON_CONF' 31='31. PEER GRP' 32='32. PROCESS'
                  33='33. PSYCHOAN' 34='34. PSYCHOLG' 35='35. PSY_SOCL'
                  36='36. RATIONAL' 37='37. REALITY' 38='38. RECOVERY'
                  39='39. ROGERIAN' 40='40. ROLEPLAY' 41='41. SLF_ASES'
                  42='42. SELFHELP' 43='43. SPIRITUL' 44='44. SUPPORT'
                  45='45. SYSTEMS' 46='46. TASK_CEN' 47='47. TRANSACT'
                  48='48. RELAXATN' 49='49. ADLERIAN' 50='50. PROBSOLV'
                  51='51. PSYDYNMC' 52='52. INTERACT' 53='53. HYPNOSIS'
                  54='54. EXPRIENT' 55='55. PSYCHOED' 95='95. CL NEEDS'
                  97='97. OTHER' ;
  VALUE v8315fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8316fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8317fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. ALL OTRS'
                  1='1. NO F1/NONE F1C' ;
  VALUE v8318fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8319fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8320fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8321fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8322fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8323fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8324fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8325fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8326fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8327fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8328fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8329fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8330fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INDIV.TH' 2='2. GROUP.TH'
                  3='3. FAMIL.TH' 8='8. CODEPEND' 9='9. THERAPY'
                  11='11. 12.STEP' 12='12. SUPPRTGP' 21='21. PREVENT'
                  22='22. EVALUATN' 23='23. AFTERCAR' 24='24. CASEMANG'
                  31='31. INPATINT' 32='32. OTHERMED' 41='41. SOCSERVS'
                  95='95. PROBAREA' 97='97. OTHPROGS' ;
  VALUE v8331fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INDIV.TH' 2='2. GROUP.TH'
                  3='3. FAMIL.TH' 8='8. CODEPEND' 9='9. THERAPY'
                  11='11. 12.STEP' 12='12. SUPPRTGP' 21='21. PREVENT'
                  22='22. EVALUATN' 23='23. AFTERCAR' 24='24. CASEMANG'
                  31='31. INPATINT' 32='32. OTHERMED' 41='41. SOCSERVS'
                  95='95. PROBAREA' 97='97. OTHPROGS' ;
  VALUE v8332fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INDIV.TH' 2='2. GROUP.TH'
                  3='3. FAMIL.TH' 8='8. CODEPEND' 9='9. THERAPY'
                  11='11. 12.STEP' 12='12. SUPPRTGP' 21='21. PREVENT'
                  22='22. EVALUATN' 23='23. AFTERCAR' 24='24. CASEMANG'
                  31='31. INPATINT' 32='32. OTHERMED' 41='41. SOCSERVS'
                  95='95. PROBAREA' 97='97. OTHPROGS' ;
  VALUE v8333fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8334fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8335fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INDIV.TH' 2='2. GROUP.TH'
                  3='3. FAMIL.TH' 8='8. CODEPEND' 9='9. THERAPY'
                  11='11. 12.STEP' 12='12. SUPPRTGP' 21='21. PREVENT'
                  22='22. EVALUATN' 23='23. AFTERCAR' 24='24. CASEMANG'
                  31='31. INPATINT' 32='32. OTHERMED' 41='41. SOCSERVS'
                  95='95. PROBAREA' 97='97. OTHPROGS' ;
  VALUE v8336fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INDIV.TH' 2='2. GROUP.TH'
                  3='3. FAMIL.TH' 8='8. CODEPEND' 9='9. THERAPY'
                  11='11. 12.STEP' 12='12. SUPPRTGP' 21='21. PREVENT'
                  22='22. EVALUATN' 23='23. AFTERCAR' 24='24. CASEMANG'
                  31='31. INPATINT' 32='32. OTHERMED' 41='41. SOCSERVS'
                  95='95. PROBAREA' 97='97. OTHPROGS' ;
  VALUE v8337fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INDIV.TH' 2='2. GROUP.TH'
                  3='3. FAMIL.TH' 8='8. CODEPEND' 9='9. THERAPY'
                  11='11. 12.STEP' 12='12. SUPPRTGP' 21='21. PREVENT'
                  22='22. EVALUATN' 23='23. AFTERCAR' 24='24. CASEMANG'
                  31='31. INPATINT' 32='32. OTHERMED' 41='41. SOCSERVS'
                  95='95. PROBAREA' 97='97. OTHPROGS' ;
  VALUE v8338fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8339fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8340fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INDIV.TH' 2='2. GROUP.TH'
                  3='3. FAMIL.TH' 8='8. CODEPEND' 9='9. THERAPY'
                  11='11. 12.STEP' 12='12. SUPPRTGP' 21='21. PREVENT'
                  22='22. EVALUATN' 23='23. AFTERCAR' 24='24. CASEMANG'
                  31='31. INPATINT' 32='32. OTHERMED' 41='41. SOCSERVS'
                  95='95. PROBAREA' 97='97. OTHPROGS' ;
  VALUE v8341fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INDIV.TH' 2='2. GROUP.TH'
                  3='3. FAMIL.TH' 8='8. CODEPEND' 9='9. THERAPY'
                  11='11. 12.STEP' 12='12. SUPPRTGP' 21='21. PREVENT'
                  22='22. EVALUATN' 23='23. AFTERCAR' 24='24. CASEMANG'
                  31='31. INPATINT' 32='32. OTHERMED' 41='41. SOCSERVS'
                  95='95. PROBAREA' 97='97. OTHPROGS' ;
  VALUE v8342fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INDIV.TH' 2='2. GROUP.TH'
                  3='3. FAMIL.TH' 8='8. CODEPEND' 9='9. THERAPY'
                  11='11. 12.STEP' 12='12. SUPPRTGP' 21='21. PREVENT'
                  22='22. EVALUATN' 23='23. AFTERCAR' 24='24. CASEMANG'
                  31='31. INPATINT' 32='32. OTHERMED' 41='41. SOCSERVS'
                  95='95. PROBAREA' 97='97. OTHPROGS' ;
  VALUE v8343fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8344fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8345fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INDIV.TH' 2='2. GROUP.TH'
                  3='3. FAMIL.TH' 8='8. CODEPEND' 9='9. THERAPY'
                  11='11. 12.STEP' 12='12. SUPPRTGP' 21='21. PREVENT'
                  22='22. EVALUATN' 23='23. AFTERCAR' 24='24. CASEMANG'
                  31='31. INPATINT' 32='32. OTHERMED' 41='41. SOCSERVS'
                  95='95. PROBAREA' 97='97. OTHPROGS' ;
  VALUE v8346fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INDIV.TH' 2='2. GROUP.TH'
                  3='3. FAMIL.TH' 8='8. CODEPEND' 9='9. THERAPY'
                  11='11. 12.STEP' 12='12. SUPPRTGP' 21='21. PREVENT'
                  22='22. EVALUATN' 23='23. AFTERCAR' 24='24. CASEMANG'
                  31='31. INPATINT' 32='32. OTHERMED' 41='41. SOCSERVS'
                  95='95. PROBAREA' 97='97. OTHPROGS' ;
  VALUE v8347fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INDIV.TH' 2='2. GROUP.TH'
                  3='3. FAMIL.TH' 8='8. CODEPEND' 9='9. THERAPY'
                  11='11. 12.STEP' 12='12. SUPPRTGP' 21='21. PREVENT'
                  22='22. EVALUATN' 23='23. AFTERCAR' 24='24. CASEMANG'
                  31='31. INPATINT' 32='32. OTHERMED' 41='41. SOCSERVS'
                  95='95. PROBAREA' 97='97. OTHPROGS' ;
  VALUE v8348fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8349fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. GEN PUBLIC'
                  2='2. SEG PUB DEAL DRUG PROBS' 3='3. ALL CLIENTS'
                  6='6. CHILDREN' 7='7. OLDER CLIENTS' 8='8. CODEPENDS'
                  9='9. LOW INCOME' 10='10. MEN' 12='12. BLACKS'
                  13='13. GAYS/LESBIANS' 14='14. PARENT GRPS'
                  15='15. MINORITIES EXC BLACKS' 16='16. HANDICAP'
                  17='17. PREG WOMEN/TEENS' 18='18. OTR PROGS FOR WOMEN'
                  19='19. TEENS' 20='20. SPOUSE/SIG OTHR/CLOSE FAM'
                  21='21. ALCOHOL' 22='22. COCAINE' 23='23. HEROIN/OPIATES'
                  27='27. DUAL DIAGNOSIS' 28='28. SEVERE ADDICT CLNTS'
                  29='29. EARLY STAGE ADDICTION' 31='31. CHRONIC PAIN'
                  32='32. METH RECIPIENTS' 33='33. AIDS RELATED'
                  34='34. MENTAL HLTH PROBS' 35='35. DUI/DWI CLIENTS'
                  37='37. PERIPHERAL PROBS' 41='41. AFTERCARE' 97='97. OTHER' ;
  VALUE v8350fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8351fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INDIV.TH' 2='2. GROUP.TH'
                  3='3. FAMIL.TH' 8='8. CODEPEND' 9='9. THERAPY'
                  11='11. 12.STEP' 12='12. SUPPRTGP' 21='21. PREVENT'
                  22='22. EVALUATN' 23='23. AFTERCAR' 24='24. CASEMANG'
                  31='31. INPATINT' 32='32. OTHERMED' 41='41. SOCSERVS'
                  95='95. PROBAREA' 97='97. OTHPROGS' ;
  VALUE v8352fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INDIV.TH' 2='2. GROUP.TH'
                  3='3. FAMIL.TH' 8='8. CODEPEND' 9='9. THERAPY'
                  11='11. 12.STEP' 12='12. SUPPRTGP' 21='21. PREVENT'
                  22='22. EVALUATN' 23='23. AFTERCAR' 24='24. CASEMANG'
                  31='31. INPATINT' 32='32. OTHERMED' 41='41. SOCSERVS'
                  95='95. PROBAREA' 97='97. OTHPROGS' ;
  VALUE v8353fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INDIV.TH' 2='2. GROUP.TH'
                  3='3. FAMIL.TH' 8='8. CODEPEND' 9='9. THERAPY'
                  11='11. 12.STEP' 12='12. SUPPRTGP' 21='21. PREVENT'
                  22='22. EVALUATN' 23='23. AFTERCAR' 24='24. CASEMANG'
                  31='31. INPATINT' 32='32. OTHERMED' 41='41. SOCSERVS'
                  95='95. PROBAREA' 97='97. OTHPROGS' ;
  VALUE v8354fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. GEN PUBLIC'
                  2='2. SEG PUB DEAL DRUG PROBS' 3='3. ALL CLIENTS'
                  6='6. CHILDREN' 7='7. OLDER CLIENTS' 8='8. CODEPENDS'
                  9='9. LOW INCOME' 10='10. MEN' 12='12. BLACKS'
                  13='13. GAYS/LESBIANS' 14='14. PARENT GRPS'
                  15='15. MINORITIES EXC BLACKS' 16='16. HANDICAP'
                  17='17. PREG WOMEN/TEENS' 18='18. OTR PROGS FOR WOMEN'
                  19='19. TEENS' 20='20. SPOUSE/SIG OTHR/CLOSE FAM'
                  21='21. ALCOHOL' 22='22. COCAINE' 23='23. HEROIN/OPIATES'
                  27='27. DUAL DIAGNOSIS' 28='28. SEVERE ADDICT CLNTS'
                  29='29. EARLY STAGE ADDICTION' 31='31. CHRONIC PAIN'
                  32='32. METH RECIPIENTS' 33='33. AIDS RELATED'
                  34='34. MENTAL HLTH PROBS' 35='35. DUI/DWI CLIENTS'
                  37='37. PERIPHERAL PROBS' 41='41. AFTERCARE' 97='97. OTHER' ;
  VALUE v8355fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8356fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INDIV.TH' 2='2. GROUP.TH'
                  3='3. FAMIL.TH' 8='8. CODEPEND' 9='9. THERAPY'
                  11='11. 12.STEP' 12='12. SUPPRTGP' 21='21. PREVENT'
                  22='22. EVALUATN' 23='23. AFTERCAR' 24='24. CASEMANG'
                  31='31. INPATINT' 32='32. OTHERMED' 41='41. SOCSERVS'
                  95='95. PROBAREA' 97='97. OTHPROGS' ;
  VALUE v8357fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INDIV.TH' 2='2. GROUP.TH'
                  3='3. FAMIL.TH' 8='8. CODEPEND' 9='9. THERAPY'
                  11='11. 12.STEP' 12='12. SUPPRTGP' 21='21. PREVENT'
                  22='22. EVALUATN' 23='23. AFTERCAR' 24='24. CASEMANG'
                  31='31. INPATINT' 32='32. OTHERMED' 41='41. SOCSERVS'
                  95='95. PROBAREA' 97='97. OTHPROGS' ;
  VALUE v8358fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INDIV.TH' 2='2. GROUP.TH'
                  3='3. FAMIL.TH' 8='8. CODEPEND' 9='9. THERAPY'
                  11='11. 12.STEP' 12='12. SUPPRTGP' 21='21. PREVENT'
                  22='22. EVALUATN' 23='23. AFTERCAR' 24='24. CASEMANG'
                  31='31. INPATINT' 32='32. OTHERMED' 41='41. SOCSERVS'
                  95='95. PROBAREA' 97='97. OTHPROGS' ;
  VALUE v8359fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. GEN PUBLIC'
                  2='2. SEG PUB DEAL DRUG PROBS' 3='3. ALL CLIENTS'
                  6='6. CHILDREN' 7='7. OLDER CLIENTS' 8='8. CODEPENDS'
                  9='9. LOW INCOME' 10='10. MEN' 12='12. BLACKS'
                  13='13. GAYS/LESBIANS' 14='14. PARENT GRPS'
                  15='15. MINORITIES EXC BLACKS' 16='16. HANDICAP'
                  17='17. PREG WOMEN/TEENS' 18='18. OTR PROGS FOR WOMEN'
                  19='19. TEENS' 20='20. SPOUSE/SIG OTHR/CLOSE FAM'
                  21='21. ALCOHOL' 22='22. COCAINE' 23='23. HEROIN/OPIATES'
                  27='27. DUAL DIAGNOSIS' 28='28. SEVERE ADDICT CLNTS'
                  29='29. EARLY STAGE ADDICTION' 31='31. CHRONIC PAIN'
                  32='32. METH RECIPIENTS' 33='33. AIDS RELATED'
                  34='34. MENTAL HLTH PROBS' 35='35. DUI/DWI CLIENTS'
                  37='37. PERIPHERAL PROBS' 41='41. AFTERCARE' 97='97. OTHER' ;
  VALUE v8360fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8361fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INDIV.TH' 2='2. GROUP.TH'
                  3='3. FAMIL.TH' 8='8. CODEPEND' 9='9. THERAPY'
                  11='11. 12.STEP' 12='12. SUPPRTGP' 21='21. PREVENT'
                  22='22. EVALUATN' 23='23. AFTERCAR' 24='24. CASEMANG'
                  31='31. INPATINT' 32='32. OTHERMED' 41='41. SOCSERVS'
                  95='95. PROBAREA' 97='97. OTHPROGS' ;
  VALUE v8362fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INDIV.TH' 2='2. GROUP.TH'
                  3='3. FAMIL.TH' 8='8. CODEPEND' 9='9. THERAPY'
                  11='11. 12.STEP' 12='12. SUPPRTGP' 21='21. PREVENT'
                  22='22. EVALUATN' 23='23. AFTERCAR' 24='24. CASEMANG'
                  31='31. INPATINT' 32='32. OTHERMED' 41='41. SOCSERVS'
                  95='95. PROBAREA' 97='97. OTHPROGS' ;
  VALUE v8363fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. INDIV.TH' 2='2. GROUP.TH'
                  3='3. FAMIL.TH' 8='8. CODEPEND' 9='9. THERAPY'
                  11='11. 12.STEP' 12='12. SUPPRTGP' 21='21. PREVENT'
                  22='22. EVALUATN' 23='23. AFTERCAR' 24='24. CASEMANG'
                  31='31. INPATINT' 32='32. OTHERMED' 41='41. SOCSERVS'
                  95='95. PROBAREA' 97='97. OTHPROGS' ;
  VALUE v8364fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8365fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v8366fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8367fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v8368fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8369fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v8370fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8371fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v8372fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8373fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1.Education/Prevention'
                  2='2. AIDS education/information'
                  3='3. Crisis intervention' 11='11. Evaluation/assessment'
                  12='12. Referral service' 13='13. Aftercare'
                  14='14. Rehabilitation' 21='21 Job/vocational services'
                  22='22. Educational assess/GED'
                  23='23. Family involvement/intervention'
                  31='31. Basic needs assistance' 32='32. Daycare'
                  33='33. Independent Living'
                  34='34. Parenting/childcare educ'
                  35='35. Exercise/nutrition info' 36='36. Treatment access'
                  37='37. Spiritual/religious counseling' 41='41. AA/NA'
                  42='42. Codepend trmt prgm'
                  43='43. Dual-diagnosis trmt prgm'
                  44='44. Gen MH counseling/therapy'
                  51='51. Med services/exams' 52='52. Detox'
                  53='53. Methadone' 54='54. Antabuse'
                  55='55. Naltrexone/Trexan' 56='56. Symmetrel'
                  57='57. Acupuncture' 59='59. Otr medication trmt'
                  61='61. AIDS (exc 02)/HIV testing' 62='62. DWI/DUI'
                  63='63. Alcohol' 64='64. Cocaine' 65='65. Eating disorders'
                  66='66. Multi-drug use'
                  67='67. Prisoners/court clients (exc 62)'
                  69='69. Otr drug/problem area' 70='70. Men'
                  71='71. Women (inc pregnancy probs)'
                  72='72. Adolescents/teens' 73='73. Elderly'
                  74='74. Minorities' 75='75. Gays/lesbians'
                  76='76. Veterans' 77='77. Low income/poor'
                  78='78. Handicapped' 79='79. Other target pop'
                  81='81. Inpatnt services' 82='82. Inpatnt alcohol trmt'
                  83='83. Inpatnt detox' 84='84. Inpatnt meth'
                  85='85. Inpatnt gen MH trmt' 89='89. Other inpatnt srvcs'
                  91='91. Therapy/counseling/treatment--NFS'
                  92='92. Individual therapy/counsel' 93='93. Group therapy'
                  94='94. Intensive (outpatient) pgm' 95='95. Partial hosp'
                  96='96. None' 97='97. Other' ;
  VALUE v8374fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8375fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 1 MO OR LESS' ;
  VALUE v8376fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8377fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8378fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. ONE OR LESS'
                  95='95. 95 OR MORE' ;
  VALUE v8379fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8380fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8381fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8382fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8383fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8384fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8385fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. SUPRTGRP' 2='2. SELFHELP'
                  3='3. INDTHRPY' 4='4. GRPTHRPY' 5='5. OUTPATNT'
                  6='6. INPATENT' 7='7. MEDICAL' 8='8. COUNSEL'
                  9='9. CONTLBEH' 10='10. ASSESMNT' 11='11. DRUGFREE'
                  12='12. FAMTHRPY' 13='13. MULTTRMT' 14='14. OUTPTDAY'
                  15='15. AFTRCARE' 16='16. AA/NA' 17='17. 12_STEP'
                  19='19. OTHTHRPY' 21='21. EDUCATON' 22='22. ENVIRMOD'
                  23='23. CHANGBEH' 24='24. THRPQUAL' 25='25. CLRESPBL'
                  31='31. REHABLTN' 41='41. CL_DEPNT' 42='42. SUB_DETR'
                  91='91. NOT AREA' 97='97. OTHER' ;
  VALUE v8386fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. SUPRTGRP' 2='2. SELFHELP'
                  3='3. INDTHRPY' 4='4. GRPTHRPY' 5='5. OUTPATNT'
                  6='6. INPATENT' 7='7. MEDICAL' 8='8. COUNSEL'
                  9='9. CONTLBEH' 10='10. ASSESMNT' 11='11. DRUGFREE'
                  12='12. FAMTHRPY' 13='13. MULTTRMT' 14='14. OUTPTDAY'
                  15='15. AFTRCARE' 16='16. AA/NA' 17='17. 12_STEP'
                  19='19. OTHTHRPY' 21='21. EDUCATON' 22='22. ENVIRMOD'
                  23='23. CHANGBEH' 24='24. THRPQUAL' 25='25. CLRESPBL'
                  31='31. REHABLTN' 41='41. CL_DEPNT' 42='42. SUB_DETR'
                  91='91. NOT AREA' 97='97. OTHER' ;
  VALUE v8387fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. SUPRTGRP' 2='2. SELFHELP'
                  3='3. INDTHRPY' 4='4. GRPTHRPY' 5='5. OUTPATNT'
                  6='6. INPATENT' 7='7. MEDICAL' 8='8. COUNSEL'
                  9='9. CONTLBEH' 10='10. ASSESMNT' 11='11. DRUGFREE'
                  12='12. FAMTHRPY' 13='13. MULTTRMT' 14='14. OUTPTDAY'
                  15='15. AFTRCARE' 16='16. AA/NA' 17='17. 12_STEP'
                  19='19. OTHTHRPY' 21='21. EDUCATON' 22='22. ENVIRMOD'
                  23='23. CHANGBEH' 24='24. THRPQUAL' 25='25. CLRESPBL'
                  31='31. REHABLTN' 41='41. CL_DEPNT' 42='42. SUB_DETR'
                  91='91. NOT AREA' 97='97. OTHER' ;
  VALUE v8388fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. ABSTAIN' 2='2. LENGTHAB'
                  3='3. LESSDOSAGE' 11='11. TRMTPLAN' 12='12. STAFEVAL'
                  13='13. LEGAL' 14='14. FOLLOWUP' 21='21. SLFREPRT'
                  30='30. LESSQUALIFE' 31='31. EMPLOYMT' 32='32. RELATONS'
                  33='33. AVOIDNEG' 34='34. SELFHELP' 35='35. MOREPHEALT'
                  97='97. OTHER' ;
  VALUE v8389fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. ABSTAIN' 2='2. LENGTHAB'
                  3='3. LESSDOSAGE' 11='11. TRMTPLAN' 12='12. STAFEVAL'
                  13='13. LEGAL' 14='14. FOLLOWUP' 21='21. SLFREPRT'
                  30='30. LESSQUALIFE' 31='31. EMPLOYMT' 32='32. RELATONS'
                  33='33. AVOIDNEG' 34='34. SELFHELP' 35='35. MOREPHEALT'
                  97='97. OTHER' ;
  VALUE v8390fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. ABSTAIN' 2='2. LENGTHAB'
                  3='3. LESSDOSAGE' 11='11. TRMTPLAN' 12='12. STAFEVAL'
                  13='13. LEGAL' 14='14. FOLLOWUP' 21='21. SLFREPRT'
                  30='30. LESSQUALIFE' 31='31. EMPLOYMT' 32='32. RELATONS'
                  33='33. AVOIDNEG' 34='34. SELFHELP' 35='35. MOREPHEALT'
                  97='97. OTHER' ;
  VALUE v8391fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. ABSTAIN' 2='2. LENGTHAB'
                  3='3. LESSDOSAGE' 11='11. TRMTPLAN' 12='12. STAFEVAL'
                  13='13. LEGAL' 14='14. FOLLOWUP' 21='21. SLFREPRT'
                  30='30. LESSQUALIFE' 31='31. EMPLOYMT' 32='32. RELATONS'
                  33='33. AVOIDNEG' 34='34. SELFHELP' 35='35. MOREPHEALT'
                  97='97. OTHER' ;
  VALUE v8392fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. ABSTAIN' 2='2. LENGTHAB'
                  3='3. LESSDOSAGE' 11='11. TRMTPLAN' 12='12. STAFEVAL'
                  13='13. LEGAL' 14='14. FOLLOWUP' 21='21. SLFREPRT'
                  30='30. LESSQUALIFE' 31='31. EMPLOYMT' 32='32. RELATONS'
                  33='33. AVOIDNEG' 34='34. SELFHELP' 35='35. MOREPHEALT'
                  97='97. OTHER' ;
  VALUE v8393fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8394fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NOT AT ALL IMPORTANT'
                  2='2. LITTLE IMPORTANT' 3='3. SOMEWT IMPORTANT'
                  4='4. VERY IMPORTANT' 5='5. EXTREMELY IMPORTANT' ;
  VALUE v8395fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NOT AT ALL IMPORTANT'
                  2='2. LITTLE IMPORTANT' 3='3. SOMEWT IMPORTANT'
                  4='4. VERY IMPORTANT' 5='5. EXTREMELY IMPORTANT' ;
  VALUE v8396fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NOT AT ALL IMPORTANT'
                  2='2. LITTLE IMPORTANT' 3='3. SOMEWT IMPORTANT'
                  4='4. VERY IMPORTANT' 5='5. EXTREMELY IMPORTANT' ;
  VALUE v8397fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NOT AT ALL IMPORTANT'
                  2='2. LITTLE IMPORTANT' 3='3. SOMEWT IMPORTANT'
                  4='4. VERY IMPORTANT' 5='5. EXTREMELY IMPORTANT' ;
  VALUE v8398fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8399fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8400fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8401fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8402fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8403fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8404fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8405fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8406fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8407fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8408fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8409fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8410fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8411fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8412fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8413fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8414fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8415fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8416fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8417fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MONITOR' 2='2. MEDRECRD'
                  3='3. PSYCHIAT' 4='4. POLICE/CRT REC' 5='5. STAFEVAL'
                  6='6. PEER' 7='7. CL BEHVR' 11='11. VISITS'
                  12='12. TESTING' 13='13. SCHL.REP' 14='14. AA/NA'
                  15='15. INFORMAL' 16='16. AGENCIES' 51='51. RECRDAPP'
                  97='97. OTHER' ;
  VALUE v8418fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8419fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MONITOR' 2='2. MEDRECRD'
                  3='3. PSYCHIAT' 4='4. POLICE/CRT REC' 5='5. STAFEVAL'
                  6='6. PEER' 7='7. CL BEHVR' 11='11. VISITS'
                  12='12. TESTING' 13='13. SCHL.REP' 14='14. AA/NA'
                  15='15. INFORMAL' 16='16. AGENCIES' 51='51. RECRDAPP'
                  97='97. OTHER' ;
  VALUE v8420fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8421fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MONITOR' 2='2. MEDRECRD'
                  3='3. PSYCHIAT' 4='4. POLICE/CRT REC' 5='5. STAFEVAL'
                  6='6. PEER' 7='7. CL BEHVR' 11='11. VISITS'
                  12='12. TESTING' 13='13. SCHL.REP' 14='14. AA/NA'
                  15='15. INFORMAL' 16='16. AGENCIES' 51='51. RECRDAPP'
                  97='97. OTHER' ;
  VALUE v8422fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8423fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8424fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8425fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8426fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8427fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NONE' 1='1. KEEPAPPT'
                  2='2. PARTINTH' 3='3. PARTGRTH' 4='4. FAMINVOL'
                  5='5. DO.ASSN' 61='61. MEET.REQ' 62='62. LABRESUL'
                  63='63. SOBERSM' 71='71. PROGRESS' 81='81. APP.BEH'
                  82='82. COOPERAT' 83='83. EMPLOYMT' 84='84. PAY.FEES'
                  97='97. OTHER' ;
  VALUE v8428fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8429fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NONE' 1='1. KEEPAPPT'
                  2='2. PARTINTH' 3='3. PARTGRTH' 4='4. FAMINVOL'
                  5='5. DO.ASSN' 61='61. MEET.REQ' 62='62. LABRESUL'
                  63='63. SOBERSM' 71='71. PROGRESS' 81='81. APP.BEH'
                  82='82. COOPERAT' 83='83. EMPLOYMT' 84='84. PAY.FEES'
                  97='97. OTHER' ;
  VALUE v8430fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8431fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NONE' 1='1. KEEPAPPT'
                  2='2. PARTINTH' 3='3. PARTGRTH' 4='4. FAMINVOL'
                  5='5. DO.ASSN' 61='61. MEET.REQ' 62='62. LABRESUL'
                  63='63. SOBERSM' 71='71. PROGRESS' 81='81. APP.BEH'
                  82='82. COOPERAT' 83='83. EMPLOYMT' 84='84. PAY.FEES'
                  97='97. OTHER' ;
  VALUE v8432fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8433fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8434fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8435fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8436fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8437fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8438fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8439fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8440fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8441fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8442fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8443fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8444fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8445fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8446fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8447fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8448fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8449fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8450fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8451fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NONE' 4='4. MOVEAWAY'
                  11='11. ASKED2GO' 21='21. INCAR.IN' 22='22. DIED'
                  97='97. OTHER' ;
  VALUE v8452fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8453fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NONE' 4='4. MOVEAWAY'
                  11='11. ASKED2GO' 21='21. INCAR.IN' 22='22. DIED'
                  97='97. OTHER' ;
  VALUE v8454fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8455fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. NONE' 4='4. MOVEAWAY'
                  11='11. ASKED2GO' 21='21. INCAR.IN' 22='22. DIED'
                  97='97. OTHER' ;
  VALUE v8456fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8457fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8458fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8459fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8460fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8461fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8462fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8463fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8464fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT' 2='2. FORGE CHECK'
                  3='3. FORGE RX' 4='4. CON GAME' 5='5. SELL DRUGS'
                  6='6. SELL OTHER ILLEG' 7='7. MURDER/ASSAULT/CH ABUSE'
                  8='8. OTHER FELONY' 9='9. DRUG POSSESS'
                  10='10. PROBATN/PAROLE VIOL'
                  11='11. CRIM SEX CONDUCT/PROSTIT' 97='97. OTHER' ;
  VALUE v8465fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8466fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT' 2='2. FORGE CHECK'
                  3='3. FORGE RX' 4='4. CON GAME' 5='5. SELL DRUGS'
                  6='6. SELL OTHER ILLEG' 7='7. MURDER/ASSAULT/CH ABUSE'
                  8='8. OTHER FELONY' 9='9. DRUG POSSESS'
                  10='10. PROBATN/PAROLE VIOL'
                  11='11. CRIM SEX CONDUCT/PROSTIT' 97='97. OTHER' ;
  VALUE v8467fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8468fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. THEFT' 2='2. FORGE CHECK'
                  3='3. FORGE RX' 4='4. CON GAME' 5='5. SELL DRUGS'
                  6='6. SELL OTHER ILLEG' 7='7. MURDER/ASSAULT/CH ABUSE'
                  8='8. OTHER FELONY' 9='9. DRUG POSSESS'
                  10='10. PROBATN/PAROLE VIOL'
                  11='11. CRIM SEX CONDUCT/PROSTIT' 97='97. OTHER' ;
  VALUE v8469fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8470fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8471fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8472fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8473fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8474fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8475fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. ALL OTRS'
                  1='1. G1=100% (ALL CRT ORDRD)' ;
  VALUE v8476fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MUCH MORE'
                  2='2. SOMEWHAT MORE' 3='3. ABOUT SAME' 4='4. SOMEWHAT LESS'
                  5='5. MUCH LESS' ;
  VALUE v8477fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MUCH MORE'
                  2='2. SOMEWHAT MORE' 3='3. ABOUT SAME' 4='4. SOMEWHAT LESS'
                  5='5. MUCH LESS' ;
  VALUE v8478fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MUCH MORE'
                  2='2. SOMEWHAT MORE' 3='3. ABOUT SAME' 4='4. SOMEWHAT LESS'
                  5='5. MUCH LESS' ;
  VALUE v8479fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MUCH MORE'
                  2='2. SOMEWHAT MORE' 3='3. ABOUT SAME' 4='4. SOMEWHAT LESS'
                  5='5. MUCH LESS' ;
  VALUE v8480fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MUCH MORE'
                  2='2. SOMEWHAT MORE' 3='3. ABOUT SAME' 4='4. SOMEWHAT LESS'
                  5='5. MUCH LESS' ;
  VALUE v8481fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MUCH MORE'
                  2='2. SOMEWHAT MORE' 3='3. ABOUT SAME' 4='4. SOMEWHAT LESS'
                  5='5. MUCH LESS' ;
  VALUE v8482fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MUCH MORE'
                  2='2. SOMEWHAT MORE' 3='3. ABOUT SAME' 4='4. SOMEWHAT LESS'
                  5='5. MUCH LESS' ;
  VALUE v8483fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. MUCH MORE'
                  2='2. SOMEWHAT MORE' 3='3. ABOUT SAME' 4='4. SOMEWHAT LESS'
                  5='5. MUCH LESS' ;
  VALUE v8484fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8485fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8486fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8487fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8488fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8489fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8490fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. STRONGLY AGREE'
                  2='2. SOMEWHAT AGREE' 3='3. NEITHER'
                  4='4. SOMEWHAT DISAGREE' 5='5. STRONGLY DISAGREE'
                  6='6. DOES NOT APPLY' ;
  VALUE v8491fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NO EXTENT'
                  2='2. A LITTLE EXTENT' 3='3. SOME EXTENT'
                  4='4. A GREAT EXTENT' 5='5. A VERY GREAT EXTENT'
                  6='6. NOT DONE AT ALL' ;
  VALUE v8492fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NO EXTENT'
                  2='2. A LITTLE EXTENT' 3='3. SOME EXTENT'
                  4='4. A GREAT EXTENT' 5='5. A VERY GREAT EXTENT'
                  6='6. NOT DONE AT ALL' ;
  VALUE v8493fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NO EXTENT'
                  2='2. A LITTLE EXTENT' 3='3. SOME EXTENT'
                  4='4. A GREAT EXTENT' 5='5. A VERY GREAT EXTENT'
                  6='6. NOT DONE AT ALL' ;
  VALUE v8494fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NO EXTENT'
                  2='2. A LITTLE EXTENT' 3='3. SOME EXTENT'
                  4='4. A GREAT EXTENT' 5='5. A VERY GREAT EXTENT'
                  6='6. NOT DONE AT ALL' ;
  VALUE v8495fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NO EXTENT'
                  2='2. A LITTLE EXTENT' 3='3. SOME EXTENT'
                  4='4. A GREAT EXTENT' 5='5. A VERY GREAT EXTENT'
                  6='6. NOT DONE AT ALL' ;
  VALUE v8496fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NO EXTENT'
                  2='2. A LITTLE EXTENT' 3='3. SOME EXTENT'
                  4='4. A GREAT EXTENT' 5='5. A VERY GREAT EXTENT'
                  6='6. NOT DONE AT ALL' ;
  VALUE v8497fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NO EXTENT'
                  2='2. A LITTLE EXTENT' 3='3. SOME EXTENT'
                  4='4. A GREAT EXTENT' 5='5. A VERY GREAT EXTENT'
                  6='6. NOT DONE AT ALL' ;
  VALUE v8498fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NO EXTENT'
                  2='2. A LITTLE EXTENT' 3='3. SOME EXTENT'
                  4='4. A GREAT EXTENT' 5='5. A VERY GREAT EXTENT'
                  6='6. NOT DONE AT ALL' ;
  VALUE v8499fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. NO EXTENT'
                  2='2. A LITTLE EXTENT' 3='3. SOME EXTENT'
                  4='4. A GREAT EXTENT' 5='5. A VERY GREAT EXTENT'
                  6='6. NOT DONE AT ALL' ;
  VALUE v8500fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8501fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8502fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8503fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8504fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8505fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. No extent'
                  2='2. A little extent' 3='3. Some extent'
                  4='4. A great extent' 5='5. A very great extent' ;
  VALUE v8506fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HELP LOT' 2='2. HELP SOME'
                  3='3. NEITHER HELP/HINDER' 4='4. HINDER SOME'
                  5='5. HINDER LOT' ;
  VALUE v8507fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HELP LOT' 2='2. HELP SOME'
                  3='3. NEITHER HELP/HINDER' 4='4. HINDER SOME'
                  5='5. HINDER LOT' ;
  VALUE v8508fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HELP LOT' 2='2. HELP SOME'
                  3='3. NEITHER HELP/HINDER' 4='4. HINDER SOME'
                  5='5. HINDER LOT' ;
  VALUE v8509fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HELP LOT' 2='2. HELP SOME'
                  3='3. NEITHER HELP/HINDER' 4='4. HINDER SOME'
                  5='5. HINDER LOT' ;
  VALUE v8510fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HELP LOT' 2='2. HELP SOME'
                  3='3. NEITHER HELP/HINDER' 4='4. HINDER SOME'
                  5='5. HINDER LOT' ;
  VALUE v8511fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HELP LOT' 2='2. HELP SOME'
                  3='3. NEITHER HELP/HINDER' 4='4. HINDER SOME'
                  5='5. HINDER LOT' ;
  VALUE v8512fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HELP LOT' 2='2. HELP SOME'
                  3='3. NEITHER HELP/HINDER' 4='4. HINDER SOME'
                  5='5. HINDER LOT' ;
  VALUE v8513fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HELP LOT' 2='2. HELP SOME'
                  3='3. NEITHER HELP/HINDER' 4='4. HINDER SOME'
                  5='5. HINDER LOT' ;
  VALUE v8514fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HELP LOT' 2='2. HELP SOME'
                  3='3. NEITHER HELP/HINDER' 4='4. HINDER SOME'
                  5='5. HINDER LOT' ;
  VALUE v8515fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HELP LOT' 2='2. HELP SOME'
                  3='3. NEITHER HELP/HINDER' 4='4. HINDER SOME'
                  5='5. HINDER LOT' ;
  VALUE v8516fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. HELP LOT' 2='2. HELP SOME'
                  3='3. NEITHER HELP/HINDER' 4='4. HINDER SOME'
                  5='5. HINDER LOT' ;
  VALUE v8517fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. ALL OTHER'
                  1='1. DEM IN DIR' ;
  VALUE v8518fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8519fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8520fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8521fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8522fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. DIRECTOR' 2='2. DEPUTY'
                  3='3. CONTROLL' 4='4. ADMIUNSP' 5='5. ADMASST'
                  6='6. OFFMANA' 7='7. SECTARY' 9='9. PUBRELAT'
                  10='10. LEGALSER' 19='19. OTHRADM' 21='21. ANYHEAD'
                  22='22. ASSTGEAD' 23='23. SUPERVISOR' 31='31. PROBOFFC'
                  32='32. COUNSELR' 34='34. CLERGY' 38='38. ADVISOR'
                  41='41. PHYSICN' 42='42. NURSE' 43='43. OTHHCP'
                  44='44. PSYCHOL' 45='45. SOCWORK' 71='71. VOLUNTR'
                  72='72. STUDENT' 73='73. PUBOFFIC' 74='74. TEACHER'
                  97='97. OTHER' ;
  VALUE v8523fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8524fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8525fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. 29 YEARS OLD OR YOUNGER'
                  2='2. 30-34 YEARS OLD' 3='3. 35-39 YEARS OLD'
                  4='4. 40-44 YEARS OLD' 5='5. 45-49 YEARS OLD'
                  6='6. 50-54 YEARS OLD' 7='7. 55-59 YEARS OLD'
                  8='8. 60 YEARS OLD OR OLDER' ;
  VALUE v8526fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. Female' 1='1. Male' ;
  VALUE v8527fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. WHITE' 2='2. BLACK'
                  5='5. OTHER' ;
  VALUE v8528fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8529fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8530fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8531fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8532fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' ;
  VALUE v8533fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8534fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
  VALUE v8535fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v8536fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v8537fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v8538fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v8539fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v8540fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v8541fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. A.A.2YR' 2='2. R.N.'
                  3='3. BA/BS' 4='4. MA/MS' 5='5. MD' 6='6. PH.D.'
                  7='7. OTHER' ;
  VALUE v8542fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 1='1. BIOLOGY' 2='2. BUSINESS'
                  3='3. CHEMISTR' 4='4. COUNSEL' 5='5. COMM SCI'
                  6='6. CRIMJUST' 7='7. DIETETIC' 8='8. ECONOMIC'
                  9='9. EDUCATON' 10='10. ED ADMIN' 11='11. PHYS ED'
                  12='12. SPECL ED' 13='13. Engineering--any type'
                  15='15. ENG LANG' 16='16. HISTORY' 17='17. HUMANSRV'
                  18='18. LANGUAGE' 19='19. LAW' 20='20. LIB ARTS'
                  21='21. MED DOC' 22='22. PERSONEL' 23='23. PHARMACY'
                  24='24. PHILOPHY' 25='25. PSYCHIAT' 26='26. PSYCHLGY'
                  27='27. PUB ADMN' 28='28. PUB HLTH' 30='30. SCIENCE'
                  31='31. SOCPSYCH' 32='32. SOCL SCI' 33='33. SOC WORK'
                  34='34. SOCIOLGY' 35='35. THEOLOGY' 36='36. SUBABUSE'
                  41='41. ARTS' 42='42. NURSING' 43='43. 3VOCREHA'
                  51='51. GENPRACT' 52='52. PEDIATRC' 53='53. INTRNMED'
                  57='57. OTHR MED' 97='97. OTHER' ;
  VALUE v8543fff  -5='-5. NO INTERVIEW' -4='-4. PARTIAL INTERVIEW'
                  -3='-3. REFUSED/NA' -2='-2. DONT KNOW'
                  -1='-1. SKIPPED QUESTION' 0='0. No' 1='1. Yes' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=3412;
INPUT
        CASEID 1-3              UNITID 4-8              V7004 9-13
        V7005 14-16             V7006 17-19             V7007 20-22
        V7008 23-25             V7009 26-28             V7010 29-31
        V7011 32-35             V7012 36-38             V7013 39-41
        V7014 42-43             V7015 44-45             V7016 46-48
        V7017 49-51             V7018 52-53             V7019 54-55
        V7020 56-57             V7021 58-59             V7022 60-61
        V7023 62-63             V7024 64-65             V7025 66-67
        V7026 68-69             V7027 70-71             V7028 72-73
        V7029 74-76             V7030 77-79             V7031 80-82
        V7032 83-85             V7033 86-89             V7034 90-93
        V7035 94-95             V7036 96-98             V7037 99-101
        V7038 102-104           V7039 105-107           V7040 108-110
        V7041 111-113           V7042 114-121           V7043 122-129
        V7044 130-137           V7045 138-140           V7046 141-143
        V7047 144-146           V7048 147-149           V7049 150-152
        V7050 153-155           V7051 156-163           V7052 164-171
        V7053 172-179           V7054 180-186           V7055 187-188
        V7056 189-195           V7057 196-198           V7058 199-200
        V7059 201-206           V7060 207-209           V7061 210-211
        V7062 212-218           V7063 219-221           V7064 222-223
        V7065 224-226           V7066 227-233           V7067 234-236
        V7068 237-238           V7069 239-241           V7070 242-248
        V7071 249-251           V7072 252-253           V7073 254-255
        V7074 256-257           V7075 258-259           V7076 260-267
        V7077 268-271           V7078 272-273           V7079 274-281
        V7080 282-284           V7081 285-286           V7082 287-294
        V7083 295-297           V7084 298-299           V7085 300-306
        V7086 307-309           V7087 310-311           V7088 312-314
        V7089 315-322           V7090 323-325           V7091 326-327
        V7092 328-330           V7093 331-337           V7094 338-340
        V7095 341-342           V7096 343-345           V7097 346-352
        V7098 353-355           V7099 356-363           V7100 364-365
        V7101 366-372           V7102 373-375           V7103 376-377
        V7104 378-380           V7105 381-388           V7106 389-391
        V7107 392-393           V7108 394-396           V7109 397-403
        V7110 404-406           V7111 407-408           V7112 409-411
        V7113 412-419           V7114 420-422           V7115 423-424
        V7116 425-427           V7117 428-433           V7118 434-436
        V7119 437-438           V7120 439-441           V7121 442-449
        V7122 450-452           V7123 453-460           V7124 461-462
        V7125 463-470           V7126 471-473           V7127 474-475
        V7128 476-483           V7129 484-486           V7130 487-488
        V7131 489-496           V7132 497-499           V7133 500-501
        V7134 502-508           V7135 509-511           V7136 512-513
        V7137 514-516           V7138 517-523           V7139 524-526
        V7140 527-528           V7141 529-531           V7142 532-538
        V7143 539-541           V7144 542-543           V7145 544-550
        V7146 551-552           V7147 553-555           V7148 556-562
        V7149 563-564           V7150 565-567           V7151 568-573
        V7152 574-575           V7153 576-578           V7154 579-584
        V7155 585-586           V7156 587-589           V7157 590-593
        V7158 594-595           V7159 596-597           V7160 598-599
        V7161 600-601           V7162 602-609           V7163 610-611
        V7164 612-613           V7165 614-617           V7166 618-620
        V7167 621-624           V7168 625-628           V7169 629-632
        V7170 633-636           V7171 637-640           V7172 641-643
        V7173 644-647           V7174 648-651           V7175 652-655
        V7176 656-659           V7177 660-662           V7178 663-666
        V7179 667-670           V7180 671-674           V7181 675-678
        V7182 679-682           V7183 683-686           V7184 687-690
        V7185 691-694           V7186 695-698           V7187 699-702
        V7188 703-706           V7189 707-710           V7190 711-713
        V7191 714-715           V7192 716-722           V7193 723-729
        V7194 730-731           V7195 732-733           V7196 734-738
        V7197 739-743           V7198 744-745           V7199 746-750
        V7200 751-755           V7201 756-760           V7202 761-765
        V7203 766-767           V7204 768-772           V7205 773-777
        V7206 778-781           V7207 782-786           V7208 787-790
        V7209 791-794           V7210 795-797           V7211 798-801
        V7212 802-804           V7213 805-808           V7214 809-811
        V7215 812-815           V7216 816-818           V7217 819-821
        V7218 822-827 .2        V7219 828-831           V7220 832-833
        V7221 834-837           V7222 838-841           V7223 842-845
        V7224 846-849           V7225 850-853           V7226 854-856
        V7227 857-858           V7228 859-861           V7229 862-865
        V7230 866-869           V7231 870-872           V7232 873-876
        V7233 877-879           V7234 880-883           V7235 884-886
        V7236 887-889           V7237 890-895 .2        V7238 896-899
        V7239 900-901           V7240 902-905           V7241 906-909
        V7242 910-913           V7243 914-917           V7244 918-921
        V7245 922-924           V7246 925-926           V7247 927-929
        V7248 930-933           V7249 934-937           V7250 938-940
        V7251 941-944           V7252 945-947           V7253 948-951
        V7254 952-954           V7255 955-957           V7256 958-963 .2
        V7257 964-967           V7258 968-969           V7259 970-971
        V7260 972-976           V7261 977-982           V7262 983-986
        V7263 987-988           V7264 989-990           V7265 991-995
        V7266 996-997           V7267 998-999           V7268 1000-1001
        V7269 1002-1003         V7270 1004-1005         V7271 1006-1007
        V7272 1008-1009         V7273 1010-1011         V7274 1012-1013
        V7275 1014-1015         V7276 1016-1017         V7277 1018-1019
        V7278 1020-1021         V7279 1022-1023         V7280 1024-1025
        V7281 1026-1027         V7282 1028-1029         V7283 1030-1031
        V7284 1032-1033         V7285 1034-1035         V7286 1036-1037
        V7287 1038-1039         V7288 1040-1041         V7289 1042-1043
        V7290 1044-1045         V7291 1046-1047         V7292 1048-1050
        V7293 1051-1053         V7294 1054-1055         V7295 1056-1058
        V7296 1059-1061         V7297 1062-1063         V7298 1064-1066
        V7299 1067-1069         V7300 1070-1071         V7301 1072-1074
        V7302 1075-1077         V7303 1078-1079         V7304 1080-1081
        V7305 1082-1084         V7306 1085-1087         V7307 1088-1090
        V7308 1091-1093         V7309 1094-1095         V7310 1096-1097
        V7311 1098-1099         V7312 1100-1101         V7313 1102-1103
        V7314 1104-1105         V7315 1106-1107         V7316 1108-1109
        V7317 1110-1111         V7318 1112-1113         V7319 1114-1115
        V7320 1116-1117         V7321 1118-1119         V7322 1120-1121
        V7323 1122-1124         V7324 1125-1126         V7325 1127-1128
        V7326 1129-1130         V7327 1131-1132         V7328 1133-1134
        V7329 1135-1136         V7330 1137-1138         V7331 1139-1140
        V7332 1141-1142         V7333 1143-1144         V7334 1145-1146
        V7335 1147-1148         V7336 1149-1150         V7337 1151-1152
        V7338 1153-1154         V7339 1155-1156         V7340 1157-1158
        V7341 1159-1160         V7342 1161-1162         V7343 1163-1165
        V7344 1166-1167         V7345 1168-1169         V7346 1170-1171
        V7347 1172-1173         V7348 1174-1175         V7349 1176-1178
        V7350 1179-1180         V7351 1181-1182         V7352 1183-1184
        V7353 1185-1186         V7354 1187-1188         V7355 1189-1191
        V7356 1192-1193         V7357 1194-1195         V7358 1196-1197
        V7359 1198-1199         V7360 1200-1201         V7361 1202-1203
        V7362 1204-1205         V7363 1206-1207         V7364 1208-1209
        V7365 1210-1212         V7366 1213-1214         V7367 1215-1216
        V7368 1217-1218         V7369 1219-1220         V7370 1221-1223
        V7371 1224-1225         V7372 1226-1227         V7373 1228-1229
        V7374 1230-1231         V7375 1232-1234         V7376 1235-1236
        V7377 1237-1238         V7378 1239-1240         V7379 1241-1242
        V7380 1243-1244         V7381 1245-1246         V7382 1247-1248
        V7383 1249-1250         V7384 1251-1252         V7385 1253-1255
        V7386 1256-1257         V7387 1258-1259         V7388 1260-1261
        V7389 1262-1263         V7390 1264-1265         V7391 1266-1268
        V7392 1269-1270         V7393 1271-1272         V7394 1273-1274
        V7395 1275-1276         V7396 1277-1278         V7397 1279-1281
        V7398 1282-1283         V7399 1284-1285         V7400 1286-1287
        V7401 1288-1289         V7402 1290-1291         V7403 1292-1293
        V7404 1294-1295         V7405 1296-1297         V7406 1298-1299
        V7407 1300-1302         V7408 1303-1304         V7409 1305-1306
        V7410 1307-1308         V7411 1309-1310         V7412 1311-1313
        V7413 1314-1315         V7414 1316-1317         V7415 1318-1319
        V7416 1320-1321         V7417 1322-1324         V7418 1325-1326
        V7419 1327-1328         V7420 1329-1330         V7421 1331-1332
        V7422 1333-1334         V7423 1335-1336         V7424 1337-1338
        V7425 1339-1340         V7426 1341-1342         V7427 1343-1345
        V7428 1346-1347         V7429 1348-1349         V7430 1350-1351
        V7431 1352-1353         V7432 1354-1355         V7433 1356-1358
        V7434 1359-1360         V7435 1361-1362         V7436 1363-1364
        V7437 1365-1366         V7438 1367-1368         V7439 1369-1371
        V7440 1372-1373         V7441 1374-1375         V7442 1376-1377
        V7443 1378-1379         V7444 1380-1381         V7445 1382-1383
        V7446 1384-1385         V7447 1386-1387         V7448 1388-1389
        V7449 1390-1392         V7450 1393-1394         V7451 1395-1396
        V7452 1397-1398         V7453 1399-1400         V7454 1401-1403
        V7455 1404-1405         V7456 1406-1407         V7457 1408-1409
        V7458 1410-1411         V7459 1412-1414         V7460 1415-1416
        V7461 1417-1418         V7462 1419-1420         V7463 1421-1422
        V7464 1423-1424         V7465 1425-1426         V7466 1427-1428
        V7467 1429-1430         V7468 1431-1432         V7469 1433-1434
        V7470 1435-1436         V7471 1437-1438         V7472 1439-1440
        V7473 1441-1442         V7474 1443-1444         V7475 1445-1446
        V7476 1447-1448         V7477 1449-1450         V7478 1451-1452
        V7479 1453-1454         V7480 1455-1456         V7481 1457-1458
        V7482 1459-1460         V7483 1461-1462         V7484 1463-1464
        V7485 1465-1466         V7486 1467-1468         V7487 1469-1470
        V7488 1471-1472         V7489 1473-1474         V7490 1475-1476
        V7491 1477-1478         V7492 1479-1480         V7493 1481-1482
        V7494 1483-1484         V7495 1485-1487         V7496 1488-1490
        V7497 1491-1493         V7498 1494-1496         V7499 1497-1499
        V7500 1500-1502         V7501 1503-1505         V7502 1506-1508
        V7503 1509-1511         V7504 1512-1514         V7505 1515-1517
        V7506 1518-1519         V7507 1520-1521         V7508 1522-1523
        V7509 1524-1525         V7510 1526-1527         V7511 1528-1529
        V7512 1530-1531         V7513 1532-1533         V7514 1534-1536
        V7515 1537-1539         V7516 1540-1541         V7517 1542-1543
        V7518 1544-1545         V7519 1546-1547         V7520 1548-1549
        V7521 1550-1551         V7522 1552-1553         V7523 1554-1555
        V7524 1556-1557         V7525 1558-1559         V7526 1560-1561
        V7527 1562-1563         V7528 1564-1565         V7529 1566-1567
        V7530 1568-1569         V7531 1570-1571         V7532 1572-1573
        V7533 1574-1575         V7534 1576-1577         V7535 1578-1579
        V7536 1580-1581         V7537 1582-1583         V7538 1584-1585
        V7539 1586-1588         V7540 1589-1591         V7541 1592-1594
        V7542 1595-1597         V7543 1598-1599         V7544 1600-1602
        V7545 1603-1605         V7546 1606-1608         V7547 1609-1611
        V7548 1612-1613         V7549 1614-1616         V7550 1617-1619
        V7551 1620-1622         V7552 1623-1625         V7553 1626-1627
        V7554 1628-1630         V7555 1631-1633         V7556 1634-1636
        V7557 1637-1639         V7558 1640-1642         V7559 1643-1645
        V7560 1646-1648         V7561 1649-1651         V7562 1652-1654
        V7563 1655-1657         V7564 1658-1660         V7565 1661-1663
        V7566 1664-1666         V7567 1667-1669         V7568 1670-1672
        V7569 1673-1675         V7570 1676-1677         V7571 1678-1680
        V7572 1681-1683         V7573 1684-1685         V7574 1686-1687
        V7575 1688-1690         V7576 1691-1693         V7577 1694-1695
        V7578 1696-1697         V7579 1698-1699         V7580 1700-1703
        V7581 1704-1706         V7582 1707-1708         V7583 1709-1710
        V7584 1711-1712         V7585 1713-1714         V7586 1715-1716
        V7587 1717-1718         V7588 1719-1720         V7589 1721-1722
        V7590 1723-1724         V7591 1725-1726         V7592 1727-1728
        V7593 1729-1730         V7594 1731-1732         V7595 1733-1734
        V7596 1735-1736         V7597 1737-1738         V7598 1739-1740
        V7599 1741-1742         V7600 1743-1745         V7601 1746-1748
        V7602 1749-1751         V7603 1752-1753         V7604 1754-1755
        V7605 1756-1757         V7606 1758-1760         V7607 1761-1763
        V7608 1764-1766         V7609 1767-1768         V7610 1769-1770
        V7611 1771-1772         V7612 1773-1774         V7613 1775-1776
        V7614 1777-1778         V7615 1779-1780         V7616 1781-1782
        V7617 1783-1784         V7618 1785-1786         V7619 1787-1788
        V7620 1789-1790         V7621 1791-1792         V7622 1793-1794
        V7623 1795-1796         V7624 1797-1798         V7625 1799-1800
        V7626 1801-1802         V7627 1803-1804         V7628 1805-1806
        V7629 1807-1808         V7630 1809-1810         V7631 1811-1815
        V7632 1816-1817         V7633 1818-1819         V7634 1820-1821
        V7635 1822-1823         V7636 1824-1825         V7637 1826-1827
        V7638 1828-1829         V7639 1830-1831         V7640 1832-1833
        V7641 1834-1835         V7642 1836-1837         V7643 1838-1839
        V7644 1840-1842         V7645 1843-1845         V7646 1846-1848
        V7647 1849-1851         V7648 1852-1854         V7649 1855-1857
        V7650 1858-1860         V7651 1861-1863         V7652 1864-1865
        V7653 1866-1867         V7654 1868-1869         V7655 1870-1872
        V7656 1873-1875         V7657 1876-1878         V7658 1879-1881
        V7659 1882-1883         V7660 1884-1885         V7661 1886-1887
        V7662 1888-1890         V7663 1891-1892         V7664 1893-1895
        V7665 1896-1897         V7666 1898-1900         V7667 1901-1902
        V7668 1903-1905         V7669 1906-1907         V8004 1908-1912
        V8005 1913-1915         V8006 1916-1918         V8007 1919-1921
        V8008 1922-1924         V8009 1925-1927         V8010 1928-1930
        V8011 1931-1934         V8012 1935-1936         V8013 1937-1938
        V8014 1939-1940         V8015 1941-1942         V8016 1943-1944
        V8017 1945-1946         V8018 1947-1948         V8019 1949-1950
        V8020 1951-1953         V8021 1954-1955         V8022 1956-1958
        V8023 1959-1960         V8024 1961-1963         V8025 1964-1965
        V8026 1966-1968         V8027 1969-1970         V8028 1971-1973
        V8029 1974-1975         V8030 1976-1978         V8031 1979-1981
        V8032 1982-1984         V8033 1985-1986         V8034 1987-1988
        V8035 1989-1990         V8036 1991-1992         V8037 1993-1994
        V8038 1995-1996         V8039 1997-1998         V8040 1999-2001
        V8041 2002-2003         V8042 2004-2006         V8043 2007-2008
        V8044 2009-2011         V8045 2012-2013         V8046 2014-2016
        V8047 2017-2018         V8048 2019-2021         V8049 2022-2023
        V8050 2024-2026         V8051 2027-2029         V8052 2030-2032
        V8053 2033-2034         V8054 2035-2036         V8055 2037-2038
        V8056 2039-2040         V8057 2041-2043         V8058 2044-2045
        V8059 2046-2048         V8060 2049-2050         V8061 2051-2053
        V8062 2054-2055         V8063 2056-2057         V8064 2058-2059
        V8065 2060-2061         V8066 2062-2063         V8067 2064-2067
        V8068 2068-2072         V8069 2073-2075         V8070 2076-2079
        V8071 2080-2082         V8072 2083-2086         V8073 2087-2089
        V8074 2090-2092         V8075 2093-2097         V8076 2098-2099
        V8077 2100-2101         V8078 2102-2104         V8079 2105-2106
        V8080 2107-2109         V8081 2110-2112         V8082 2113-2115
        V8083 2116-2118         V8084 2119-2121         V8085 2122-2124
        V8086 2125-2127         V8087 2128-2130         V8088 2131-2134
        V8089 2135-2137         V8090 2138-2140         V8091 2141-2143
        V8092 2144-2147         V8093 2148-2151         V8094 2152-2155
        V8095 2156-2158         V8096 2159-2160         V8097 2161-2162
        V8098 2163-2165         V8099 2166-2167         V8100 2168-2169
        V8101 2170-2171         V8102 2172-2173         V8103 2174-2175
        V8104 2176-2177         V8105 2178-2180         V8106 2181-2182
        V8107 2183-2184         V8108 2185-2186         V8109 2187-2188
        V8110 2189-2190         V8111 2191-2193         V8112 2194-2195
        V8113 2196-2197         V8114 2198-2199         V8115 2200-2201
        V8116 2202-2203         V8117 2204-2206         V8118 2207-2208
        V8119 2209-2210         V8120 2211-2212         V8121 2213-2214
        V8122 2215-2216         V8123 2217-2218         V8124 2219-2220
        V8125 2221-2222         V8126 2223-2224         V8127 2225-2227
        V8128 2228-2229         V8129 2230-2231         V8130 2232-2233
        V8131 2234-2235         V8132 2236-2238         V8133 2239-2240
        V8134 2241-2242         V8135 2243-2244         V8136 2245-2246
        V8137 2247-2249         V8138 2250-2251         V8139 2252-2253
        V8140 2254-2255         V8141 2256-2257         V8142 2258-2259
        V8143 2260-2261         V8144 2262-2263         V8145 2264-2267
        V8146 2268-2269         V8147 2270-2271         V8148 2272-2275
        V8149 2276-2279         V8150 2280-2281         V8151 2282-2283
        V8152 2284-2285         V8153 2286-2287         V8154 2288-2289
        V8155 2290-2291         V8156 2292-2293         V8157 2294-2295
        V8158 2296-2297         V8159 2298-2299         V8160 2300-2301
        V8161 2302-2303         V8162 2304-2305         V8163 2306-2307
        V8164 2308-2310         V8165 2311-2312         V8166 2313-2315
        V8167 2316-2318         V8168 2319-2321         V8169 2322-2324
        V8170 2325-2329         V8171 2330-2333         V8172 2334-2337
        V8173 2338-2341         V8174 2342-2345         V8175 2346-2349
        V8176 2350-2352         V8177 2353-2355         V8178 2356-2358
        V8179 2359-2362         V8180 2363-2366         V8181 2367-2369
        V8182 2370-2372         V8183 2373-2375         V8184 2376-2379
        V8185 2380-2383         V8186 2384-2387         V8187 2388-2390
        V8188 2391-2394         V8189 2395-2397         V8190 2398-2401
        V8191 2402-2404         V8192 2405-2407         V8193 2408-2410
        V8194 2411-2413         V8195 2414-2416         V8196 2417-2419
        V8197 2420-2424         V8198 2425-2428         V8199 2429-2432
        V8200 2433-2435         V8201 2436-2439         V8202 2440-2443
        V8203 2444-2446         V8204 2447-2449         V8205 2450-2452
        V8206 2453-2455         V8207 2456-2458         V8208 2459-2462
        V8209 2463-2466         V8210 2467-2470         V8211 2471-2473
        V8212 2474-2476         V8213 2477-2479         V8214 2480-2483
        V8215 2484-2487         V8216 2488-2491         V8217 2492-2494
        V8218 2495-2497         V8219 2498-2501         V8220 2502-2504
        V8221 2505-2507         V8222 2508-2510         V8223 2511-2513
        V8224 2514-2516         V8225 2517-2519         V8226 2520-2522
        V8227 2523-2525         V8228 2526-2529         V8229 2530-2533
        V8230 2534-2536         V8231 2537-2539         V8232 2540-2542
        V8233 2543-2547         V8234 2548-2551         V8235 2552-2555
        V8236 2556-2559         V8237 2560-2562         V8238 2563-2565
        V8239 2566-2567         V8240 2568-2572         V8241 2573-2577
        V8242 2578-2581         V8243 2582-2584         V8244 2585-2588
        V8245 2589-2592         V8246 2593-2596         V8247 2597-2599
        V8248 2600-2602         V8249 2603-2605         V8250 2606-2609
        V8251 2610-2612         V8252 2613-2615         V8253 2616-2618
        V8254 2619-2621         V8255 2622-2623         V8256 2624-2625
        V8257 2626-2627         V8258 2628-2629         V8259 2630-2631
        V8260 2632-2633         V8261 2634-2635         V8262 2636-2637
        V8263 2638-2641         V8264 2642-2643         V8265 2644-2645
        V8266 2646-2647         V8267 2648-2649         V8268 2650-2652
        V8269 2653-2654         V8270 2655-2656         V8271 2657-2658
        V8272 2659-2660         V8273 2661-2663         V8274 2664-2665
        V8275 2666-2667         V8276 2668-2669         V8277 2670-2671
        V8278 2672-2674         V8279 2675-2676         V8280 2677-2678
        V8281 2679-2680         V8282 2681-2682         V8283 2683-2684
        V8284 2685-2686         V8285 2687-2688         V8286 2689-2692
        V8287 2693-2696         V8288 2697-2700         V8289 2701-2704
        V8290 2705-2708         V8291 2709-2712         V8292 2713-2714
        V8293 2715-2717         V8294 2718-2720         V8295 2721-2723
        V8296 2724-2727         V8297 2728-2729         V8298 2730-2731
        V8299 2732-2733         V8300 2734-2735         V8301 2736-2737
        V8302 2738-2739         V8303 2740-2741         V8304 2742-2744
        V8305 2745-2746         V8306 2747-2748         V8307 2749-2750
        V8308 2751-2752         V8309 2753-2754         V8310 2755-2757
        V8311 2758-2760         V8312 2761-2763         V8313 2764-2766
        V8314 2767-2769         V8315 2770-2773         V8316 2774-2777
        V8317 2778-2779         V8318 2780-2783         V8319 2784-2787
        V8320 2788-2791         V8321 2792-2795         V8322 2796-2799
        V8323 2800-2803         V8324 2804-2807         V8325 2808-2811
        V8326 2812-2815         V8327 2816-2818         V8328 2819-2820
        V8329 2821-2824         V8330 2825-2827         V8331 2828-2830
        V8332 2831-2833         V8333 2834-2835         V8334 2836-2839
        V8335 2840-2842         V8336 2843-2845         V8337 2846-2848
        V8338 2849-2850         V8339 2851-2854         V8340 2855-2857
        V8341 2858-2860         V8342 2861-2863         V8343 2864-2865
        V8344 2866-2869         V8345 2870-2872         V8346 2873-2875
        V8347 2876-2878         V8348 2879-2880         V8349 2881-2883
        V8350 2884-2887         V8351 2888-2890         V8352 2891-2893
        V8353 2894-2896         V8354 2897-2899         V8355 2900-2903
        V8356 2904-2906         V8357 2907-2909         V8358 2910-2912
        V8359 2913-2915         V8360 2916-2919         V8361 2920-2922
        V8362 2923-2925         V8363 2926-2928         V8364 2929-2932
        V8365 2933-2935         V8366 2936-2939         V8367 2940-2942
        V8368 2943-2946         V8369 2947-2949         V8370 2950-2953
        V8371 2954-2956         V8372 2957-2960         V8373 2961-2963
        V8374 2964-2965         V8375 2966-2968         V8376 2969-2973
        V8377 2974-2977         V8378 2978-2980         V8379 2981-2982
        V8380 2983-2984         V8381 2985-2986         V8382 2987-2988
        V8383 2989-2990         V8384 2991-2992         V8385 2993-2995
        V8386 2996-2998         V8387 2999-3001         V8388 3002-3004
        V8389 3005-3007         V8390 3008-3010         V8391 3011-3013
        V8392 3014-3016         V8393 3017-3020         V8394 3021-3022
        V8395 3023-3024         V8396 3025-3026         V8397 3027-3028
        V8398 3029-3030         V8399 3031-3032         V8400 3033-3034
        V8401 3035-3036         V8402 3037-3038         V8403 3039-3040
        V8404 3041-3042         V8405 3043-3044         V8406 3045-3046
        V8407 3047-3048         V8408 3049-3050         V8409 3051-3052
        V8410 3053-3054         V8411 3055-3056         V8412 3057-3058
        V8413 3059-3060         V8414 3061-3062         V8415 3063-3064
        V8416 3065-3066         V8417 3067-3069         V8418 3070-3071
        V8419 3072-3074         V8420 3075-3076         V8421 3077-3078
        V8422 3079-3080         V8423 3081-3082         V8424 3083-3084
        V8425 3085-3086         V8426 3087-3088         V8427 3089-3091
        V8428 3092-3093         V8429 3094-3096         V8430 3097-3098
        V8431 3099-3101         V8432 3102-3103         V8433 3104-3105
        V8434 3106-3107         V8435 3108-3109         V8436 3110-3111
        V8437 3112-3113         V8438 3114-3115         V8439 3116-3117
        V8440 3118-3119         V8441 3120-3121         V8442 3122-3125
        V8443 3126-3128         V8444 3129-3131         V8445 3132-3135
        V8446 3136-3138         V8447 3139-3142         V8448 3143-3146
        V8449 3147-3149         V8450 3150-3152         V8451 3153-3155
        V8452 3156-3158         V8453 3159-3161         V8454 3162-3164
        V8455 3165-3167         V8456 3168-3170         V8457 3171-3173
        V8458 3174-3177         V8459 3178-3181         V8460 3182-3185
        V8461 3186-3189         V8462 3190-3192         V8463 3193-3196
        V8464 3197-3199         V8465 3200-3203         V8466 3204-3206
        V8467 3207-3210         V8468 3211-3213         V8469 3214-3216
        V8470 3217-3220         V8471 3221-3224         V8472 3225-3228
        V8473 3229-3232         V8474 3233-3236         V8475 3237-3238
        V8476 3239-3240         V8477 3241-3242         V8478 3243-3244
        V8479 3245-3246         V8480 3247-3248         V8481 3249-3250
        V8482 3251-3252         V8483 3253-3254         V8484 3255-3256
        V8485 3257-3258         V8486 3259-3260         V8487 3261-3262
        V8488 3263-3264         V8489 3265-3266         V8490 3267-3268
        V8491 3269-3270         V8492 3271-3272         V8493 3273-3274
        V8494 3275-3276         V8495 3277-3278         V8496 3279-3280
        V8497 3281-3282         V8498 3283-3284         V8499 3285-3286
        V8500 3287-3288         V8501 3289-3290         V8502 3291-3292
        V8503 3293-3294         V8504 3295-3296         V8505 3297-3298
        V8506 3299-3300         V8507 3301-3302         V8508 3303-3304
        V8509 3305-3306         V8510 3307-3308         V8511 3309-3310
        V8512 3311-3312         V8513 3313-3314         V8514 3315-3316
        V8515 3317-3318         V8516 3319-3320         V8517 3321-3322
        V8518 3323-3325         V8519 3326-3328         V8520 3329-3331
        V8521 3332-3334         V8522 3335-3337         V8523 3338-3340
        V8524 3341-3343         V8525 3344-3346         V8526 3347-3348
        V8527 3349-3350         V8528 3351-3352         V8529 3353-3355
        V8530 3356-3358         V8531 3359-3361         V8532 3362-3364
        V8533 3365-3366         V8534 3367-3368         V8535 3369-3370
        V8536 3371-3373         V8537 3374-3375         V8538 3376-3378
        V8539 3379-3380         V8540 3381-3383         V8541 3384-3385
        V8542 3386-3388         V8543 3389-3390         V9118 3391-3401 .8
        V9119 3402-3412 .8      ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   UNITID  = 'ID NUMBER FOR UNIT/OSAT CENTER'
   V7004   = 'FS INTERVIEWERS ID'
   V7005   = 'FS MONTH BEGAN IW'
   V7006   = 'FS DAY BEGAN IW'
   V7007   = 'FS YEAR BEGAN IW'
   V7008   = 'FS MONTH FINISH IW'
   V7009   = 'FS DAY FINISH IW'
   V7010   = 'FS YEAR FINISH IW'
   V7011   = 'FS IW LENGTH (MINS.)'
   V7012   = 'A1 OSAT START MONTH'
   V7013   = 'A1 OSAT START YEAR'
   V7014   = 'A2 EXTNT FOUNDERS INFL NOW'
   V7015   = 'A3 MI CH LAST 2 YRS:Y/N?'
   V7016   = 'A3AM1 HOW MI CHANGED?'
   V7017   = 'A3AM2 HOW MI CHANGED?'
   V7018   = 'A4A DEGREE IMP KEEP COST LOW'
   V7019   = 'A4B DEGREE CL SELE IMP 4COST'
   V7020   = 'A4C DEGREE IMP U MAKE PROFIT'
   V7021   = 'A4D DEGREE 4-PROFIT UNITS OK'
   V7022   = 'A4E DEGREE 4PROFIT U MOR EFF'
   V7023   = 'A4F DEGREE STANDRDS NOT COST'
   V7024   = 'A4G DEGREE CL ACC CARE W/O $'
   V7025   = 'A4H DEGREE $ FOR TX PUB RESP'
   V7026   = 'A4I DEGREE PR SCTR SHD COVER'
   V7027   = 'B1 OTHR R FOR FUNDGS:Y/N?'
   V7028   = 'B2 U PRV NONOSAT SERV:Y/N?'
   V7029   = 'B2AM1 OTHER SERV PROV'
   V7030   = 'B2AM2 OTHER SERV PROV'
   V7031   = 'B2AM3 OTHER SERV PROV'
   V7032   = 'B2AM4 OTHER SERV PROV'
   V7033   = 'B2B % TOT CL ARE OSAT'
   V7034   = 'B2C % TOT REV FR OSAT'
   V7035   = 'B3 $#S FOR JUST OSAT:Y/N?'
   V7036   = 'B4 BEGIN MONTH MRCFYR'
   V7037   = 'B4 BEGIN DAY MRCFYR'
   V7038   = 'B4 BEGIN YEAR MRCFYR'
   V7039   = 'B4 END MONTH MRCFYR'
   V7040   = 'B4 END DAY MRCFYR'
   V7041   = 'B4 END YEAR MRCFYR'
   V7042   = 'B4A TOT U REV MRCFYR'
   V7043   = 'B4B TOT U XPNS MRCFYR'
   V7044   = 'B4C $FOR WAGES,SALARY'
   V7045   = 'B5 OSAT BEGIN MO FYR'
   V7046   = 'B5 OSAT BEGIN DAY FYR'
   V7047   = 'B5 OSAT BEGIN YR FYR'
   V7048   = 'B5 OSAT END MONTH FYR'
   V7049   = 'B5 OSAT END DAY MRFYR'
   V7050   = 'B5 OSAT END YEAR FYR'
   V7051   = 'B5A OSATU REV MRCFYR'
   V7052   = 'B5B OSATU XPNS MRCFYR'
   V7053   = 'B5C OSAT WAGES,SALARY'
   V7054   = 'B6 TOT FEDERAL $ TO U'
   V7055   = 'B7A U $ FR: MEDICARE:Y/N?'
   V7056   = 'B8A MEDICARE $ AMOUNT'
   V7057   = 'B9A MEDICARE PAYBASIS'
   V7058   = 'B7B U $FR: FED COURTS:Y/N?'
   V7059   = 'B8B FED COURTS $ AMT'
   V7060   = 'B9B F COURTS PAYBASIS'
   V7061   = 'B7C U $ FR: DHHS:Y/N?'
   V7062   = 'B8C DHHS $ AMOUNT'
   V7063   = 'B9C DHHS PAY BASIS'
   V7064   = 'B7D U $ FR:OTH F SRC1:Y/N?'
   V7065   = 'B7D OTHER FED SOURCE1'
   V7066   = 'B8D OTH FED SRC1 $AMT'
   V7067   = 'B9D O F SRC1 PAYBASIS'
   V7068   = 'B7E U $ FR:OTH F SRC2:Y/N?'
   V7069   = 'B7E OTHER FED SOURCE2'
   V7070   = 'B8E OTH FED SRC2 $AMT'
   V7071   = 'B9E O F SRC2 PAYBASIS'
   V7072   = 'B7F U $ FR:OTH F SRC3:Y/N?'
   V7073   = 'B7F OTHER FED SOURCE3'
   V7074   = 'B8F OTH FED SRC3 $AMT'
   V7075   = 'B9F O F SRC3 PAYBASIS'
   V7076   = 'B10 TOT STATE $ TO U'
   V7077   = 'B10A %TOT FR BLKGRNTS'
   V7078   = 'B11A U $ FR:MEDICAID:Y/N?'
   V7079   = 'B12A MEDICAID $AMOUNT'
   V7080   = 'B13A MEDICAID PAYBASE'
   V7081   = 'B11B U $ FR:STATE OSA:Y/N?'
   V7082   = 'B12B STATE OSA $ AMT'
   V7083   = 'B13B ST OSA PAYBASIS'
   V7084   = 'B11C U $ FR:ST COURTS:Y/N?'
   V7085   = 'B12C ST COURTS $ AMT'
   V7086   = 'B13C ST CORT PAYBASIS'
   V7087   = 'B11D U $FR:OTH S SRC1:Y/N?'
   V7088   = 'B11D OTH STATE SORCE1'
   V7089   = 'B12D OTH S SRC1 $ AMT'
   V7090   = 'B13D O S SRC1 PAYBASE'
   V7091   = 'B11E U $FR:OTH S SRC2:Y/N?'
   V7092   = 'B11E OTH STATE SORCE2'
   V7093   = 'B12E OTH S SRC2 $ AMT'
   V7094   = 'B13E O S SRC2 PAYBASE'
   V7095   = 'B11F U $FR:OTH S SRC3:Y/N?'
   V7096   = 'B11F OTH STATE SORCE3'
   V7097   = 'B12F OTH S SRC3 $ AMT'
   V7098   = 'B13F O S SRC3 PAYBASE'
   V7099   = 'B14 TOT $FR CITY,CNTY'
   V7100   = 'B15A U $FR:CI,CO CRTS:Y/N?'
   V7101   = 'B16A CI,CO CORTS $AMT'
   V7102   = 'B17A CTY CORT PAYBASE'
   V7103   = 'B15B U$FR:OTH CO SRC1:Y/N?'
   V7104   = 'B15B OTH COUNTY SRC 1'
   V7105   = 'B16B OTH CO SRC1 $AMT'
   V7106   = 'B17B O CO SRC1PAYBASE'
   V7107   = 'B15C U$FR:OTH CO SRC2:Y/N?'
   V7108   = 'B15C OTH COUNTY SRC 2'
   V7109   = 'B16C OTH CO SRC2 $AMT'
   V7110   = 'B17C O CO SRC2PAYBASE'
   V7111   = 'B15D U$FR:OTH C1 SRC3:Y/N?'
   V7112   = 'B15D OTH CITY SOURCE3'
   V7113   = 'B16D OTH CI SRC3 $AMT'
   V7114   = 'B17D O CI SRC3PAYBASE'
   V7115   = 'B15E U$FR:OTH CI SRC4:Y/N?'
   V7116   = 'B15E OTH CITY SOURCE4'
   V7117   = 'B16E OTH CI SRC4 $AMT'
   V7118   = 'B17E O CI SRC4PAYBASE'
   V7119   = 'B15F U$FR:O CI&COSRC5:Y/N?'
   V7120   = 'B15F O CITY&CNTY SRC5'
   V7121   = 'B16F O CI&CO SRC5$AMT'
   V7122   = 'B17F OTH SRC5 PAYBASE'
   V7123   = 'B18 TOT FEES,INS$TO U'
   V7124   = 'B19A U $ FR: CL FEES:Y/N?'
   V7125   = 'B20A CL FEES $ AMOUNT'
   V7126   = 'B21A CL FEES PAYBASIS'
   V7127   = 'B19B U $FR: PRIV INS:Y/N?'
   V7128   = 'B20B PRIV INS $AMOUNT'
   V7129   = 'B21B PRIV INS PAYBASE'
   V7130   = 'B19C U $ FR: HMO:Y/N?'
   V7131   = 'B20C HMO $ AMOUNT'
   V7132   = 'B21C HMO PAY BASIS'
   V7133   = 'B19D U $ FR: PPO:Y/N?'
   V7134   = 'B20D PPO $ AMOUNT'
   V7135   = 'B21D PPO PAY BASIS'
   V7136   = 'B19E U $FR:O C,I SRC1:Y/N?'
   V7137   = 'B19E OTH CL, INS SRC1'
   V7138   = 'B20E OTH C,I SRC1$AMT'
   V7139   = 'B21E O C,I SRC1 PAYBA'
   V7140   = 'B19F U $FR:O C,I SRC2:Y/N?'
   V7141   = 'B19F OTH CL,INS SRC 2'
   V7142   = 'B20F OTH C,I SRC2$AMT'
   V7143   = 'B21F O C,I SRC2 PAYBA'
   V7144   = 'B22A U $FR:PRV DONATN:Y/N?'
   V7145   = 'B23A PRV DONATION$AMT'
   V7146   = 'B22B U $FR:OTH SORCE1:Y/N?'
   V7147   = 'B22B OTH U $ SOURCE 1'
   V7148   = 'B23B OTH SOURCE1 $AMT'
   V7149   = 'B22C U $FR:OTH SORCE2'
   V7150   = 'B22C OTH U $ SOURCE 2'
   V7151   = 'B23C OTH SOURCE2 $AMT'
   V7152   = 'B22D U $FR:OTH SORCE3:Y/N?'
   V7153   = 'B22D OTH U $ SOURCE 3'
   V7154   = 'B23D OTH SOURCE3 $AMT'
   V7155   = 'B22E U $FR:OTH SORCE4:Y/N?'
   V7156   = 'B22E OTH U $ SOURCE 4'
   V7157   = 'B23E OTH SOURCE4 $AMT'
   V7158   = 'B22F U $FR:OTH SORCE5:Y/N?'
   V7159   = 'B22F OTH U $ SOURCE 5'
   V7160   = 'B23F OTH SOURCE5 $AMT'
   V7161   = 'B24 INKINDPARENT SUPT:Y/N?'
   V7162   = 'B24A $AMT PARENT SUPT'
   V7163   = 'B25 U PROV OTH SERVS?'
   V7164   = 'B26 CAN R SEP OSAT#S:Y/N?'
   V7165   = 'B27 %TOT CL PR,PU ASS'
   V7166   = 'B28 %TOT CL W PRI INS'
   V7167   = 'B28A%TOT PR INS@75%PD'
   V7168   = 'B28B %TOT PRINS<=50%P'
   V7169   = 'B29 %TOT CL W PUB ASS'
   V7170   = 'B29A %TOT PU ASS@75%P'
   V7171   = 'B29B %TOT PUASS<=50%P'
   V7172   = 'B30 %TOTCL HMO,PPO FY'
   V7173   = 'B31 %TOTCL PAYAUTH FY'
   V7174   = 'B32 %TOTCL CONCREV FY'
   V7175   = 'B33 %TOTCL CANTPAY FY'
   V7176   = 'B34 %TOTCL PAYLESS FY'
   V7177   = 'B35 %TOTCL TURNAWY FY'
   V7178   = 'B36 %OSAT W PR,PU ASS'
   V7179   = 'B37 %OSAT CL W PR INS'
   V7180   = 'B37A %OSAT PRINS@75%P'
   V7181   = 'B37B %OSAT PRINS<=50%'
   V7182   = 'B38 %OSAT CL W PU ASS'
   V7183   = 'B38A %OSAT PUASS@75%P'
   V7184   = 'B38B %OSAT PUASS<=50%'
   V7185   = 'B39 %OSAT HMO,PPO FYR'
   V7186   = 'B40 %OSAT PAY AUTH FY'
   V7187   = 'B41 %OSAT CONC REV FY'
   V7188   = 'B42 %OSAT CANT PAY FY'
   V7189   = 'B43 %OSAT PAY LESS FY'
   V7190   = 'B44 %OSAT TURNAWAY FY'
   V7191   = 'B45 U RENT OR OWN?'
   V7192   = 'B45A TOT RENT XPNS FY'
   V7193   = 'B46 U SIZE IN SQ FEET'
   V7194   = 'B47 U HAS FIN REPORT:Y/N?'
   V7195   = 'B47A U SEND FIN REPT:Y/N?'
   V7196   = 'B48 TOT STAFF HRS/WK'
   V7197   = 'B48A OSAT STAF HRS/WK'
   V7198   = 'B49 U VOLUNTEER SUPT:Y/N?'
   V7199   = 'B49A TOT VOLUNTER HRS'
   V7200   = 'B50A TOT#OP CL MRCFYR'
   V7201   = 'B50B TOT#OSAT CL MRFY'
   V7202   = 'B51 #OSAT CL PER WEEK'
   V7203   = 'B52 U PROV INDIV THER:Y/N?'
   V7204   = 'B52A #IND THER SES/WK'
   V7205   = 'B52B #IND THER CL/WK'
   V7206   = 'B52C #MIN/SESS IND TH'
   V7207   = 'B52D #IND TH HRS/WEEK'
   V7208   = 'B52E IND TH COST/SESS'
   V7209   = 'B52FM1 %OITS:PSYCHIAT'
   V7210   = 'B52FM2 %OITS:PSYCHOLO'
   V7211   = 'B52FM3 %OITS:MA SW,PS'
   V7212   = 'B52FM4 OTH OPIT STAF1'
   V7213   = 'B52FM4 %SES OTH SITS1'
   V7214   = 'B52FM5 OTH OPIT STAF2'
   V7215   = 'B52FM5 %SES OTH OITS2'
   V7216   = 'B52FM6 OTH OPIT STAF3'
   V7217   = 'B52FM6 %SES OTH OITS3'
   V7218   = 'B52G #OPIT SESS/CL/WK'
   V7219   = 'B52H #OPIT SESS/CL/TX'
   V7220   = 'B53 U PROV GROUP THER:Y/N?'
   V7221   = 'B53A #GP THER SESS/WK'
   V7222   = 'B53B #GP THERPY CL/WK'
   V7223   = 'B53C #MIN/SESS GP TH'
   V7224   = 'B53D #GROUP TH HRS/WK'
   V7225   = 'B53E GP TH $/CL/SESS'
   V7226   = 'B53F #CL/SESS GP THER'
   V7227   = 'B53G #COUNSLRS/SES GT'
   V7228   = 'B53HM1 %OGTS:PSYCHIAT'
   V7229   = 'B53HM2 %OGTS:PSYCHOLO'
   V7230   = 'B53HM3 %OGTS:MA SW,PS'
   V7231   = 'B53HM4 OTH OPGT STAF1'
   V7232   = 'B53HM4 %SES OTH OGTS1'
   V7233   = 'B53HM5 OTH OPGT STAF2'
   V7234   = 'B53HM5 %SES OTH OGTS2'
   V7235   = 'B53HM6 OTH OPGT STAF3'
   V7236   = 'B53HM6 %SES OTH OGTS3'
   V7237   = 'B53I #OPGT SESS/CL/WK'
   V7238   = 'B53J #OPGT SESS/CL/TX'
   V7239   = 'B54 U PROV FAMILY TH:Y/N?'
   V7240   = 'B54A #FA THER SESS/WK'
   V7241   = 'B54B #FAMLYTHER CL/WK'
   V7242   = 'B54C #MIN/SESS F THER'
   V7243   = 'B54D #FAM THER HRS/WK'
   V7244   = 'B54E FT COST/FAM/SESS'
   V7245   = 'B54F #FAM MEM/SESS FT'
   V7246   = 'B54G #COUNSLRS/SES FT'
   V7247   = 'B54HM1 %OFTS:PSYCHIAT'
   V7248   = 'B54HM2 %OFTS:PSYCHOLO'
   V7249   = 'B54HM3 %OFTS:MA SW,PS'
   V7250   = 'B54HM4 OTH OFTS STAF1'
   V7251   = 'B54HM4 %SES OTH OFTS1'
   V7252   = 'B54HM5 OTH OFTS STAF2'
   V7253   = 'B54HM5 %SES OTH OFTS2'
   V7254   = 'B54HM6 OTH OFTS STAF3'
   V7255   = 'B54HM6 %SES OTH OFTS3'
   V7256   = 'B54I #OPFT SESS/CL/WK'
   V7257   = 'B54J #OPFT SESS/CL/TX'
   V7258   = 'B55 W PROV OP METH TX:Y/N?'
   V7259   = 'B55A MT BEGN LAST2YRS:Y/N?'
   V7260   = 'B55B #OP METH CL/WEEK'
   V7261   = 'B55C TOT #METHDOSE/WK'
   V7262   = 'B55D $/DOSE METHADONE'
   V7263   = 'B56 MT STOP LAST 2YRS:Y/N?'
   V7264   = 'B57 U PRO OTH OSATSER:Y/N?'
   V7265   = 'B58 #STAFHRS OTH SERV'
   V7266   = 'B59 OSATU PUB OR PRIV'
   V7267   = 'B60 PUB/PRIV CH L2YRS:Y/N?'
   V7268   = 'C1 U PART OF OTH ORG:Y/N?'
   V7269   = 'C1A PART-OF:CHG 2 YRS:Y/N?'
   V7270   = 'C2 IWR CKPT:U PART-OF'
   V7271   = 'C3 PART-OF:PUB,FP,NFP'
   V7272   = 'C3A PART-OF:FED,ST,LO'
   V7273   = 'C4 PART-OF:HOSP,MHC,O'
   V7274   = 'C6 U OWND BY OTH ORG:Y/N?'
   V7275   = 'C6A OWN STATUS CH 2YR:Y/N?'
   V7276   = 'C7 IWR CKPT:U OWNEBY'
   V7277   = 'C8 OWNER IS:PU,FP,NFP'
   V7278   = 'C8A PU OWNR FED,ST,LO'
   V7279   = 'C9 OWNR IS HOSP,MHC,O'
   V7280   = 'C11 U MANGBY OTH ORG:Y/N?'
   V7281   = 'C11A MGMT STA CHG 2YR:Y/N?'
   V7282   = 'C12 IWR CKPT:U MANAGD'
   V7283   = 'C13 MANAGR:PUB,FP,NFP'
   V7284   = 'C13A MANAGR:FED,ST,LO'
   V7285   = 'C14 MANAGR HOSP,MHC,O'
   V7286   = 'C16 IWR CKPT:U PARENT'
   V7287   = 'C17 EXTNT PARENT ACCEPTCE U'
   V7288   = 'D1A U LIC: JCAHC:Y/N?'
   V7289   = 'D1B U LIC: FDA:Y/N?'
   V7290   = 'D1C U LIC: DEA:Y/N?'
   V7291   = 'D1D U LIC: ST AGENCY:Y/N?'
   V7292   = 'D1EM1 ST LIC AGENCY1'
   V7293   = 'D1EM2 ST LIC AGENCY2'
   V7294   = 'D1F U LIC: CTY,CO AGY:Y/N?'
   V7295   = 'D1GM1 CTY,CO LIC AGY1'
   V7296   = 'D1GM2 CTY,CO LIC AGY2'
   V7297   = 'D1H U LIC: OTHER ORGS:Y/N?'
   V7298   = 'D1IM1 OTH LIC AGENCY1'
   V7299   = 'D1IM2 OTH LIC AGENCY2'
   V7300   = 'D2 U LIC: ST REQMENT:Y/N?'
   V7301   = 'D2AM1 REQ ST LIC AGY1'
   V7302   = 'D2AM2 REQ ST LIC AGY2'
   V7303   = 'D2B U LIC:SUBSTITUTES:Y/N?'
   V7304   = 'D3 U LIC:NEED FOR PAY:Y/N?'
   V7305   = 'D3AM1 LIC REQD 4PAY 1'
   V7306   = 'D3AM2 LIC REQD 4PAY 2'
   V7307   = 'D3BM1 LIC REQ BY AGY1'
   V7308   = 'D3BM2 LIC REQ BY AGY2'
   V7309   = 'D4 U REVU:OUTSIDE AGY:Y/N?'
   V7310   = 'D5A U REVU: JCAHO:Y/N?'
   V7311   = 'D5B U REVU:JCAHO-FREQ'
   V7312   = 'D5C U REVU:ST DEPT PH:Y/N?'
   V7313   = 'D5D U REVU:SDPH-FREQY'
   V7314   = 'D5E U REVU:ST DEPT MH:Y/N?'
   V7315   = 'D5F U REVU:SDMH-FREQY'
   V7316   = 'D5G U REVU:ST DEPT SA:Y/N?'
   V7317   = 'D5H U REVU:SDSA-FREQY'
   V7318   = 'D5I U REVU: FDA:Y/N?'
   V7319   = 'D5J U REVU:FDA-FREQCY'
   V7320   = 'D5K U REVU: DEA:Y/N?'
   V7321   = 'D5L U REVU:DEA-FREQCY'
   V7322   = 'D6 U REVU:OTH AGENCY:Y/N?'
   V7323   = 'D6A U REVU:O AGY NAME'
   V7324   = 'D6B U REVU:O AGY FREQ'
   V7325   = 'D7A REV INCL:$RECORDS:Y/N?'
   V7326   = 'D7B REV INCL:CL CNTCT:Y/N?'
   V7327   = 'D7C REV INCL:SITEVSIT:Y/N?'
   V7328   = 'D7D REV INCL:REV REPT:Y/N?'
   V7329   = 'D7E REV INCL:CL RECRD:Y/N?'
   V7330   = 'D7F REV INCL:POLICIES:Y/N?'
   V7331   = 'D7G REV INCL:QA PROCD:Y/N?'
   V7332   = 'D8 EXTNT U SHD INVLVD POL DVLP'
   V7333   = 'D8A EXTNT U IS INVLVD POL DVLP'
   V7334   = 'D9A EXTNT RELY CURR:PROF PUBLS'
   V7335   = 'D9B EXTNT RELY CURR:ATTND CONF'
   V7336   = 'D9C EXTNT RELY CURR:SPEC TRAIN'
   V7337   = 'D9D EXTNT RELY CURR:PROF ASSNS'
   V7338   = 'D9E EXTNT RELY CURR:PART BORDS'
   V7339   = 'D9F EXTNT RELY CURR:MKT RESRCH'
   V7340   = 'D9G EXTNT RELY CURR:TALK-ORGS'
   V7341   = 'D10 EXTNT MSN:FORMAL AGRMNT'
   V7342   = 'D10 MSN:AGR-#ORGNAMES'
   V7343   = 'D10A MSN:AGR-ORGNAME1'
   V7344   = 'D10B MSN:AGR-FUNDAGY1'
   V7345   = 'D10B MSN:AGR-LIC AGY1'
   V7346   = 'D10B MSN:AGR-REF AGY1'
   V7347   = 'D10B MSN:AGR-TX AGY 1'
   V7348   = 'D10C MSN:AGR-LVL AGY1'
   V7349   = 'D10A MSN:AGR:ORGNAME2'
   V7350   = 'D10B MSN:AGR-FUNDAGY2'
   V7351   = 'D10B MSN:AGR-LIC AGY2'
   V7352   = 'D10B MSN:AGR-REF AGY2'
   V7353   = 'D10B MSN:AGR-TX AGY 2'
   V7354   = 'D10C MSN:AGR-LVL AGY2'
   V7355   = 'D10A MSN:AGR-ORGNAME3'
   V7356   = 'D10B MSN:AGR-FUNDAGY3'
   V7357   = 'D10B MSN:AGR-LIC AGY3'
   V7358   = 'D10B MSN:AGR-REF AGY3'
   V7359   = 'D10B MSN:AGR-TX AGY 3'
   V7360   = 'D10C MSN:AGR-LVL AGY3'
   V7361   = 'D11 EXTNT MSN:AGR-CONFL REQ'
   V7362   = 'D12 EXTNT MSN:INCENTVS OFRD'
   V7363   = 'D13 EXTNT MSN:GOV AGCY REGS'
   V7364   = 'D13 MSN:GOV-#AGYNAMES'
   V7365   = 'D13A MSN:GOV-AGYNAME1'
   V7366   = 'D13B MSN:GOV-FUNDAGY1'
   V7367   = 'D13B MSN:GOV-LIC AGY1'
   V7368   = 'D13B MSN:GOV-REF AGY1'
   V7369   = 'D13C MSN:GOV-LVL AGY1'
   V7370   = 'D13A MSN:GOV-AGYNAME2'
   V7371   = 'D13B MSN:GOV-FUNDAGY2'
   V7372   = 'D13B MSN:GOV-LIC AGY2'
   V7373   = 'D13B MSN:GOV-REF AGY2'
   V7374   = 'D13C MSN:GOV-LVL AGY2'
   V7375   = 'D13A MSN:GOV-AGYNAME3'
   V7376   = 'D13B MSN:GOV-FUNDAGY3'
   V7377   = 'D13B MSN:GOV-LIC AGY3'
   V7378   = 'D13B MSN:GOV-REF AGY3'
   V7379   = 'D13C MSN:GOV-LVL AGY3'
   V7380   = 'D14 EXTNT MSN:GOV-CONFL REQ'
   V7381   = 'D15 EXTNT MSN:ENHANCE IMAGE'
   V7382   = 'D16 EXTNT MSN: STAY CURRENTX'
   V7383   = 'D17 EXTNT ASS:FORMAL AGRMNT'
   V7384   = 'D17 ASS:AGR-#ORGNAMES'
   V7385   = 'D17A ASS:AGR-ORGNAME1'
   V7386   = 'D17B ASS:AGR-FUNDAGY1'
   V7387   = 'D17B ASS:AGR-LIC AGY1'
   V7388   = 'D17B ASS:AGR-REF AGY1'
   V7389   = 'D17B ASS:AGR-TX AGY 1'
   V7390   = 'D17C ASS:AGR-LVL AGY1'
   V7391   = 'D17A ASS:AGR-ORGNAME2'
   V7392   = 'D17B ASS:AGR-FUNDAGY2'
   V7393   = 'D17B ASS:AGR-LIC AGY2'
   V7394   = 'D17B ASS:AGR-REF AGY2'
   V7395   = 'D17B ASS:AGR-TX AGY 2'
   V7396   = 'D17C ASS:AGR-LVL AGY2'
   V7397   = 'D17A ASS:AGR-ORGNAME3'
   V7398   = 'D17B ASS:AGR-FUNDAGY3'
   V7399   = 'D17B ASS:AGR-LIC AGY3'
   V7400   = 'D17B ASS:AGR-REF AGY3'
   V7401   = 'D17B ASS:AGR-TX AGY 3'
   V7402   = 'D17C ASS:AGR-LVL AGY3'
   V7403   = 'D18 EXTNT ASS:AGR-CONFL REQ'
   V7404   = 'D19 EXTNT ASS:INCENTIV OFRD'
   V7405   = 'D20 EXTNT ASS:GOV AGCY REQS'
   V7406   = 'D20 ASS:GOV-#AGYNAMES'
   V7407   = 'D20A ASS:GOV-AGYNAME1'
   V7408   = 'D20B ASS:GOV-FUNDAGY1'
   V7409   = 'D20B ASS:GOV-LIC AGY1'
   V7410   = 'D20B ASS:GOV-REF AGY1'
   V7411   = 'D20C ASS:GOV-LVL AGY1'
   V7412   = 'D20A ASS:GOV-AGYNAME2'
   V7413   = 'D20B ASS:GOV-FUNDAGY2'
   V7414   = 'D20B ASS:GOV-LIC AGY2'
   V7415   = 'D20B ASS:GOV-REF AGY2'
   V7416   = 'D20C ASS:GOV-LVL AGY2'
   V7417   = 'D20A ASS:GOV-AGYNAME3'
   V7418   = 'D20B ASS:GOV-FUNDAGY3'
   V7419   = 'D20B ASS:GOV-LIC AGY3'
   V7420   = 'D20B ASS:GOV-REF AGY3'
   V7421   = 'D20C ASS:GOV-LVL AGY3'
   V7422   = 'D21 EXTNT ASS:GOV-CONFL REQ'
   V7423   = 'D22 EXTNT ASS:ENHANCE IMAGE'
   V7424   = 'D23 EXTNT ASS: STAY CURRENTX'
   V7425   = 'D24 EXTNT TX:FORMAL AGRMENT'
   V7426   = 'D24 TX:AGR-#ORG NAMES'
   V7427   = 'D24A TX:AGR-ORG NAME1'
   V7428   = 'D24B TX:AGR-FUND AGY1'
   V7429   = 'D24B TX:AGR-LIC AGY 1'
   V7430   = 'D24B TX:AGR-REF AGY 1'
   V7431   = 'D24B TX:AGR- TX AGY 1'
   V7432   = 'D24C TX:AGR-LVL AGY 1'
   V7433   = 'D24A TX:AGR-ORG NAME2'
   V7434   = 'D24B TX:AGR-FUND AGY2'
   V7435   = 'D24B TX:AGR-LIC AGY 2'
   V7436   = 'D24B TX:AGR-REF AGY 2'
   V7437   = 'D24B TX:AGR- TX AGY 2'
   V7438   = 'D24C TX:AGR-LVL AGY 2'
   V7439   = 'D24A TX:AGR-ORG NAME3'
   V7440   = 'D24B TX:AGR-FUND AGY3'
   V7441   = 'D24B TX:AGR-LIC AGY 3'
   V7442   = 'D24B TX:AGR-REF AGY 3'
   V7443   = 'D24B TX:AGR- TX AGY 3'
   V7444   = 'D24C TX:AGR-LVL AGY 3'
   V7445   = 'D25 TX:EXTNT AGR-CONFL REQS'
   V7446   = 'D26 TX:EXTNT INCENTIVS OFRD'
   V7447   = 'D27 TX:EXTNT GOV AGNCY REQS'
   V7448   = 'D27 TX:GOV-#AGY NAMES'
   V7449   = 'D27A TX:GOV-AGY NAME1'
   V7450   = 'D27B TX:GOV-FUND AGY1'
   V7451   = 'D27B TX:GOV-LIC AGY 1'
   V7452   = 'D27B TX:GOV-REF AGY 1'
   V7453   = 'D27C TX:GOV-LVL AGY 1'
   V7454   = 'D27A TX:GOV-AGY NAME2'
   V7455   = 'D27B TX:GOV-FUND AGY2'
   V7456   = 'D27B TX:GOV-LIC AGY 2'
   V7457   = 'D27B TX:GOV-REF AGY 2'
   V7458   = 'D27C TX:GOV-LVL AGY 2'
   V7459   = 'D27A TX:GOV-AGY NAME3'
   V7460   = 'D27B TX:GOV-FUND AGY3'
   V7461   = 'D27B TX:GOV-LIC AGY 3'
   V7462   = 'D27B TX:GOV-REF AGY 3'
   V7463   = 'D27C TX:GOV-LVL AGY 3'
   V7464   = 'D28 TX:EXTNT GOV-CONFL REQS'
   V7465   = 'D29 TX:EXTNT ENHANCE IMAGE'
   V7466   = 'D30 TX:EXTNT STAY CURRENT'
   V7467   = 'E1A COMPETE:EXTNT HOSP SATU'
   V7468   = 'E1B COMPETE:HOSP PUB/PRI'
   V7469   = 'E1C COMPETE: HOSP FP/NFP'
   V7470   = 'E1D COMPETE:EXTNT MHC SATU'
   V7471   = 'E1E COMPETE:MHC PUB/PRIV'
   V7472   = 'E1F COMPETE: MHC FP/NFP'
   V7473   = 'E1G COMPETE:EXTNT FREE-ST SATU'
   V7474   = 'E1H COMPETE:FR-ST PUB/PR'
   V7475   = 'E1I COMPETE:FR-ST FP/NFP'
   V7476   = 'E2A COMP4:EXTNT CLIENT REFS'
   V7477   = 'E2B COMP4:EXTNT GOV FUNDING'
   V7478   = 'E2C COMP4:EXTNT POL SUPPORT'
   V7479   = 'E2D COMP4:EXTNT COMM SUPORT'
   V7480   = 'E2E COMP4:EXTNT PR INSURNCE'
   V7481   = 'E2F COMP4:EXTNT ACCREDITATN'
   V7482   = 'E2G COMP4:EXTNT PERSONNEL'
   V7483   = 'E2H COMP4:EXTNT PRESTIGE'
   V7484   = 'E3A COMP BASE:EXTNT COST CL'
   V7485   = 'E3B COMPBASE:EXTNT COST OTH'
   V7486   = 'E3C COMP B:EXTNT STAFF CRED'
   V7487   = 'E3D COMP B:EXTNT TX SETTING'
   V7488   = 'E3E COMP B:EXTNT EASE ACCES'
   V7489   = 'E3F COMP B:EXTNT QUAL CARE'
   V7490   = 'E3G COMPB:EXTNT MARKET EFFS'
   V7491   = 'E3H COMPB:EXTNT RANG OF SRV'
   V7492   = 'E3I COMPB:EXTNT PRICE STRAT'
   V7493   = 'E3J COMPBASE:EXTNT COSTCTRL'
   V7494   = 'E4 DEGREE COMP RESORCS CH YR'
   V7495   = 'E4AM1 Y COMP CHNGE-YR'
   V7496   = 'E4AM2 Y COMP CHNGE-YR'
   V7497   = 'E5A HR/WK R:NEG $ AGY'
   V7498   = 'E5B HR/WK R:LIASN LIC'
   V7499   = 'E5C HR/WK R:COMM TALK'
   V7500   = 'E5D HR/WK R:LOOK4 NU$'
   V7501   = 'E5E HR/WK R:OTH PROVR'
   V7502   = 'E5F HR/WK R:MK POLICY'
   V7503   = 'E5G HR/WK R:RECRUT ST'
   V7504   = 'E5H HR/WK R:PROF ASSN'
   V7505   = 'E6 SOU LARGST# REFRLS'
   V7506   = 'E7A M REF SOU:INF AGR:Y/N?'
   V7507   = 'E7B M REF SOU:OWNS U:Y/N?'
   V7508   = 'E8 M REF SOU:CONTRACT:Y/N?'
   V7509   = 'E9A CONTRACT:U LICNSD:Y/N?'
   V7510   = 'E9B CONTRACT:INCENTVE:Y/N?'
   V7511   = 'E9C CONTRACT:STD PROC:Y/N?'
   V7512   = 'E9D CONTRACT:DISPUTES:Y/N?'
   V7513   = 'E9E CONTRACT:FEE SCHD:Y/N?'
   V7514   = 'E10M1 OTHR ARANG W/E6'
   V7515   = 'E10M2 OTHR ARANG W/E6'
   V7516   = 'E11A E6:RECVNG CL CRITCL'
   V7517   = 'E11B E6:CNTRL REFRLS TO U'
   V7518   = 'E11C E6:U INFLNCES E6'
   V7519   = 'E11D E6:FUT REF UNCER'
   V7520   = 'E11E E6:OTHER U COMPETING FOR REFRLS'
   V7521   = 'E11F E6:DEALINGS CRIT TO FUT SURVIVAL'
   V7522   = 'E11G E6:U UNDRSTDS E6'
   V7523   = 'E11H E6:EYE TO EYE-TX'
   V7524   = 'E11I E6:SHARE BELIEFS'
   V7525   = 'E11J CLIMATE COMP-REFRLS'
   V7526   = 'E12A +1YR:DEGREE AMT AVAIL $'
   V7527   = 'E12B +1YR:LVL DEMAND SERVC'
   V7528   = 'E12C +1YR:KIND OF SERVCS IN DEMAND'
   V7529   = 'E12D +1YR:KIND OF STAFF NEEDED'
   V7530   = 'E12E +1YR:ACCREDT REQUIRED'
   V7531   = 'E12F +1YR:OTH SAT OFFERING'
   V7532   = 'E12G +1YR:OTH SAT CHARGING'
   V7533   = 'E12H +1YR:OTH SAT QUAL'
   V7534   = 'E12I +1YR:$SOU EXPECT'
   V7535   = 'E13A L2YR:JOIND COAL:Y/N?'
   V7536   = 'E13B L2YR:PARTNERSHP:Y/N?'
   V7537   = 'E13C L2YR:MERGED O U:Y/N?'
   V7538   = 'E13D L2YR:PLAN MERGE:Y/N?'
   V7539   = 'E14M1 Y U PLAN 2MERGE'
   V7540   = 'E14M2 Y U PLAN 2MERGE'
   V7541   = 'E15M1 NEC SV NOT OFRD'
   V7542   = 'E15M2 NEC SV NOT OFRD'
   V7543   = 'E16 NEW SA SERV L2YR:Y/N?'
   V7544   = 'E16AM1 DESC NU SA SVC'
   V7545   = 'E16AM2 DESC NU SA SVC'
   V7546   = 'E16AM3 DESC NU SA SVC'
   V7547   = 'E16AM4 DESC NU SA SVC'
   V7548   = 'E17 NU NON-SA SVC 2YR:Y/N?'
   V7549   = 'E17AM1 DESC NU NON-SA'
   V7550   = 'E17AM2 DESC NU NON-SA'
   V7551   = 'E17AM3 DESC NU NON-SA'
   V7552   = 'E17AM4 DESC NU NON-SA'
   V7553   = 'E18 NEW SVC SP SA CL:Y/N?'
   V7554   = 'E18A TYPE NEW SA CL 1'
   V7555   = 'E18B NEW CLTYPE1:SVC1'
   V7556   = 'E18B NEW CLTYPE1:SVC2'
   V7557   = 'E18B NEW CLTYPE1:SVC3'
   V7558   = 'E18A TYPE NEW SA CL 2'
   V7559   = 'E18B NEW CLTYPE2:SVC1'
   V7560   = 'E18B NEW CLTYPE2:SVC2'
   V7561   = 'E18B NEW CLTYPE2:SVC3'
   V7562   = 'E18A TYPE NEW SA CL 3'
   V7563   = 'E18B NEW CLTYPE3:SVC1'
   V7564   = 'E18B NEW CLTYPE3:SVC2'
   V7565   = 'E18B NEW CLTYPE3:SVC3'
   V7566   = 'E18A TYPE NEW SA CL 4'
   V7567   = 'E18B NEW CLTYPE4:SVC1'
   V7568   = 'E18B NEW CLTYPE4:SVC2'
   V7569   = 'E18B NEW CLTYPE4:SVC3'
   V7570   = 'E19 U STOP SP SERV 2Y:Y/N?'
   V7571   = 'E19AM1 SERV U STOPPED'
   V7572   = 'E19AM2 SERV U STOPPED'
   V7573   = 'E19AM3 SERV U STOPPED'
   V7574   = 'E20 U STOP SVC SP CL:Y/N?'
   V7575   = 'E20AM1 SVCSTOP CLTYPE'
   V7576   = 'E20AM2 SVCSTOP CLTYPE'
   V7577   = 'E20AM3 SVCSTOP CLTYPE'
   V7578   = 'E20AM4 SVCSTOP CLTYPE'
   V7579   = 'F1 EXTNT U GETS FOLWUP INFO'
   V7580   = 'F2A 6MOS:%CL CONT USE'
   V7581   = 'F2B 6MOS:%CL DRUGFREE'
   V7582   = 'F3A FOLOW:1-3MO AFT TX'
   V7583   = 'F3B FOLOW:4-6MO AFT TX'
   V7584   = 'F3C FOLOW:7-9MO AFT TX'
   V7585   = 'F3D FOLOW:10-12MO AFT'
   V7586   = 'F3E FOLOW:13-18MO AFT'
   V7587   = 'F3F FOLOW:19-24MO AFT'
   V7588   = 'F3G FOLOW:>24MO AFT TX'
   V7589   = 'F4 FOLOW:EXTNT ALL CL-SUCES'
   V7590   = 'F5A FOLOW:EXTNT LIV SITUATN'
   V7591   = 'F5B FOLOW:EXTNT EMPLOY STAT'
   V7592   = 'F5C FOLOW:EXTNT HEALTH STAT'
   V7593   = 'F5D FOLOW:EXTNT PROBAT STAT'
   V7594   = 'F5E FOLOW:EXTNT FINANC STAT'
   V7595   = 'F5F FOLOW:EXTNT IN RECMD TX'
   V7596   = 'F5G FOLOW:EXTNT DRUG,AL USE'
   V7597   = 'F5H FOLOW:EXTNT CL EVALU TX'
   V7598   = 'F5I FOLLOW:EXTNT CL EVALU U'
   V7599   = 'F5J FOLOW:EXTNT GT DROPS RE'
   V7600   = 'F5KM1 FOLOW:OTHR INFO'
   V7601   = 'F5KM2 FOLOW:OTHR INFO'
   V7602   = 'F5KM3 FOLOW:OTHR INFO'
   V7603   = 'F6A FOLOW:SLF-ADM SUR:Y/N?'
   V7604   = 'F6B FOLLOW-UP: PHONE:Y/N?'
   V7605   = 'F6C FOLOW:FACE 2 FACE:Y/N?'
   V7606   = 'F6DM1 FOLOW:OTH MEANS'
   V7607   = 'F6DM2 FOLOW:OTH MEANS'
   V7608   = 'F6DM3 FOLOW:OTH MEANS'
   V7609   = 'F7 FOLOW:EXTNT USE-COMPAREU'
   V7610   = 'F8 FOLOW:EXTNT USE-CHG PROG'
   V7611   = 'G1A AIDS:EXTNT KNOW-PREVENT'
   V7612   = 'G1B AIDS:EXTNT TEACH CL PRV'
   V7613   = 'G1C AIDS:EXTNT HOW WRK W CL'
   V7614   = 'G1D AIDS:EXTNT STAF RISK-CL'
   V7615   = 'G1E AIDS:EXTNT STAF FEAR CL'
   V7616   = 'G2A AIDS:EXTNT CLEAN NEEDLS'
   V7617   = 'G2B AIDS:EXTNT BLEACH SOLUT'
   V7618   = 'G2C AIDS:EXTNT CONDOMS 2 IV'
   V7619   = 'G2D AIDS:EXTNT EDUCATN 2 IV'
   V7620   = 'G2E AIDS:EXTNT NEEDLE XCHGE'
   V7621   = 'G3A AIDS:EXTNT U ADEQUATE $'
   V7622   = 'G3B AIDS:EXTNT U ENUF STAFF'
   V7623   = 'G3C AIDS:EXTNT TALK CL-SE'
   V7624   = 'G3D AIDS:EXTNT TALK CL-IV'
   V7625   = 'G3E AIDS:EXTNT TALK-CL FETU'
   V7626   = 'G3F AIDS:EXTNT GIV CL READG'
   V7627   = 'G3G AIDS:EXTNT USE MASS MED'
   V7628   = 'G3H AIDS:EXTNT SPECIAL STAF'
   V7629   = 'G4 AIDS:EXTNT WRK W OTH GPS'
   V7630   = 'G5 AIDS:EXTNT COMMUNTY WORK'
   V7631   = 'G6 AIDS:COMUNTY WK-HR'
   V7632   = 'G7 AIDS:SPEC TRAINING:Y/N?'
   V7633   = 'G8A AIDS:INFO-CLEANIV:Y/N?'
   V7634   = 'G8B AIDS:INFO-CONDOMS:Y/N?'
   V7635   = 'G8C AIDS:INFO-PREVENT:Y/N?'
   V7636   = 'G8D AIDS:GIVE CONDOMS:Y/N?'
   V7637   = 'G8E AIDS:GIVE CLEN IV:Y/N?'
   V7638   = 'G8F AIDS: GIVE BLEACH:Y/N?'
   V7639   = 'G8G AIDS:TALK-IVUSERS:Y/N?'
   V7640   = 'G8H AIDS:TALK-IVFAMLY:Y/N?'
   V7641   = 'G8I AIDS:XCHG NEEDLES:Y/N?'
   V7642   = 'H1 IWR CKPT:R THIS SE'
   V7643   = 'H1A IWR CKPT:DEM IN S'
   V7644   = 'H2 #YRS EMPLOYED BY U'
   V7645   = 'H2 #MOS EMPLOYED BY U'
   V7646   = 'H3 #YRS WORK IN FIELD'
   V7647   = 'H3 #MOS WORK IN FIELD'
   V7648   = 'H4 R PRESENT POSITION'
   V7649   = 'H4A #YRS PRES POSITON'
   V7650   = 'G4A #MOS PRES POSITON'
   V7651   = 'H5 WHAT IS YOUR AGE? - CATEGORIZED'
   V7652   = 'H6 ARE YOU MALE/FEM?'
   V7653   = 'H7 RACE - RECODED'
   V7654   = 'H8 RACE: HISPANIC:Y/N?'
   V7655   = 'H9 R:HOURS WORK OSATU'
   V7656   = 'H10A R: HR/WK THERAPY'
   V7657   = 'H10B R:HR/WK SUPRVISE'
   V7658   = 'H11 R:HI GRADE YR SCH'
   V7659   = 'H11A R:PASS HI SCHOOL:Y/N?'
   V7660   = 'H11B R:COLLEGE DEGREE'
   V7661   = 'H11C R: WHAT DEGREE 1'
   V7662   = 'H11D R:DEGREE FIELD 1'
   V7663   = 'H11C R: WHAT DEGREE 2'
   V7664   = 'H11D R:DEGREE FIELD 2'
   V7665   = 'H11C R: WHAT DEGREE 3'
   V7666   = 'H11D R:DEGREE FIELD 3'
   V7667   = 'H11C R: WHAT DEGREE 4'
   V7668   = 'H11D R:DEGREE FIELD 4'
   V7669   = 'H12 R:CERTF SA COUNSL'
   V8004   = 'FS. INTERVIEWERS ID'
   V8005   = 'FS. MONTH BEGAN IW'
   V8006   = 'FS. DAY BEGAN IW'
   V8007   = 'FS. YEAR BEGAN IW'
   V8008   = 'FS. MONTH FINISH IW'
   V8009   = 'FS. DAY FINISH IW'
   V8010   = 'FS. YEAR FINISH IW'
   V8011   = 'FS. IW LENGTH (MINS.)'
   V8012   = 'A1A. EXTENT REF FRM VOC REHAB'
   V8013   = 'A1B. EXTENT REFRL FROM COURTS'
   V8014   = 'A1C. EXTENT REF FRM HOSPITALS'
   V8015   = 'A1D. EXTENT REF FRM MH AGENCY'
   V8016   = 'A1E. EXTENT REFRL FROM EAP'
   V8017   = 'A1F. EXTENT REFRL FROM POLICE'
   V8018   = 'A1G. EXTEMT SELF-REFERRALS'
   V8019   = 'A1H. EXTENT REF CL FRIEND/FAM'
   V8020   = 'A1I.M1 OTHER REFRL FRM M1'
   V8021   = 'A1I.M1 EXTENT OF REFRL FROM M1'
   V8022   = 'A1I.M2 OTHER REFRL FRM M2'
   V8023   = 'A1I.M2 EXTENT OF REFRL FROM M2'
   V8024   = 'A1I.M3 OTHER REFRL FRM M3'
   V8025   = 'A1I.M3 EXTENT OF REFRL FROM M3'
   V8026   = 'A1I.M4 OTHER REFRL FRM M4'
   V8027   = 'A1I.M4 EXTENT OF REFRL FROM M4'
   V8028   = 'A1I.M5 OTHER REFRL FRM M5'
   V8029   = 'A1I.M5 EXTENT OF REFRL FROM M5'
   V8030   = 'A2. MOST IMP REF SOURCE'
   V8031   = 'A3.M1 REASON MOST IMP SOURCE'
   V8032   = 'A3.M2 REASON MOST IMP SOURCE'
   V8033   = 'A4A. EXTENT REFER TO HOSPITAL'
   V8034   = 'A4B. EXTENT REF TO RES T UNIT'
   V8035   = 'A4C. EXTENT REF TO PHYSICIANS'
   V8036   = 'A4D. EXTENT REF TO VOC REHAB'
   V8037   = 'A4E. EXTENT REF TO MH AGENCY'
   V8038   = 'A4F. EXTENT REF TO OTHR OSATU'
   V8039   = 'A4G. EXTENT REFER TO AA, NA'
   V8040   = 'A4H.M1 OTHER REFER TO M1'
   V8041   = 'A4H.M1 EXTENT UNIT REF TO M1'
   V8042   = 'A4H.M2 OTHER REFER TO M2'
   V8043   = 'A4H.M2 EXTENT UNIT REF TO M2'
   V8044   = 'A4H.M3 OTHER REFER TO M3'
   V8045   = 'A4H.M3 EXTENT UNIT REF TO M3'
   V8046   = 'A4H.M4 OTHER REFER TO M4'
   V8047   = 'A4H.M4 EXTENT UNIT REF TO M4'
   V8048   = 'A4H.M5 OTHER REFER TO M5'
   V8049   = 'A4H.M5 EXTENT UNIT REF TO M5'
   V8050   = 'A5. MOST IMP ORG RF TO'
   V8051   = 'A6.M1 REASON MOST IMP RF TO'
   V8052   = 'A6.M2 REASON MOST IMP RF TO'
   V8053   = 'A7A. FREQ SEND WR SUMRY TO REFERRAL'
   V8054   = 'A7B. FREQ SEND CHART TO REFERRAL'
   V8055   = 'A7C. FREQ PHON CASE SUM TO REFERRAL'
   V8056   = 'A7D. FREQ FOLLOW-UP CALL TO REFERRAL'
   V8057   = 'A7E.M1 OTHR PROCED TO REFERRAL M1'
   V8058   = 'A7E.M1 FREQ PROCEDURE M1'
   V8059   = 'A7E.M2 OTHR PROCED TO REFERRAL M2'
   V8060   = 'A7E.M2 FREQ PROCEDURE M2'
   V8061   = 'A7E.M3 OTHR PROCEDURE TO REFERRAL M3'
   V8062   = 'A7E.M3 FREQ PROCEDURE M3'
   V8063   = 'A7E.M4 OTHR PROCED TO REFERRAL M4'
   V8064   = 'A7E.M4 FREQ PROCEDURE M4'
   V8065   = 'A7E.M5 OTHR PROCED TO REFERRAL M5'
   V8066   = 'A7E.M5 FREQ PROCEDURE M5'
   V8067   = 'B1. # F-T PD STAFF CURRENTLY IN OSAT'
   V8068   = 'B1A. # HRS/WK F-T STAFFS CURRLY OSAT'
   V8069   = 'B2. # P-T PD STAFF CURRENTLY IN OSAT'
   V8070   = 'B2A. # HRS/WK P-T STAFFS CURRLY OSAT'
   V8071   = 'B3. # CONSLT&CONTR CURRENTLY IN OSAT'
   V8072   = 'B3A. # HRS/WK CONSLT&CONT CURRLY OSAT'
   V8073   = 'B4A. PERC HRS ALL STAFF:ADMIN WORK'
   V8074   = 'B4B. PERC HRS ALL STAFF:CLER&SUPPRT WK'
   V8075   = 'B5. # HRS/WK BY ALL TX STAFF ON CL TMT'
   V8076   = 'B6A.# TX STAFF WITH PHD'
   V8077   = 'B6B.# TX STAFF WITH PSYCHOLOGY DG'
   V8078   = 'B7A.# TX STAFF WITH MD,DO'
   V8079   = 'B7B.# TX STAFF WI PSYCHIATRY DG'
   V8080   = 'B8A.# TX STAFF WI MASTR DEG'
   V8081   = 'B8B # TX STAFF WI MA PSYCHOLOG DG'
   V8082   = 'B8C # TX STAFF WI MA SOCIAL WK DG'
   V8083   = 'B9A.# TX STAFF WI BA DEG'
   V8084   = 'B10A.# TX STF WI RNS'
   V8085   = 'B11A.# TX STF WITH W ASSOC DEG'
   V8086   = 'B12A.# TX STF WITH HS OR LESS'
   V8087   = 'B13A.# TX STAFF EXADDICTS OR REC ALC'
   V8088   = 'B14A.# TX STAFF HAVE SPEC SAT TRNG'
   V8089   = 'B15A.# TX STAFF HAVE SAT CERTIF'
   V8090   = 'B16A. PERC OSAT BY PHD'
   V8091   = 'B16B. PERC OSAT BY MD,DO'
   V8092   = 'B16C. PERC OSAT BY MASTER'
   V8093   = 'B16D. PERC OSAT BY BA'
   V8094   = 'B16E. PERC OSAT BY OTHER'
   V8095   = 'B17.# OSAT TX STAFF ARE CONSLT&CONTR'
   V8096   = 'B18A.# OSAT TX STAFF C&C ARE PHYSICIANS'
   V8097   = 'B18B.# OSAT TX STAFF C&C ARE PSYC PHDXS'
   V8098   = 'B18C.# OSAT TX STAFF C&C ARE MSW,PSY MA'
   V8099   = 'B19.INTV CHKPT:TMT STAF EXADD/NOT'
   V8100   = 'B20.EXTENT USE EXADICT:PUB IMAGE'
   V8101   = 'B21.EXTENT USE EXADICT:KEEP UP WI FLD'
   V8102   = 'B22.INTV CHKPT:PRO TX ST >=MA/NOT'
   V8103   = 'B23.EXT USE PROF:BY FORML AGREMNT AGY'
   V8104   = 'B23A.PROF STF:SUMMARY # AGY/ORG'
   V8105   = 'B23A.PROF STF: AGY/ORGN NAME M1'
   V8106   = 'B23B.PROF STF: M1 FUNDING AGY:C/N?'
   V8107   = 'B23B PROF STF: M1 LICN/ACCRED:C/N?'
   V8108   = 'B23B PROF STF: M1 REFERRAL AGY:C/N?'
   V8109   = 'B23B PROF STF: M1 TRMT AGY:C/N?'
   V8110   = 'B23C PROF STF: M1 GOVT LEVL'
   V8111   = 'B23A PROF STF: AGY/ORGN NAME M2'
   V8112   = 'B23B PROF STF: M2 FUNDING AGY:C/N?'
   V8113   = 'B23B PROF STF: M2 LICN/ACCRED: C/N?'
   V8114   = 'B23B PROF STF: M2 REFERRAL AGY:C/N?'
   V8115   = 'B23B PROF STF: M2 TREATMT AGY:C/N?'
   V8116   = 'B23C PROF STF: M2 GOVT LEVEL'
   V8117   = 'B23A PROF STF: AGY/ORGN NAME M3'
   V8118   = 'B23B PROF STF: M3 FUNDING AGY:C/N?'
   V8119   = 'B23B PROF STF: M3 LICN/ACCRED:C/N?'
   V8120   = 'B23B PROF STF: M3 REFERRAL AGY:C/N?'
   V8121   = 'B23B PROF STF: M3 TREATMENT AGY: /N?'
   V8122   = 'B23C PROF STF: M3 GOVT LEVEL'
   V8123   = 'B24.EXTENT PROF ST:CONFLICT REQ'
   V8124   = 'B25.EXTENT PROF ST:ORG OFRD INCT'
   V8125   = 'B26.EXTENT PROF ST:COMPLY GOV AGY REGS'
   V8126   = 'B26A.PROF STF:SUMMARY # GOVT AGY NAMES'
   V8127   = 'B26A PROF STF:GV-AGY NAME M1'
   V8128   = 'B26B PROF STF:M1 A FUNDING AGY:C/N?'
   V8129   = 'B26B PROF STF:M1 A LICN/ACCRED AGY:C/N?'
   V8130   = 'B26B PROF STF:M1 A REFERRAL AGY:C/N?'
   V8131   = 'B26C PROF STF:M1 GOVT LEVEL'
   V8132   = 'B26A PROF STF::GV-AGY NAME M2'
   V8133   = 'B26B PROF STF:M2 A FUNDING AGY:C/N?'
   V8134   = 'B26B PROF STF:M2 A LICN/ACCRED AGY:C/N?'
   V8135   = 'B26B PROF STF:M2 A REFERRAL AGY:C/N?'
   V8136   = 'B26C PROF STF:M2 GOVT LEVEL'
   V8137   = 'B26A PROF STF:M3 GV-AGY NAME M3'
   V8138   = 'B26B PROF STF:M3 A FUNDING AGY:C/N?'
   V8139   = 'B26B PROF STF:M3 A LICN/ACCRED AGY:C/N?'
   V8140   = 'B26B PROF STF:M3 A REFERRAL AGY:C/N?'
   V8141   = 'B26C PROF STF:M3 GOVT LEVEL'
   V8142   = 'B27 EXTENT PROF STF:GV-CONFLT REQ'
   V8143   = 'B28 EXTENT PROF STF:ENHANC PUB IMAGE'
   V8144   = 'B29 EXTENT PROF STF:KEEP UP W FLD'
   V8145   = 'B30.AVG # MO CLIN SUPV TRNG BY OT STAFF'
   V8146   = 'B31.FREQ TX-STAFF EVAL ON PERFM'
   V8147   = 'B32.HOW MUCH CASELOAD TOO HI/LOW'
   V8148   = 'B33.# CLIENTS IN TYP CASELOAD F-T STAFF'
   V8149   = 'B34.# CLIENTS IN IDEAL CASELOAD F-T STF'
   V8150   = 'B35A.EXTENT AGREE APLCNT:PROF DEGR'
   V8151   = 'B35B.EXTENT AGREE APLCNT:WORK EXPR'
   V8152   = 'B35C EXTENT AGREE APLCNT:SPECL TRN'
   V8153   = 'B35D EXTENT AGREE APLCNT:HSTY ABUS'
   V8154   = 'B35E EXTENT AGREE APLCNT:CERT CNSL'
   V8155   = 'B35F EXTENT AGREE APLCNT:CLINC EXP'
   V8156   = 'B36A EXTENT AGREE X-AD MORE EFFECT'
   V8157   = 'B36B EXTENT AGREE PROF DEG> EFFECT'
   V8158   = 'B36C EXTENT AGREE X-AD>W CL DENIAL'
   V8159   = 'B36D EXTENT AGREE PROF DEG> OBJECT'
   V8160   = 'B37A EXTENT AGREE ST REWARD-INOVAT'
   V8161   = 'B37B EXTENT AGREE LIMT PROCD CHANG'
   V8162   = 'B37C EXTENT AGREE STAF UNCMF W CHG'
   V8163   = 'B37D EXTENT AGREE ENUF $-NEW PROCD'
   V8164   = 'C1 BEG MO MOST REC FY'
   V8165   = 'C1 BEG DY MOST REC FY'
   V8166   = 'C1 BEG YR MOST REC FY'
   V8167   = 'C1 END MO MOST REC FY'
   V8168   = 'C1 END DY MOST REC FY'
   V8169   = 'C1 END YR MOST REC FY'
   V8170   = 'C2.TOTAL #CL:ANY OP TMT-MRCFY'
   V8171   = 'C3 PERC OP CL:PROB W ALCOHOL'
   V8172   = 'C3A PERC OP CL:ALCH T-REQUIR'
   V8173   = 'C4 PERC OP CL:PROB W DRUG AB'
   V8174   = 'C4A PERC OP CL:DRG T-REQUIRE'
   V8175   = 'C5A PERC OP CL:HEROIN ABUSE'
   V8176   = 'C5B PERC OP CL:NONPESCR METH'
   V8177   = 'C5C PERC OP CL:OPIATE/SYNTH'
   V8178   = 'C5D PERC OP CL:BARBIT/TRANQL'
   V8179   = 'C5E PERC OP CL:OTHR SEDATIVE'
   V8180   = 'C5F PERC OP CL:COCAIN(~CRAK)'
   V8181   = 'C5G PERC OP CL:CRACK ABUSE'
   V8182   = 'C5H PERC OP CL:ICE ABUSE'
   V8183   = 'C5I PERC OP CL:AMPHETAMINES'
   V8184   = 'C5J PERC OP CL:OVER-THE-COUN'
   V8185   = 'C5K PERC OP CL:PRSCRPT DRUGS'
   V8186   = 'C5L PERC OP CL:MARIJUNA/HASH'
   V8187   = 'C5M PERC OP CL:HALLUCINOGENS'
   V8188   = 'C5N PERC OP CL:MULTIPLE DRUG'
   V8189   = 'C5O.OTHR ABUSED DRG NAME M1'
   V8190   = 'C5P. PERC OP CL:ABUSED DRUG M1'
   V8191   = 'C5O.OTHR ABUSED DRG NAME M2'
   V8192   = 'C5P. PERC OP CL:ABUSED DRUG M2'
   V8193   = 'C5O.OTHR ABUSED DRG NAME M3'
   V8194   = 'C5P. PERC OP CL:ABUSED DRUG M3'
   V8195   = 'C5O.OTHR ABUSED DRG NAME M4'
   V8196   = 'C5P. PERC OP CL:ABUSED DRUG M4'
   V8197   = 'SC6 #CL:OSAT-FISCAL YR'
   V8198   = 'SC7A PERC OSAT CL:BLACK NOT HIS'
   V8199   = 'SC7B PERC OSAT CL:WHITE NOT HIS'
   V8200   = 'SC7C PERC OSAT CL:HISPANIC'
   V8201   = 'SC7D PERC OSAT CL:OTHER RACES'
   V8202   = 'SC8A PERC OSAT CL: <20 YRS OLD'
   V8203   = 'SC8B PERC OSAT CL:20-29 YRS OLD'
   V8204   = 'SC8C PERC OSAT CL:30-39 YRS OLD'
   V8205   = 'SC8D PERC OSAT CL:40-49 YRS OLD'
   V8206   = 'SC8E PERC OSAT CL:50-64 YRS OLD'
   V8207   = 'SC8F PERC OSAT CL: >64 YRS OLD'
   V8208   = 'SC9 PERC OSAT CL:MALES-FYR'
   V8209   = 'C10 PERC OSAT CL:USED NEEDLES'
   V8210   = 'C11 PERC OSAT CL:NEEDLES-30DAY'
   V8211   = 'C12A PERC OSAT CL:+ AIDS VIRUS'
   V8212   = 'C12B PERC OSAT CL:DIAGNOS-AIDS'
   V8213   = 'C12C PERC OSAT CL:DIED FR AIDS'
   V8214   = 'C13A PERC OSAT CL:PROSTITUTION'
   V8215   = 'C13B PERC OSAT CL:THEFT/BURGLR'
   V8216   = 'C13C PERC OSAT CL:DEALT DRUGS'
   V8217   = 'C13D PERC OSAT CL:VIOLNT CRIM'
   V8218   = 'C13E OTHR ILEG ACT M1'
   V8219   = 'C13F PERC OSAT CL:ILEG ACT M1'
   V8220   = 'C13E OTHR ILEG ACT M2'
   V8221   = 'C13F PERC OSAT CL:ILEG ACT M2'
   V8222   = 'C13E OTHR ILEG ACT M3'
   V8223   = 'C13F PERC OSAT CL:ILEG ACT M3'
   V8224   = 'C13E OTHR ILEG ACT M4'
   V8225   = 'C13F PERC OSAT CL:ILEG ACT M4'
   V8226   = 'C13E OTHR ILEG ACT M5'
   V8227   = 'C13F PERC OSAT CL:ILEG ACT M5'
   V8228   = 'C14A PERC OSAT CL:INC <$12500'
   V8229   = 'C14B PERC OSAT CL:$12.5-25000'
   V8230   = 'C14C PERC OSAT CL:$ 25K-50000'
   V8231   = 'C14D PERC OSAT CL:INC $50K 0R>'
   V8232   = 'C15  PERC OSAT CL IN MRCFY UNEMPL'
   V8233   = 'C16 #CLIENTS:OSAT LAST 30DY'
   V8234   = 'C17A PERC REC OSAT CL:NO PRIOR TX OTH U'
   V8235   = 'C17B PERC RECENT OSAT CL:PRIOR TX YOUR U'
   V8236   = 'C17C PERC REC OSAT CL:PRIOR TMT OTHR UNT'
   V8237   = 'C18A PERC ALL OSAT CL:ABSTINT 2 YR'
   V8238   = 'C18B PERC ALL OSAT CL:CNTRL USE 2YR'
   V8239   = 'D1 U PROV OUT METH TX:Y/N?'
   V8240   = 'D2 TOTAL # METH CLIENTS IN MRCFY'
   V8241   = 'D2A CURRENT # METHADONE CLIENTS'
   V8242   = 'D3A PERC CURR MX CL: <DOSES METH'
   V8243   = 'D3B PERC CURR MX CL: >DOSES METH'
   V8244   = 'D3C PERC CURR MX CL: =DOSES METH 2 WKS'
   V8245   = 'D4A PERC SAME SIZE MX CL=METH:< 40 MG'
   V8246   = 'D4B PERC SAME SIZE MX CL=METH:40-59 MG'
   V8247   = 'D4C PERC SAME SUZE MX CL=METH:60-79 MG'
   V8248   = 'D4D PERC SAME SIZE MX CL=METH:80-99 MG'
   V8249   = 'D4E PERC SAME SIZE MX CL=METH:=/>100MG'
   V8250   = 'D5A PERC ALL CURR MX CL:CONT METH<3MO'
   V8251   = 'D5B PERC ALL CURR MX CL:METH 3MO-1 YR'
   V8252   = 'D5C PERC ALL CURR MX CL:METH 1YR-2 YR'
   V8253   = 'D5D PERC ALL CURR MX CL:METH 2YR -3YR'
   V8254   = 'D5E PERC ALL CURR MX CL:METH =OR> 3YR'
   V8255   = 'D6A EXTENT CL AWAR METH LEVL'
   V8256   = 'D6B EXTENT CL INFLU METH LVL'
   V8257   = 'D6C EXTENT ALLOW TAK-HM METH'
   V8258   = 'D7  EXTENT ENCOURG METH DETO'
   V8259   = 'D7A AMT TIME UNTIL CLI URGED TO DETOX'
   V8260   = 'D8 HAVE MAX TIME TX WHEN MUST DTOX:Y/N?'
   V8261   = 'D8A AMT TIME UNTIL REQUIRE DTOX'
   V8262   = 'D9 EXTENT SET UPPER LIMIT FOR METH LVL'
   V8263   = 'D9A TYPICAL #MG SET UPPR METH LIMIT'
   V8264   = 'D10 EXT POLICY ON MX DS LV:FORML AGREMNT'
   V8265   = 'D11 EXT POLICY ON MX DS LV:ORG OFR INCEN'
   V8266   = 'D12 EXT POLICY ON MX DS LV:GOV AGY REGS'
   V8267   = 'D12A MX DS LV:SUMMARY # GOVT AGY NAMES'
   V8268   = 'D12A MX DS LV:GOV-AGY M1'
   V8269   = 'D12B MX DS LV:M1 A FUNDING AGY:Y/N?'
   V8270   = 'D12B MX DS LV:M1 A LICN/ACCRED AGY:Y/N?'
   V8271   = 'D12B MX DS LV:M1 A REFERRAL AGY:Y/N?'
   V8272   = 'D12C MX DS LV:GOVT LEVEL M1'
   V8273   = 'D12A MX DS LV:GOV AGY M2'
   V8274   = 'D12B MX DS LV:M2 A FUNDING AGY:Y/N?'
   V8275   = 'D12B MX DS LV:M2 A LICN/ACCRED AGY:Y/N?'
   V8276   = 'D12B MX DS LV:M2 A REFERRAL AGY:Y/N?'
   V8277   = 'D12C MX DS LV:GOVT LEVEL M2'
   V8278   = 'D12A MX DS LV:GOV AGY M3'
   V8279   = 'D12B MX DS LV:M3 A FUNDING AGY:Y/N?'
   V8280   = 'D12B MX DS LV:M3 A LICN/ACCRED AGY:Y/N?'
   V8281   = 'D12B MX DS LV:M3 A REFERRAL AGY:Y/N?'
   V8282   = 'D12C MX DS LV:GOVT LEVEL M3'
   V8283   = 'D13 EXTENT MX DS LV:GOV-CNFLT REQ'
   V8284   = 'D14 EXTENT MX DS LV:ENHNC PUB IMG'
   V8285   = 'D15 EXTENT MX DS LV:KEEP UP W FLD'
   V8286   = 'E1 PERC OSAT CL:OBTAIN DRUG HISTORY'
   V8287   = 'E2 PERC OSAT CL:OBTAIN INFO-PERCEPTN'
   V8288   = 'E3 PERC OSAT CL:DO TEST FOR AIDS'
   V8289   = 'E4 PERC OSAT CL:ASSESS SUPPORT NETWORK'
   V8290   = 'E5 PERC OSAT CL:DO PHYSICAL EXAM'
   V8291   = 'E6 PERC OSAT CL:ASSESS MH PROB'
   V8292   = 'E7 USE PSYCH TESTS WI CL:Y/N/OTHR?'
   V8293   = 'E7A M1 PSYCH TESTS USE'
   V8294   = 'E7A M2 PSYCH TESTS USE'
   V8295   = 'E7A M3 PSYCH TESTS USE'
   V8296   = 'E8 PERC OSAT CL:OBTAIN DSM3 DIAGNOSIS'
   V8297   = 'E9A MAKE DX OF CL-DSM3:PSYCHIATR:Y/N?'
   V8298   = 'E9B MAKE DX OF CL-DSM3:PHYSICIAN:Y/N?'
   V8299   = 'E9C MAKE DX OF CL-DSM3:PSYCHOLOG:Y/N?'
   V8300   = 'E9D MAKE DX OF CL-DSM3:SOC WORKR:Y/N?'
   V8301   = 'E9E MAKE DX OF CL-DSM3: RN:Y/N?'
   V8302   = 'E9F MAKE DX OF CL-DSM3:DR.ASST:Y/N?'
   V8303   = 'E9G MAKE DX OF CL-DSM3: OTHER:Y/N?'
   V8304   = 'E9G WHO MAKES CX OF CL-DSM3:OTHER'
   V8305   = 'E10A EXTENT ASSES:WRITN PROC'
   V8306   = 'E10B EXTENT ASSESMT:STAF TRN'
   V8307   = 'E10C EXTENT ASSESMT:STF EVAL'
   V8308   = 'F1 UNIT OFFR IND THERPY:Y/N?'
   V8309   = 'F1A COMMON TYPES IND THERPY:Y/N?'
   V8310   = 'F1B M1 IND THERPY USED'
   V8311   = 'F1B M2 IND THERPY USED'
   V8312   = 'F1B M3 IND THERPY USED'
   V8313   = 'F1B M4 IND THERPY USED'
   V8314   = 'F1B M5 IND THERPY USED'
   V8315   = 'F1C PERC CURR OSAT CL NOW:IND THERP'
   V8316   = 'F2 PERC CURR OSAT CL NOW:GRP THERPY'
   V8317   = 'F2A IC:F1=NO,F1C=NO/0'
   V8318   = 'F3 PERC CURR OSAT CL:BOTH IND&GP THERPY'
   V8319   = 'F4A PERC OSAT CL:MEDICAL CARE FR UNT/OTH'
   V8320   = 'F4B PERC OSAT CL:TMT-MH PROBS FR UNT/OTH'
   V8321   = 'F4C PERC OSAT CL:TMT-MULT DRG FR UNT/OTH'
   V8322   = 'F4D PERC OSAT CL:EMPLYMT CNSL FR UNT/OTH'
   V8323   = 'F4E PERC OSAT CL:FINANCL CNSL FR UNT/OTH'
   V8324   = 'F4F PERC OSAT CL:LEGAL COUNSL FR UNT/OTH'
   V8325   = 'F4G PERC OSAT CL:DWI PRGRMS FR UNIT/OTHR'
   V8326   = 'F4H PERC OSAT CL:ANTABUSE FROM UNIT/OTHR'
   V8327   = 'F4I PERC OSAT CL:NALTREXONE FR UNIT/OTHR'
   V8328   = 'F5A HAVE SPEC PRGS FOR  WM:Y/N?'
   V8329   = 'F5B #WM IN PRGMS IN TYPICAL WK'
   V8330   = 'F5C M1 PROGRAM CONTENT'
   V8331   = 'F5C M2 PROGRAM CONTENT'
   V8332   = 'F5C M3 PROGRAM CONTENT'
   V8333   = 'F5D HAVE SPEC PRGS FOR PREG WOMEN:Y/N?'
   V8334   = 'F5E # WM IN PRGS IN TYPICAL WEEK'
   V8335   = 'F5F M1 PROGRAM CONTENT'
   V8336   = 'F5F M2 PROGRAM CONTENT'
   V8337   = 'F5F M3 PROGRAM CONTENT'
   V8338   = 'F5G HAVE SPEC PRGS FOR ADOLESCT:Y/N?'
   V8339   = 'F5H # ADOLS IN PRGS IN TYPICAL WEEK'
   V8340   = 'F5I M1 PROGRAM CONTENT'
   V8341   = 'F5I M2 PROGRAM CONTENT'
   V8342   = 'F5I M3 PROGRAM CONTENT'
   V8343   = 'F5J HAVE SPEC PRGS FOR FAMILIES:Y/N?'
   V8344   = 'F5K # PERSONS IN PROGS IN TYP WEEK'
   V8345   = 'F5L M1 PROGRAM CONTENT'
   V8346   = 'F5L M2 PROGRAM CONTENT'
   V8347   = 'F5L M3 PROGRAM CONTENT'
   V8348   = 'F5M HAVE OTHER SPEC PRGS OR GROUPS:Y/N?'
   V8349   = 'F5M M1 TYPE OF CL/GRP'
   V8350   = 'F5N M1 # PERSONS IN PROG/WEEK'
   V8351   = 'F5O M1A PROGRAM CONTENT'
   V8352   = 'F5O M1B PROGRAM CONTENT'
   V8353   = 'F5O M1C PROGRAM CONTENT'
   V8354   = 'F5M M2 TYPE OF CL/GRP'
   V8355   = 'F5N M2 # PERSONS IN PROG/WEEK'
   V8356   = 'F5O M2A PROGRAM CONTENT'
   V8357   = 'F5O M2B PROGRAM CONTENT'
   V8358   = 'F5O M2C PROGRAM CONTENT'
   V8359   = 'F5M M3 TYPE OF CL/GRP'
   V8360   = 'F5N M3 # PERSONS IN PROG/WEEK'
   V8361   = 'F5O M3A PROGRAM CONTENT'
   V8362   = 'F5O M3B PROGRAM CONTENT'
   V8363   = 'F5 OM3C PROGRAM CONTENT'
   V8364   = 'F6 PERC OSAT CL RECV OTHR SERV'
   V8365   = 'F6A M1 WHAT SERVICES'
   V8366   = 'F6B M1 PERCCL:RECV SERVCE'
   V8367   = 'F6A M2 WHAT SERVICES'
   V8368   = 'F6B M2 PERCCL:RECV SERVCE'
   V8369   = 'F6A M3 WHAT SERVICES'
   V8370   = 'F6B M3 PERCCL:RECV SERVCE'
   V8371   = 'F6A M4 WHAT SERVICES'
   V8372   = 'F6B M4 PERCCL:RECV SERVCE'
   V8373   = 'F6A M5 WHAT SERVICES'
   V8374   = 'F6B M5 PERCCL:RECV SERVCE'
   V8375   = 'F7 AVG # MONTHS CLIENTS IN OSAT'
   V8376   = 'F8 CURR MAX # OSAT CL CAN SRV PER WEEK'
   V8377   = 'F9 CURRENT # PEOPLE WAITING OSA TRMT'
   V8378   = 'F9A AVG # DAYS HAVE TO WAIT FOR TMT'
   V8379   = 'F10 EXTENT TX EFFECTV FOR CL ORDR TO TX'
   V8380   = 'F11 EXT AA,NA MODEL EFFTV W SAT CLIENTS'
   V8381   = 'F12 ENCOURGE CL AA,NA:Y/N?'
   V8382   = 'F12A EXTENT AA,NA USED BY OP CLIENTS'
   V8383   = 'F12B EXTENT UNIT URG AA,NA:PUB IM'
   V8384   = 'F12C EXTENT UNIT URG AA,NA:UP FLD'
   V8385   = 'F13 M1 MOST EFFECTV OSAT'
   V8386   = 'F13 M2 MOST EFFECTV OSAT'
   V8387   = 'F13 M3 MOST EFFECTV OSAT'
   V8388   = 'F14 M1 CRITERIA USE TO DETERMINE CL SUC'
   V8389   = 'F14 M2 CRITERIA USE TO DETERMINE CL SUC'
   V8390   = 'F14 M3 CRITERIA USE TO DETERMINE CL SUC'
   V8391   = 'F14 M4 CRITERIA USE TO DETERMINE CL SUC'
   V8392   = 'F14 M5 CRITERIA USE TO DETERMINE CL SUC'
   V8393   = 'F15 PERC OSAT CL:HAVE WRTTN PST-TMT PLN'
   V8394   = 'F16A HOW IMPT CL KNOW IS SUBST ABUSR'
   V8395   = 'F16B HOW IMPT CL ACCEPT RESPNBL RECOV'
   V8396   = 'F16C HOW IMPT CL GAIN INSIGHT'
   V8397   = 'F16D HOW IMPT CL HIT BOTTOM'
   V8398   = 'F17A EXTENT AGREE TX GOAL:ABSTINCE'
   V8399   = 'F17B EXTENT AGREE TX GOAL:RESPNBL USE'
   V8400   = 'F17C EXTENT AGREE TX GOAL:STEADY EMPL'
   V8401   = 'F17D EXTENT AGREE TX GOAL:+PHY HEALTH'
   V8402   = 'F17E EXTENT AGREE TX GOAL:SPIRIT STRN'
   V8403   = 'F17F EXTENT AGREE TX GOAL:MET LEG REQ'
   V8404   = 'F18 EXTENT CL PARTIC IN ESTAB TX GOALS'
   V8405   = 'F19 EXT UNT HAS COMPLTE ABSTNCE TX GOAL'
   V8406   = 'F19A EXTENT ABSTINCE:GOV REG'
   V8407   = 'F19B EXTENT ABSTINCE:PUB IMG'
   V8408   = 'F19C EXTENT ABSTINCE:UP FLD'
   V8409   = 'F20 EXTENT DIFFIC TO CONTACT AFTER HRS'
   V8410   = 'F21A EXTENT MONITOR:CL RECRD'
   V8411   = 'F21B EXTENT MONTR:SLF-REPORT'
   V8412   = 'F21C EXTENT MONTR:URINE TEST'
   V8413   = 'F21D EXTENT MONTR:SIGO REPRT'
   V8414   = 'F21E EXTENT MONTR:THERP EVAL'
   V8415   = 'F21F EXTENT MONTR:EMPL REPRT'
   V8416   = 'F21G EXTENT MONTR:COURT OFIC'
   V8417   = 'F21H M1 MONTR:OTH METH'
   V8418   = 'F21H M1  EXT OTHR MONTR'
   V8419   = 'F21H M2 MONTR:OTH METH'
   V8420   = 'F21H M2  EXT OTHR MONTR'
   V8421   = 'F21H M3 MONTR:OTH METH'
   V8422   = 'F21 HM3  EXT OTHR MONTR'
   V8423   = 'F22 EXTENT MUST MEET CONDTNS:REMAIN TP'
   V8424   = 'F22A EXTENT CONDTN:SOBRIETY'
   V8425   = 'F22B EXTENT CONDTN:COMPLY-TX'
   V8426   = 'F22C EXTENT COND:CMPLY-COURT'
   V8427   = 'F22D M1 OTHR CONDITION'
   V8428   = 'F22D M1  EXT OTHR CONDT'
   V8429   = 'F22D M2 OTHR CONDITION'
   V8430   = 'F22D M2  EXT OTHR CONDT'
   V8431   = 'F22D M3 OTHR CONDITION'
   V8432   = 'F22D M3  EXT OTHR CONDT'
   V8433   = 'F23 HAVE WRITTEN QUAL ASURNC PLN:Y/N?'
   V8434   = 'F23A EXTENT BASED ON JCAHCO STANDARDS'
   V8435   = 'F24A EXTENT REVU:T PLAN ADDR'
   V8436   = 'F24B EXTENT REVU:REFERS MADE'
   V8437   = 'F24C EXTENT REVU:CHANGE TRMT'
   V8438   = 'F24D EXTENT REVU:TRMT DURATN'
   V8439   = 'F24E EXTENT REVU:DOC T PROBS'
   V8440   = 'F24F EXTENT REVU:DISCHG PLAN'
   V8441   = 'F24G EXTENT REVU:CPLNT RESLV'
   V8442   = 'F25A CL END T:PERC CMPT TX'
   V8443   = 'F25B CL END T:PERC NOT CMP TX'
   V8444   = 'F25C CL END T:PERC DROP TX'
   V8445   = 'F25D CL END T:PERC DRGFREE'
   V8446   = 'F25E CL END T:PERC CNTRL USE'
   V8447   = 'F25F CL END T:PERC CONT ABUSE'
   V8448   = 'F25G CL END T:PERC FAIL TO PAY'
   V8449   = 'F25H CL END T:PERC EXHAUSTED INS'
   V8450   = 'F25I CL END T:PERC TRNSFR OTHR UNIT/PRG'
   V8451   = 'F25J M1 CL END T:OTH-REASON'
   V8452   = 'F25J M1 CL END T:PERC OTHR'
   V8453   = 'F25J M2 CL END T:OTH-REASON'
   V8454   = 'F25J M2 CL END T:PERC OTHR'
   V8455   = 'F25J M3 CL END T:OTH-REASON'
   V8456   = 'F25J M3 CL END T:PERC OTHR'
   V8457   = 'F26 CL END T:PERC ENDED INVOLNTY'
   V8458   = 'F27 CL END T:PERC MET GOALS OF TX'
   V8459   = 'G1 PERC OF OSAT CL MRCFY:COURT-ORD TX'
   V8460   = 'G2A PERC CT-ORD CL CHARGED WITH DWI/DUI'
   V8461   = 'G2B PERC CT-ORD CL CHARGED WITH VIOLENCE'
   V8462   = 'G2C PERC CT-ORD CL CHRGED W DRUNK,DISORD'
   V8463   = 'G2D PERC CT-ORD CL CHRGED W DRUG DEALING'
   V8464   = 'G2E M1 OTHER OFFENSE'
   V8465   = 'G2E M1 PERC CT-ORD CL CHARGED W OFFENSE'
   V8466   = 'G2E M2 OTHER OFFENSE'
   V8467   = 'G2E M2 PERC CT-ORD CL CHARGED W OFFENCE'
   V8468   = 'G2E M3 OTHER OFFENSE'
   V8469   = 'G2E M3 PERC CT-ORD CL CHARGED W OFFENCE'
   V8470   = 'G3 PERC CT-ORD CL MRCFY:PROB W ALCHL ABU'
   V8471   = 'G4 PERC CT-ORD CL MRCFY:PROB W DRUG ABUS'
   V8472   = 'G5A PERC CT-ORD CL END TX:BEC MET GOALS'
   V8473   = 'G5B PERC CT-ORD CL END TX:BEC ABSTINENT'
   V8474   = 'G5C PERC CT-ORD CL END TX:BEC FAIL COMPL'
   V8475   = 'G6 INTV CHKPT:ALL CL CRT-ORDR/NOT'
   V8476   = 'G7A EXTENT CO MR HOSTILE THAN NON-C0'
   V8477   = 'G7B EXTENT CO MR COMPLIANT THAN NON-CO'
   V8478   = 'G7C EXTENT CO MR MOTIVATED THAN NON-CO'
   V8479   = 'G7D EXT CO MR MANIPULATIVE THAN NON-CO'
   V8480   = 'G7E EXTENT CO MR SUSPICIOUS THAN NON-CO'
   V8481   = 'G7F EXTENT CO MR FRIGHTENED THAN NON-CO'
   V8482   = 'G7G EXTENT CO MR SECRETIVE THAN NON-CO'
   V8483   = 'G7H EXT CO MR UNHAPPY AT TX THAN NON-CO'
   V8484   = 'G8A EXT AGR ABSTNNCE IMPT GOAL FOR CO CL'
   V8485   = 'G8B EXT AGR RESPN USE IMPT GOAL FOR CO C'
   V8486   = 'G8C EXT AGR CRME REDUC IMPT GOAL F CO CL'
   V8487   = 'G8D EXT AGR STEADY EMP IMPT GOAL F CO CL'
   V8488   = 'G8E EXT AGR +PHY HLTH IMPT GOAL FOR CO C'
   V8489   = 'G8F EXT AGR IMP SPRT STR IMPT GOAL F CO'
   V8490   = 'G8G EXT AGR MTG LEGL REQ IMPT GOAL F CO'
   V8491   = 'G9A EXT CO CL HVE CNTRL:WHICH THERAPIST'
   V8492   = 'G9B EXT CO CL HVE CNTRL:WHETHER MEDCATN'
   V8493   = 'G9C EXT CO CL HVE CNTRL:WHETHER CLIN TST'
   V8494   = 'G9D EXT CO CL HVE CNTRL:WHETHER EMPLOYER'
   V8495   = 'G9E EXT CO CL HVE CNTRL:# TX SESSIONS'
   V8496   = 'G9F EXT CO CL HVE CNTRL:WHICH TX GOALS'
   V8497   = 'G9G EXT CO CL HVE CNTRL:INFO TO COURT'
   V8498   = 'G9H EXT CO CL HVE CNTRL:IF REMAIN IN TX'
   V8499   = 'G9I EXT CO CL HVE CNTRL:IF EMPLOYERS INF'
   V8500   = 'G10A EXT EDUC STAFF ON SPEC PROBS CO CL'
   V8501   = 'G10B EXT CLIN SUPV ADDRESS PROBS CO CL'
   V8502   = 'G10C EXT DISCUSS DIFFIC TX-REL W CO CL'
   V8503   = 'G10D EXT CLIN SUPV CAN REASSIGN THERPST'
   V8504   = 'G10E EXT TELL CO CL INFO GIVEN TO COURT'
   V8505   = 'G10F EXT INVITE FAM MMBERS PARTCIPTE IN'
   V8506   = 'G11A EXT BELEVE CO TX HLPS CL MOTVATION'
   V8507   = 'G11B EXT BELEVE CO TX HLPS THERAP RELTN'
   V8508   = 'G11C EXT BELEVE CO TX HLPS CL REMAIN TX'
   V8509   = 'G11D EXT BELEVE CO TX HLPS OVRCME CL DEN'
   V8510   = 'G11E EXT BELEVE CO TX HLPS MEET PRSNL GO'
   V8511   = 'G11F EXT BELEVE CO TX HLPS MAINT ABST'
   V8512   = 'G11G EXT BELEVE CO TX HLPS COUNS EFFVEN'
   V8513   = 'G12A EXT BELEVE CO TX HLPS STAFF MORALE'
   V8514   = 'G12B EXT BELEVE CO TX HLPS +STAFF ATTDL'
   V8515   = 'G12C EXT BELEVE CO TX HLPS COUNS FEEL GD'
   V8516   = 'G12D EXT BELEVE CO TX HLPS STFF COMMT'
   V8517   = 'H0 INTV CHKPT:DEMOGRPH IN DIR/NOT'
   V8518   = 'H1 #YRS:EMPLOYED BY UNIT'
   V8519   = 'H1 #MOS:EMPLOYED BY UNIT'
   V8520   = 'H2 #YRS:WORK IN FIELD OF SA OR MH'
   V8521   = 'H2 #MOS:WORK IN FIELD OF SA OR MH'
   V8522   = 'H3 PRSNT POSN,JOB TITLE'
   V8523   = 'H3A #YR:PRSNT POSITON'
   V8524   = 'H3A #MO:PRSNT POSITON'
   V8525   = 'H4 RESPONDENTS AGE? - CATEGORIZED'
   V8526   = 'H5 RESPONDENTS GENDER: MALE/FEM:M/NM?'
   V8527   = 'H6 RACE - RECODED'
   V8528   = 'H7 RESPONDENTS HISPANIC ORIGIN:Y/N?'
   V8529   = 'H8 TYPICAL # HR/WK WORK-OSATU'
   V8530   = 'H9A # HRS/WK-PROVIDINGTHERAPY'
   V8531   = 'H9B # HRS/WK-DIRECTLY SUPRVISNG'
   V8532   = 'H10 HIGHEST GRADE/YR SCH'
   V8533   = 'H10A HIGH SCHOL/GED:Y/N?'
   V8534   = 'H10B COLLEGE DEGREE:Y/N?'
   V8535   = 'H10C M1 R:WHAT DEGREE'
   V8536   = 'H10D M1 R:DEGREE FIELD'
   V8537   = 'H10C M2 R:WHAT DEGREE'
   V8538   = 'H10D M2 R:DEGREE FIELD'
   V8539   = 'H10C M3 R:WHAT DEGREE'
   V8540   = 'H10D M3 R:DEGREE FIELD'
   V8541   = 'H10C M4 R:WHAT DEGREE'
   V8542   = 'H10D M4 R:DEGREE FIELD'
   V8543   = 'H11 CERTF SA COUNSL:Y/N?'
   V9118   = 'SMP:TRIMMED.WEIGHTS'
   V9119   = 'SMP:CENTERED.WEIGHTS'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (V7004 >= -5 AND V7004 <= -1) THEN V7004 = .;
   IF (V7005 >= -5 AND V7005 <= -1) THEN V7005 = .;
   IF (V7006 >= -5 AND V7006 <= -1) THEN V7006 = .;
   IF (V7007 >= -5 AND V7007 <= -1) THEN V7007 = .;
   IF (V7008 >= -5 AND V7008 <= -1) THEN V7008 = .;
   IF (V7009 >= -5 AND V7009 <= -1) THEN V7009 = .;
   IF (V7010 >= -5 AND V7010 <= -1) THEN V7010 = .;
   IF (V7011 >= -5 AND V7011 <= -1) THEN V7011 = .;
   IF (V7012 >= -5 AND V7012 <= -1) THEN V7012 = .;
   IF (V7013 >= -5 AND V7013 <= -1) THEN V7013 = .;
   IF (V7014 >= -5 AND V7014 <= -1) THEN V7014 = .;
   IF (V7015 >= -5 AND V7015 <= -1) THEN V7015 = .;
   IF (V7016 >= -5 AND V7016 <= -1) THEN V7016 = .;
   IF (V7017 >= -5 AND V7017 <= -1) THEN V7017 = .;
   IF (V7018 >= -5 AND V7018 <= -1) THEN V7018 = .;
   IF (V7019 >= -5 AND V7019 <= -1) THEN V7019 = .;
   IF (V7020 >= -5 AND V7020 <= -1) THEN V7020 = .;
   IF (V7021 >= -5 AND V7021 <= -1) THEN V7021 = .;
   IF (V7022 >= -5 AND V7022 <= -1) THEN V7022 = .;
   IF (V7023 >= -5 AND V7023 <= -1) THEN V7023 = .;
   IF (V7024 >= -5 AND V7024 <= -1) THEN V7024 = .;
   IF (V7025 >= -5 AND V7025 <= -1) THEN V7025 = .;
   IF (V7026 >= -5 AND V7026 <= -1) THEN V7026 = .;
   IF (V7027 >= -5 AND V7027 <= -1) THEN V7027 = .;
   IF (V7028 >= -5 AND V7028 <= -1) THEN V7028 = .;
   IF (V7029 >= -5 AND V7029 <= -1) THEN V7029 = .;
   IF (V7030 >= -5 AND V7030 <= -1) THEN V7030 = .;
   IF (V7031 >= -5 AND V7031 <= -1) THEN V7031 = .;
   IF (V7032 >= -5 AND V7032 <= -1) THEN V7032 = .;
   IF (V7033 >= -5 AND V7033 <= -1) THEN V7033 = .;
   IF (V7034 >= -5 AND V7034 <= -1) THEN V7034 = .;
   IF (V7035 >= -5 AND V7035 <= -1) THEN V7035 = .;
   IF (V7036 >= -5 AND V7036 <= -1) THEN V7036 = .;
   IF (V7037 >= -5 AND V7037 <= -1) THEN V7037 = .;
   IF (V7038 >= -5 AND V7038 <= -1) THEN V7038 = .;
   IF (V7039 >= -5 AND V7039 <= -1) THEN V7039 = .;
   IF (V7040 >= -5 AND V7040 <= -1) THEN V7040 = .;
   IF (V7041 >= -5 AND V7041 <= -1) THEN V7041 = .;
   IF (V7042 >= -5 AND V7042 <= -1) THEN V7042 = .;
   IF (V7043 >= -5 AND V7043 <= -1) THEN V7043 = .;
   IF (V7044 >= -5 AND V7044 <= -1) THEN V7044 = .;
   IF (V7045 >= -5 AND V7045 <= -1) THEN V7045 = .;
   IF (V7046 >= -5 AND V7046 <= -1) THEN V7046 = .;
   IF (V7047 >= -5 AND V7047 <= -1) THEN V7047 = .;
   IF (V7048 >= -5 AND V7048 <= -1) THEN V7048 = .;
   IF (V7049 >= -5 AND V7049 <= -1) THEN V7049 = .;
   IF (V7050 >= -5 AND V7050 <= -1) THEN V7050 = .;
   IF (V7051 >= -5 AND V7051 <= -1) THEN V7051 = .;
   IF (V7052 >= -5 AND V7052 <= -1) THEN V7052 = .;
   IF (V7053 >= -5 AND V7053 <= -1) THEN V7053 = .;
   IF (V7054 >= -5 AND V7054 <= -1) THEN V7054 = .;
   IF (V7055 >= -5 AND V7055 <= -1) THEN V7055 = .;
   IF (V7056 >= -5 AND V7056 <= -1) THEN V7056 = .;
   IF (V7057 >= -5 AND V7057 <= -1) THEN V7057 = .;
   IF (V7058 >= -5 AND V7058 <= -1) THEN V7058 = .;
   IF (V7059 >= -5 AND V7059 <= -1) THEN V7059 = .;
   IF (V7060 >= -5 AND V7060 <= -1) THEN V7060 = .;
   IF (V7061 >= -5 AND V7061 <= -1) THEN V7061 = .;
   IF (V7062 >= -5 AND V7062 <= -1) THEN V7062 = .;
   IF (V7063 >= -5 AND V7063 <= -1) THEN V7063 = .;
   IF (V7064 >= -5 AND V7064 <= -1) THEN V7064 = .;
   IF (V7065 >= -5 AND V7065 <= -1) THEN V7065 = .;
   IF (V7066 >= -5 AND V7066 <= -1) THEN V7066 = .;
   IF (V7067 >= -5 AND V7067 <= -1) THEN V7067 = .;
   IF (V7068 >= -5 AND V7068 <= -1) THEN V7068 = .;
   IF (V7069 >= -5 AND V7069 <= -1) THEN V7069 = .;
   IF (V7070 >= -5 AND V7070 <= -1) THEN V7070 = .;
   IF (V7071 >= -5 AND V7071 <= -1) THEN V7071 = .;
   IF (V7072 >= -5 AND V7072 <= -1) THEN V7072 = .;
   IF (V7073 >= -5 AND V7073 <= -1) THEN V7073 = .;
   IF (V7074 >= -5 AND V7074 <= -1) THEN V7074 = .;
   IF (V7075 >= -5 AND V7075 <= -1) THEN V7075 = .;
   IF (V7076 >= -5 AND V7076 <= -1) THEN V7076 = .;
   IF (V7077 >= -5 AND V7077 <= -1) THEN V7077 = .;
   IF (V7078 >= -5 AND V7078 <= -1) THEN V7078 = .;
   IF (V7079 >= -5 AND V7079 <= -1) THEN V7079 = .;
   IF (V7080 >= -5 AND V7080 <= -1) THEN V7080 = .;
   IF (V7081 >= -5 AND V7081 <= -1) THEN V7081 = .;
   IF (V7082 >= -5 AND V7082 <= -1) THEN V7082 = .;
   IF (V7083 >= -5 AND V7083 <= -1) THEN V7083 = .;
   IF (V7084 >= -5 AND V7084 <= -1) THEN V7084 = .;
   IF (V7085 >= -5 AND V7085 <= -1) THEN V7085 = .;
   IF (V7086 >= -5 AND V7086 <= -1) THEN V7086 = .;
   IF (V7087 >= -5 AND V7087 <= -1) THEN V7087 = .;
   IF (V7088 >= -5 AND V7088 <= -1) THEN V7088 = .;
   IF (V7089 >= -5 AND V7089 <= -1) THEN V7089 = .;
   IF (V7090 >= -5 AND V7090 <= -1) THEN V7090 = .;
   IF (V7091 >= -5 AND V7091 <= -1) THEN V7091 = .;
   IF (V7092 >= -5 AND V7092 <= -1) THEN V7092 = .;
   IF (V7093 >= -5 AND V7093 <= -1) THEN V7093 = .;
   IF (V7094 >= -5 AND V7094 <= -1) THEN V7094 = .;
   IF (V7095 >= -5 AND V7095 <= -1) THEN V7095 = .;
   IF (V7096 >= -5 AND V7096 <= -1) THEN V7096 = .;
   IF (V7097 >= -5 AND V7097 <= -1) THEN V7097 = .;
   IF (V7098 >= -5 AND V7098 <= -1) THEN V7098 = .;
   IF (V7099 >= -5 AND V7099 <= -1) THEN V7099 = .;
   IF (V7100 >= -5 AND V7100 <= -1) THEN V7100 = .;
   IF (V7101 >= -5 AND V7101 <= -1) THEN V7101 = .;
   IF (V7102 >= -5 AND V7102 <= -1) THEN V7102 = .;
   IF (V7103 >= -5 AND V7103 <= -1) THEN V7103 = .;
   IF (V7104 >= -5 AND V7104 <= -1) THEN V7104 = .;
   IF (V7105 >= -5 AND V7105 <= -1) THEN V7105 = .;
   IF (V7106 >= -5 AND V7106 <= -1) THEN V7106 = .;
   IF (V7107 >= -5 AND V7107 <= -1) THEN V7107 = .;
   IF (V7108 >= -5 AND V7108 <= -1) THEN V7108 = .;
   IF (V7109 >= -5 AND V7109 <= -1) THEN V7109 = .;
   IF (V7110 >= -5 AND V7110 <= -1) THEN V7110 = .;
   IF (V7111 >= -5 AND V7111 <= -1) THEN V7111 = .;
   IF (V7112 >= -5 AND V7112 <= -1) THEN V7112 = .;
   IF (V7113 >= -5 AND V7113 <= -1) THEN V7113 = .;
   IF (V7114 >= -5 AND V7114 <= -1) THEN V7114 = .;
   IF (V7115 >= -5 AND V7115 <= -1) THEN V7115 = .;
   IF (V7116 >= -5 AND V7116 <= -1) THEN V7116 = .;
   IF (V7117 >= -5 AND V7117 <= -1) THEN V7117 = .;
   IF (V7118 >= -5 AND V7118 <= -1) THEN V7118 = .;
   IF (V7119 >= -5 AND V7119 <= -1) THEN V7119 = .;
   IF (V7120 >= -5 AND V7120 <= -1) THEN V7120 = .;
   IF (V7121 >= -5 AND V7121 <= -1) THEN V7121 = .;
   IF (V7122 >= -5 AND V7122 <= -1) THEN V7122 = .;
   IF (V7123 >= -5 AND V7123 <= -1) THEN V7123 = .;
   IF (V7124 >= -5 AND V7124 <= -1) THEN V7124 = .;
   IF (V7125 >= -5 AND V7125 <= -1) THEN V7125 = .;
   IF (V7126 >= -5 AND V7126 <= -1) THEN V7126 = .;
   IF (V7127 >= -5 AND V7127 <= -1) THEN V7127 = .;
   IF (V7128 >= -5 AND V7128 <= -1) THEN V7128 = .;
   IF (V7129 >= -5 AND V7129 <= -1) THEN V7129 = .;
   IF (V7130 >= -5 AND V7130 <= -1) THEN V7130 = .;
   IF (V7131 >= -5 AND V7131 <= -1) THEN V7131 = .;
   IF (V7132 >= -5 AND V7132 <= -1) THEN V7132 = .;
   IF (V7133 >= -5 AND V7133 <= -1) THEN V7133 = .;
   IF (V7134 >= -5 AND V7134 <= -1) THEN V7134 = .;
   IF (V7135 >= -5 AND V7135 <= -1) THEN V7135 = .;
   IF (V7136 >= -5 AND V7136 <= -1) THEN V7136 = .;
   IF (V7137 >= -5 AND V7137 <= -1) THEN V7137 = .;
   IF (V7138 >= -5 AND V7138 <= -1) THEN V7138 = .;
   IF (V7139 >= -5 AND V7139 <= -1) THEN V7139 = .;
   IF (V7140 >= -5 AND V7140 <= -1) THEN V7140 = .;
   IF (V7141 >= -5 AND V7141 <= -1) THEN V7141 = .;
   IF (V7142 >= -5 AND V7142 <= -1) THEN V7142 = .;
   IF (V7143 >= -5 AND V7143 <= -1) THEN V7143 = .;
   IF (V7144 >= -5 AND V7144 <= -1) THEN V7144 = .;
   IF (V7145 >= -5 AND V7145 <= -1) THEN V7145 = .;
   IF (V7146 >= -5 AND V7146 <= -1) THEN V7146 = .;
   IF (V7147 >= -5 AND V7147 <= -1) THEN V7147 = .;
   IF (V7148 >= -5 AND V7148 <= -1) THEN V7148 = .;
   IF (V7149 >= -5 AND V7149 <= -1) THEN V7149 = .;
   IF (V7150 >= -5 AND V7150 <= -1) THEN V7150 = .;
   IF (V7151 >= -5 AND V7151 <= -1) THEN V7151 = .;
   IF (V7152 >= -5 AND V7152 <= -1) THEN V7152 = .;
   IF (V7153 >= -5 AND V7153 <= -1) THEN V7153 = .;
   IF (V7154 >= -5 AND V7154 <= -1) THEN V7154 = .;
   IF (V7155 >= -5 AND V7155 <= -1) THEN V7155 = .;
   IF (V7156 >= -5 AND V7156 <= -1) THEN V7156 = .;
   IF (V7157 >= -5 AND V7157 <= -1) THEN V7157 = .;
   IF (V7158 >= -5 AND V7158 <= -1) THEN V7158 = .;
   IF (V7159 >= -5 AND V7159 <= -1) THEN V7159 = .;
   IF (V7160 >= -5 AND V7160 <= -1) THEN V7160 = .;
   IF (V7161 >= -5 AND V7161 <= -1) THEN V7161 = .;
   IF (V7162 >= -5 AND V7162 <= -1) THEN V7162 = .;
   IF (V7163 >= -5 AND V7163 <= -1) THEN V7163 = .;
   IF (V7164 >= -5 AND V7164 <= -1) THEN V7164 = .;
   IF (V7165 >= -5 AND V7165 <= -1) THEN V7165 = .;
   IF (V7166 >= -5 AND V7166 <= -1) THEN V7166 = .;
   IF (V7167 >= -5 AND V7167 <= -1) THEN V7167 = .;
   IF (V7168 >= -5 AND V7168 <= -1) THEN V7168 = .;
   IF (V7169 >= -5 AND V7169 <= -1) THEN V7169 = .;
   IF (V7170 >= -5 AND V7170 <= -1) THEN V7170 = .;
   IF (V7171 >= -5 AND V7171 <= -1) THEN V7171 = .;
   IF (V7172 >= -5 AND V7172 <= -1) THEN V7172 = .;
   IF (V7173 >= -5 AND V7173 <= -1) THEN V7173 = .;
   IF (V7174 >= -5 AND V7174 <= -1) THEN V7174 = .;
   IF (V7175 >= -5 AND V7175 <= -1) THEN V7175 = .;
   IF (V7176 >= -5 AND V7176 <= -1) THEN V7176 = .;
   IF (V7177 >= -5 AND V7177 <= -1) THEN V7177 = .;
   IF (V7178 >= -5 AND V7178 <= -1) THEN V7178 = .;
   IF (V7179 >= -5 AND V7179 <= -1) THEN V7179 = .;
   IF (V7180 >= -5 AND V7180 <= -1) THEN V7180 = .;
   IF (V7181 >= -5 AND V7181 <= -1) THEN V7181 = .;
   IF (V7182 >= -5 AND V7182 <= -1) THEN V7182 = .;
   IF (V7183 >= -5 AND V7183 <= -1) THEN V7183 = .;
   IF (V7184 >= -5 AND V7184 <= -1) THEN V7184 = .;
   IF (V7185 >= -5 AND V7185 <= -1) THEN V7185 = .;
   IF (V7186 >= -5 AND V7186 <= -1) THEN V7186 = .;
   IF (V7187 >= -5 AND V7187 <= -1) THEN V7187 = .;
   IF (V7188 >= -5 AND V7188 <= -1) THEN V7188 = .;
   IF (V7189 >= -5 AND V7189 <= -1) THEN V7189 = .;
   IF (V7190 >= -5 AND V7190 <= -1) THEN V7190 = .;
   IF (V7191 >= -5 AND V7191 <= -1) THEN V7191 = .;
   IF (V7192 >= -5 AND V7192 <= -1) THEN V7192 = .;
   IF (V7193 >= -5 AND V7193 <= -1) THEN V7193 = .;
   IF (V7194 >= -5 AND V7194 <= -1) THEN V7194 = .;
   IF (V7195 >= -5 AND V7195 <= -1) THEN V7195 = .;
   IF (V7196 >= -5 AND V7196 <= -1) THEN V7196 = .;
   IF (V7197 >= -5 AND V7197 <= -1) THEN V7197 = .;
   IF (V7198 >= -5 AND V7198 <= -1) THEN V7198 = .;
   IF (V7199 >= -5 AND V7199 <= -1) THEN V7199 = .;
   IF (V7200 >= -5 AND V7200 <= -1) THEN V7200 = .;
   IF (V7201 >= -5 AND V7201 <= -1) THEN V7201 = .;
   IF (V7202 >= -5 AND V7202 <= -1) THEN V7202 = .;
   IF (V7203 >= -5 AND V7203 <= -1) THEN V7203 = .;
   IF (V7204 >= -5 AND V7204 <= -1) THEN V7204 = .;
   IF (V7205 >= -5 AND V7205 <= -1) THEN V7205 = .;
   IF (V7206 >= -5 AND V7206 <= -1) THEN V7206 = .;
   IF (V7207 >= -5 AND V7207 <= -1) THEN V7207 = .;
   IF (V7208 >= -5 AND V7208 <= -1) THEN V7208 = .;
   IF (V7209 >= -5 AND V7209 <= -1) THEN V7209 = .;
   IF (V7210 >= -5 AND V7210 <= -1) THEN V7210 = .;
   IF (V7211 >= -5 AND V7211 <= -1) THEN V7211 = .;
   IF (V7212 >= -5 AND V7212 <= -1) THEN V7212 = .;
   IF (V7213 >= -5 AND V7213 <= -1) THEN V7213 = .;
   IF (V7214 >= -5 AND V7214 <= -1) THEN V7214 = .;
   IF (V7215 >= -5 AND V7215 <= -1) THEN V7215 = .;
   IF (V7216 >= -5 AND V7216 <= -1) THEN V7216 = .;
   IF (V7217 >= -5 AND V7217 <= -1) THEN V7217 = .;
   IF (V7218 >= -5.00 AND V7218 <= -1.00) THEN V7218 = .;
   IF (V7219 >= -5 AND V7219 <= -1) THEN V7219 = .;
   IF (V7220 >= -5 AND V7220 <= -1) THEN V7220 = .;
   IF (V7221 >= -5 AND V7221 <= -1) THEN V7221 = .;
   IF (V7222 >= -5 AND V7222 <= -1) THEN V7222 = .;
   IF (V7223 >= -5 AND V7223 <= -1) THEN V7223 = .;
   IF (V7224 >= -5 AND V7224 <= -1) THEN V7224 = .;
   IF (V7225 >= -5 AND V7225 <= -1) THEN V7225 = .;
   IF (V7226 >= -5 AND V7226 <= -1) THEN V7226 = .;
   IF (V7227 >= -5 AND V7227 <= -1) THEN V7227 = .;
   IF (V7228 >= -5 AND V7228 <= -1) THEN V7228 = .;
   IF (V7229 >= -5 AND V7229 <= -1) THEN V7229 = .;
   IF (V7230 >= -5 AND V7230 <= -1) THEN V7230 = .;
   IF (V7231 >= -5 AND V7231 <= -1) THEN V7231 = .;
   IF (V7232 >= -5 AND V7232 <= -1) THEN V7232 = .;
   IF (V7233 >= -5 AND V7233 <= -1) THEN V7233 = .;
   IF (V7234 >= -5 AND V7234 <= -1) THEN V7234 = .;
   IF (V7235 >= -5 AND V7235 <= -1) THEN V7235 = .;
   IF (V7236 >= -5 AND V7236 <= -1) THEN V7236 = .;
   IF (V7237 >= -5.00 AND V7237 <= -1.00) THEN V7237 = .;
   IF (V7238 >= -5 AND V7238 <= -1) THEN V7238 = .;
   IF (V7239 >= -5 AND V7239 <= -1) THEN V7239 = .;
   IF (V7240 >= -5 AND V7240 <= -1) THEN V7240 = .;
   IF (V7241 >= -5 AND V7241 <= -1) THEN V7241 = .;
   IF (V7242 >= -5 AND V7242 <= -1) THEN V7242 = .;
   IF (V7243 >= -5 AND V7243 <= -1) THEN V7243 = .;
   IF (V7244 >= -5 AND V7244 <= -1) THEN V7244 = .;
   IF (V7245 >= -5 AND V7245 <= -1) THEN V7245 = .;
   IF (V7246 >= -5 AND V7246 <= -1) THEN V7246 = .;
   IF (V7247 >= -5 AND V7247 <= -1) THEN V7247 = .;
   IF (V7248 >= -5 AND V7248 <= -1) THEN V7248 = .;
   IF (V7249 >= -5 AND V7249 <= -1) THEN V7249 = .;
   IF (V7250 >= -5 AND V7250 <= -1) THEN V7250 = .;
   IF (V7251 >= -5 AND V7251 <= -1) THEN V7251 = .;
   IF (V7252 >= -5 AND V7252 <= -1) THEN V7252 = .;
   IF (V7253 >= -5 AND V7253 <= -1) THEN V7253 = .;
   IF (V7254 >= -5 AND V7254 <= -1) THEN V7254 = .;
   IF (V7255 >= -5 AND V7255 <= -1) THEN V7255 = .;
   IF (V7256 >= -5.00 AND V7256 <= -1.00) THEN V7256 = .;
   IF (V7257 >= -5 AND V7257 <= -1) THEN V7257 = .;
   IF (V7258 >= -5 AND V7258 <= -1) THEN V7258 = .;
   IF (V7259 >= -5 AND V7259 <= -1) THEN V7259 = .;
   IF (V7260 >= -5 AND V7260 <= -1) THEN V7260 = .;
   IF (V7261 >= -5 AND V7261 <= -1) THEN V7261 = .;
   IF (V7262 >= -5 AND V7262 <= -1) THEN V7262 = .;
   IF (V7263 >= -5 AND V7263 <= -1) THEN V7263 = .;
   IF (V7264 >= -5 AND V7264 <= -1) THEN V7264 = .;
   IF (V7265 >= -5 AND V7265 <= -1) THEN V7265 = .;
   IF (V7266 >= -5 AND V7266 <= -1) THEN V7266 = .;
   IF (V7267 >= -5 AND V7267 <= -1) THEN V7267 = .;
   IF (V7268 >= -5 AND V7268 <= -1) THEN V7268 = .;
   IF (V7269 >= -5 AND V7269 <= -1) THEN V7269 = .;
   IF (V7270 >= -5 AND V7270 <= -1) THEN V7270 = .;
   IF (V7271 >= -5 AND V7271 <= -1) THEN V7271 = .;
   IF (V7272 >= -5 AND V7272 <= -1) THEN V7272 = .;
   IF (V7273 >= -5 AND V7273 <= -1) THEN V7273 = .;
   IF (V7274 >= -5 AND V7274 <= -1) THEN V7274 = .;
   IF (V7275 >= -5 AND V7275 <= -1) THEN V7275 = .;
   IF (V7276 >= -5 AND V7276 <= -1) THEN V7276 = .;
   IF (V7277 >= -5 AND V7277 <= -1) THEN V7277 = .;
   IF (V7278 >= -5 AND V7278 <= -1) THEN V7278 = .;
   IF (V7279 >= -5 AND V7279 <= -1) THEN V7279 = .;
   IF (V7280 >= -5 AND V7280 <= -1) THEN V7280 = .;
   IF (V7281 >= -5 AND V7281 <= -1) THEN V7281 = .;
   IF (V7282 >= -5 AND V7282 <= -1) THEN V7282 = .;
   IF (V7283 >= -5 AND V7283 <= -1) THEN V7283 = .;
   IF (V7284 >= -5 AND V7284 <= -1) THEN V7284 = .;
   IF (V7285 >= -5 AND V7285 <= -1) THEN V7285 = .;
   IF (V7286 >= -5 AND V7286 <= -1) THEN V7286 = .;
   IF (V7287 >= -5 AND V7287 <= -1) THEN V7287 = .;
   IF (V7288 >= -5 AND V7288 <= -1) THEN V7288 = .;
   IF (V7289 >= -5 AND V7289 <= -1) THEN V7289 = .;
   IF (V7290 >= -5 AND V7290 <= -1) THEN V7290 = .;
   IF (V7291 >= -5 AND V7291 <= -1) THEN V7291 = .;
   IF (V7292 >= -5 AND V7292 <= -1) THEN V7292 = .;
   IF (V7293 >= -5 AND V7293 <= -1) THEN V7293 = .;
   IF (V7294 >= -5 AND V7294 <= -1) THEN V7294 = .;
   IF (V7295 >= -5 AND V7295 <= -1) THEN V7295 = .;
   IF (V7296 >= -5 AND V7296 <= -1) THEN V7296 = .;
   IF (V7297 >= -5 AND V7297 <= -1) THEN V7297 = .;
   IF (V7298 >= -5 AND V7298 <= -1) THEN V7298 = .;
   IF (V7299 >= -5 AND V7299 <= -1) THEN V7299 = .;
   IF (V7300 >= -5 AND V7300 <= -1) THEN V7300 = .;
   IF (V7301 >= -5 AND V7301 <= -1) THEN V7301 = .;
   IF (V7302 >= -5 AND V7302 <= -1) THEN V7302 = .;
   IF (V7303 >= -5 AND V7303 <= -1) THEN V7303 = .;
   IF (V7304 >= -5 AND V7304 <= -1) THEN V7304 = .;
   IF (V7305 >= -5 AND V7305 <= -1) THEN V7305 = .;
   IF (V7306 >= -5 AND V7306 <= -1) THEN V7306 = .;
   IF (V7307 >= -5 AND V7307 <= -1) THEN V7307 = .;
   IF (V7308 >= -5 AND V7308 <= -1) THEN V7308 = .;
   IF (V7309 >= -5 AND V7309 <= -1) THEN V7309 = .;
   IF (V7310 >= -5 AND V7310 <= -1) THEN V7310 = .;
   IF (V7311 >= -5 AND V7311 <= -1) THEN V7311 = .;
   IF (V7312 >= -5 AND V7312 <= -1) THEN V7312 = .;
   IF (V7313 >= -5 AND V7313 <= -1) THEN V7313 = .;
   IF (V7314 >= -5 AND V7314 <= -1) THEN V7314 = .;
   IF (V7315 >= -5 AND V7315 <= -1) THEN V7315 = .;
   IF (V7316 >= -5 AND V7316 <= -1) THEN V7316 = .;
   IF (V7317 >= -5 AND V7317 <= -1) THEN V7317 = .;
   IF (V7318 >= -5 AND V7318 <= -1) THEN V7318 = .;
   IF (V7319 >= -5 AND V7319 <= -1) THEN V7319 = .;
   IF (V7320 >= -5 AND V7320 <= -1) THEN V7320 = .;
   IF (V7321 >= -5 AND V7321 <= -1) THEN V7321 = .;
   IF (V7322 >= -5 AND V7322 <= -1) THEN V7322 = .;
   IF (V7323 >= -5 AND V7323 <= -1) THEN V7323 = .;
   IF (V7324 >= -5 AND V7324 <= -1) THEN V7324 = .;
   IF (V7325 >= -5 AND V7325 <= -1) THEN V7325 = .;
   IF (V7326 >= -5 AND V7326 <= -1) THEN V7326 = .;
   IF (V7327 >= -5 AND V7327 <= -1) THEN V7327 = .;
   IF (V7328 >= -5 AND V7328 <= -1) THEN V7328 = .;
   IF (V7329 >= -5 AND V7329 <= -1) THEN V7329 = .;
   IF (V7330 >= -5 AND V7330 <= -1) THEN V7330 = .;
   IF (V7331 >= -5 AND V7331 <= -1) THEN V7331 = .;
   IF (V7332 >= -5 AND V7332 <= -1) THEN V7332 = .;
   IF (V7333 >= -5 AND V7333 <= -1) THEN V7333 = .;
   IF (V7334 >= -5 AND V7334 <= -1) THEN V7334 = .;
   IF (V7335 >= -5 AND V7335 <= -1) THEN V7335 = .;
   IF (V7336 >= -5 AND V7336 <= -1) THEN V7336 = .;
   IF (V7337 >= -5 AND V7337 <= -1) THEN V7337 = .;
   IF (V7338 >= -5 AND V7338 <= -1) THEN V7338 = .;
   IF (V7339 >= -5 AND V7339 <= -1) THEN V7339 = .;
   IF (V7340 >= -5 AND V7340 <= -1) THEN V7340 = .;
   IF (V7341 >= -5 AND V7341 <= -1) THEN V7341 = .;
   IF (V7342 >= -5 AND V7342 <= -1) THEN V7342 = .;
   IF (V7343 >= -5 AND V7343 <= -1) THEN V7343 = .;
   IF (V7344 >= -5 AND V7344 <= -1) THEN V7344 = .;
   IF (V7345 >= -5 AND V7345 <= -1) THEN V7345 = .;
   IF (V7346 >= -5 AND V7346 <= -1) THEN V7346 = .;
   IF (V7347 >= -5 AND V7347 <= -1) THEN V7347 = .;
   IF (V7348 >= -5 AND V7348 <= -1) THEN V7348 = .;
   IF (V7349 >= -5 AND V7349 <= -1) THEN V7349 = .;
   IF (V7350 >= -5 AND V7350 <= -1) THEN V7350 = .;
   IF (V7351 >= -5 AND V7351 <= -1) THEN V7351 = .;
   IF (V7352 >= -5 AND V7352 <= -1) THEN V7352 = .;
   IF (V7353 >= -5 AND V7353 <= -1) THEN V7353 = .;
   IF (V7354 >= -5 AND V7354 <= -1) THEN V7354 = .;
   IF (V7355 >= -5 AND V7355 <= -1) THEN V7355 = .;
   IF (V7356 >= -5 AND V7356 <= -1) THEN V7356 = .;
   IF (V7357 >= -5 AND V7357 <= -1) THEN V7357 = .;
   IF (V7358 >= -5 AND V7358 <= -1) THEN V7358 = .;
   IF (V7359 >= -5 AND V7359 <= -1) THEN V7359 = .;
   IF (V7360 >= -5 AND V7360 <= -1) THEN V7360 = .;
   IF (V7361 >= -5 AND V7361 <= -1) THEN V7361 = .;
   IF (V7362 >= -5 AND V7362 <= -1) THEN V7362 = .;
   IF (V7363 >= -5 AND V7363 <= -1) THEN V7363 = .;
   IF (V7364 >= -5 AND V7364 <= -1) THEN V7364 = .;
   IF (V7365 >= -5 AND V7365 <= -1) THEN V7365 = .;
   IF (V7366 >= -5 AND V7366 <= -1) THEN V7366 = .;
   IF (V7367 >= -5 AND V7367 <= -1) THEN V7367 = .;
   IF (V7368 >= -5 AND V7368 <= -1) THEN V7368 = .;
   IF (V7369 >= -5 AND V7369 <= -1) THEN V7369 = .;
   IF (V7370 >= -5 AND V7370 <= -1) THEN V7370 = .;
   IF (V7371 >= -5 AND V7371 <= -1) THEN V7371 = .;
   IF (V7372 >= -5 AND V7372 <= -1) THEN V7372 = .;
   IF (V7373 >= -5 AND V7373 <= -1) THEN V7373 = .;
   IF (V7374 >= -5 AND V7374 <= -1) THEN V7374 = .;
   IF (V7375 >= -5 AND V7375 <= -1) THEN V7375 = .;
   IF (V7376 >= -5 AND V7376 <= -1) THEN V7376 = .;
   IF (V7377 >= -5 AND V7377 <= -1) THEN V7377 = .;
   IF (V7378 >= -5 AND V7378 <= -1) THEN V7378 = .;
   IF (V7379 >= -5 AND V7379 <= -1) THEN V7379 = .;
   IF (V7380 >= -5 AND V7380 <= -1) THEN V7380 = .;
   IF (V7381 >= -5 AND V7381 <= -1) THEN V7381 = .;
   IF (V7382 >= -5 AND V7382 <= -1) THEN V7382 = .;
   IF (V7383 >= -5 AND V7383 <= -1) THEN V7383 = .;
   IF (V7384 >= -5 AND V7384 <= -1) THEN V7384 = .;
   IF (V7385 >= -5 AND V7385 <= -1) THEN V7385 = .;
   IF (V7386 >= -5 AND V7386 <= -1) THEN V7386 = .;
   IF (V7387 >= -5 AND V7387 <= -1) THEN V7387 = .;
   IF (V7388 >= -5 AND V7388 <= -1) THEN V7388 = .;
   IF (V7389 >= -5 AND V7389 <= -1) THEN V7389 = .;
   IF (V7390 >= -5 AND V7390 <= -1) THEN V7390 = .;
   IF (V7391 >= -5 AND V7391 <= -1) THEN V7391 = .;
   IF (V7392 >= -5 AND V7392 <= -1) THEN V7392 = .;
   IF (V7393 >= -5 AND V7393 <= -1) THEN V7393 = .;
   IF (V7394 >= -5 AND V7394 <= -1) THEN V7394 = .;
   IF (V7395 >= -5 AND V7395 <= -1) THEN V7395 = .;
   IF (V7396 >= -5 AND V7396 <= -1) THEN V7396 = .;
   IF (V7397 >= -5 AND V7397 <= -1) THEN V7397 = .;
   IF (V7398 >= -5 AND V7398 <= -1) THEN V7398 = .;
   IF (V7399 >= -5 AND V7399 <= -1) THEN V7399 = .;
   IF (V7400 >= -5 AND V7400 <= -1) THEN V7400 = .;
   IF (V7401 >= -5 AND V7401 <= -1) THEN V7401 = .;
   IF (V7402 >= -5 AND V7402 <= -1) THEN V7402 = .;
   IF (V7403 >= -5 AND V7403 <= -1) THEN V7403 = .;
   IF (V7404 >= -5 AND V7404 <= -1) THEN V7404 = .;
   IF (V7405 >= -5 AND V7405 <= -1) THEN V7405 = .;
   IF (V7406 >= -5 AND V7406 <= -1) THEN V7406 = .;
   IF (V7407 >= -5 AND V7407 <= -1) THEN V7407 = .;
   IF (V7408 >= -5 AND V7408 <= -1) THEN V7408 = .;
   IF (V7409 >= -5 AND V7409 <= -1) THEN V7409 = .;
   IF (V7410 >= -5 AND V7410 <= -1) THEN V7410 = .;
   IF (V7411 >= -5 AND V7411 <= -1) THEN V7411 = .;
   IF (V7412 >= -5 AND V7412 <= -1) THEN V7412 = .;
   IF (V7413 >= -5 AND V7413 <= -1) THEN V7413 = .;
   IF (V7414 >= -5 AND V7414 <= -1) THEN V7414 = .;
   IF (V7415 >= -5 AND V7415 <= -1) THEN V7415 = .;
   IF (V7416 >= -5 AND V7416 <= -1) THEN V7416 = .;
   IF (V7417 >= -5 AND V7417 <= -1) THEN V7417 = .;
   IF (V7418 >= -5 AND V7418 <= -1) THEN V7418 = .;
   IF (V7419 >= -5 AND V7419 <= -1) THEN V7419 = .;
   IF (V7420 >= -5 AND V7420 <= -1) THEN V7420 = .;
   IF (V7421 >= -5 AND V7421 <= -1) THEN V7421 = .;
   IF (V7422 >= -5 AND V7422 <= -1) THEN V7422 = .;
   IF (V7423 >= -5 AND V7423 <= -1) THEN V7423 = .;
   IF (V7424 >= -5 AND V7424 <= -1) THEN V7424 = .;
   IF (V7425 >= -5 AND V7425 <= -1) THEN V7425 = .;
   IF (V7426 >= -5 AND V7426 <= -1) THEN V7426 = .;
   IF (V7427 >= -5 AND V7427 <= -1) THEN V7427 = .;
   IF (V7428 >= -5 AND V7428 <= -1) THEN V7428 = .;
   IF (V7429 >= -5 AND V7429 <= -1) THEN V7429 = .;
   IF (V7430 >= -5 AND V7430 <= -1) THEN V7430 = .;
   IF (V7431 >= -5 AND V7431 <= -1) THEN V7431 = .;
   IF (V7432 >= -5 AND V7432 <= -1) THEN V7432 = .;
   IF (V7433 >= -5 AND V7433 <= -1) THEN V7433 = .;
   IF (V7434 >= -5 AND V7434 <= -1) THEN V7434 = .;
   IF (V7435 >= -5 AND V7435 <= -1) THEN V7435 = .;
   IF (V7436 >= -5 AND V7436 <= -1) THEN V7436 = .;
   IF (V7437 >= -5 AND V7437 <= -1) THEN V7437 = .;
   IF (V7438 >= -5 AND V7438 <= -1) THEN V7438 = .;
   IF (V7439 >= -5 AND V7439 <= -1) THEN V7439 = .;
   IF (V7440 >= -5 AND V7440 <= -1) THEN V7440 = .;
   IF (V7441 >= -5 AND V7441 <= -1) THEN V7441 = .;
   IF (V7442 >= -5 AND V7442 <= -1) THEN V7442 = .;
   IF (V7443 >= -5 AND V7443 <= -1) THEN V7443 = .;
   IF (V7444 >= -5 AND V7444 <= -1) THEN V7444 = .;
   IF (V7445 >= -5 AND V7445 <= -1) THEN V7445 = .;
   IF (V7446 >= -5 AND V7446 <= -1) THEN V7446 = .;
   IF (V7447 >= -5 AND V7447 <= -1) THEN V7447 = .;
   IF (V7448 >= -5 AND V7448 <= -1) THEN V7448 = .;
   IF (V7449 >= -5 AND V7449 <= -1) THEN V7449 = .;
   IF (V7450 >= -5 AND V7450 <= -1) THEN V7450 = .;
   IF (V7451 >= -5 AND V7451 <= -1) THEN V7451 = .;
   IF (V7452 >= -5 AND V7452 <= -1) THEN V7452 = .;
   IF (V7453 >= -5 AND V7453 <= -1) THEN V7453 = .;
   IF (V7454 >= -5 AND V7454 <= -1) THEN V7454 = .;
   IF (V7455 >= -5 AND V7455 <= -1) THEN V7455 = .;
   IF (V7456 >= -5 AND V7456 <= -1) THEN V7456 = .;
   IF (V7457 >= -5 AND V7457 <= -1) THEN V7457 = .;
   IF (V7458 >= -5 AND V7458 <= -1) THEN V7458 = .;
   IF (V7459 >= -5 AND V7459 <= -1) THEN V7459 = .;
   IF (V7460 >= -5 AND V7460 <= -1) THEN V7460 = .;
   IF (V7461 >= -5 AND V7461 <= -1) THEN V7461 = .;
   IF (V7462 >= -5 AND V7462 <= -1) THEN V7462 = .;
   IF (V7463 >= -5 AND V7463 <= -1) THEN V7463 = .;
   IF (V7464 >= -5 AND V7464 <= -1) THEN V7464 = .;
   IF (V7465 >= -5 AND V7465 <= -1) THEN V7465 = .;
   IF (V7466 >= -5 AND V7466 <= -1) THEN V7466 = .;
   IF (V7467 >= -5 AND V7467 <= -1) THEN V7467 = .;
   IF (V7468 >= -5 AND V7468 <= -1) THEN V7468 = .;
   IF (V7469 >= -5 AND V7469 <= -1) THEN V7469 = .;
   IF (V7470 >= -5 AND V7470 <= -1) THEN V7470 = .;
   IF (V7471 >= -5 AND V7471 <= -1) THEN V7471 = .;
   IF (V7472 >= -5 AND V7472 <= -1) THEN V7472 = .;
   IF (V7473 >= -5 AND V7473 <= -1) THEN V7473 = .;
   IF (V7474 >= -5 AND V7474 <= -1) THEN V7474 = .;
   IF (V7475 >= -5 AND V7475 <= -1) THEN V7475 = .;
   IF (V7476 >= -5 AND V7476 <= -1) THEN V7476 = .;
   IF (V7477 >= -5 AND V7477 <= -1) THEN V7477 = .;
   IF (V7478 >= -5 AND V7478 <= -1) THEN V7478 = .;
   IF (V7479 >= -5 AND V7479 <= -1) THEN V7479 = .;
   IF (V7480 >= -5 AND V7480 <= -1) THEN V7480 = .;
   IF (V7481 >= -5 AND V7481 <= -1) THEN V7481 = .;
   IF (V7482 >= -5 AND V7482 <= -1) THEN V7482 = .;
   IF (V7483 >= -5 AND V7483 <= -1) THEN V7483 = .;
   IF (V7484 >= -5 AND V7484 <= -1) THEN V7484 = .;
   IF (V7485 >= -5 AND V7485 <= -1) THEN V7485 = .;
   IF (V7486 >= -5 AND V7486 <= -1) THEN V7486 = .;
   IF (V7487 >= -5 AND V7487 <= -1) THEN V7487 = .;
   IF (V7488 >= -5 AND V7488 <= -1) THEN V7488 = .;
   IF (V7489 >= -5 AND V7489 <= -1) THEN V7489 = .;
   IF (V7490 >= -5 AND V7490 <= -1) THEN V7490 = .;
   IF (V7491 >= -5 AND V7491 <= -1) THEN V7491 = .;
   IF (V7492 >= -5 AND V7492 <= -1) THEN V7492 = .;
   IF (V7493 >= -5 AND V7493 <= -1) THEN V7493 = .;
   IF (V7494 >= -5 AND V7494 <= -1) THEN V7494 = .;
   IF (V7495 >= -5 AND V7495 <= -1) THEN V7495 = .;
   IF (V7496 >= -5 AND V7496 <= -1) THEN V7496 = .;
   IF (V7497 >= -5 AND V7497 <= -1) THEN V7497 = .;
   IF (V7498 >= -5 AND V7498 <= -1) THEN V7498 = .;
   IF (V7499 >= -5 AND V7499 <= -1) THEN V7499 = .;
   IF (V7500 >= -5 AND V7500 <= -1) THEN V7500 = .;
   IF (V7501 >= -5 AND V7501 <= -1) THEN V7501 = .;
   IF (V7502 >= -5 AND V7502 <= -1) THEN V7502 = .;
   IF (V7503 >= -5 AND V7503 <= -1) THEN V7503 = .;
   IF (V7504 >= -5 AND V7504 <= -1) THEN V7504 = .;
   IF (V7505 >= -5 AND V7505 <= -1) THEN V7505 = .;
   IF (V7506 >= -5 AND V7506 <= -1) THEN V7506 = .;
   IF (V7507 >= -5 AND V7507 <= -1) THEN V7507 = .;
   IF (V7508 >= -5 AND V7508 <= -1) THEN V7508 = .;
   IF (V7509 >= -5 AND V7509 <= -1) THEN V7509 = .;
   IF (V7510 >= -5 AND V7510 <= -1) THEN V7510 = .;
   IF (V7511 >= -5 AND V7511 <= -1) THEN V7511 = .;
   IF (V7512 >= -5 AND V7512 <= -1) THEN V7512 = .;
   IF (V7513 >= -5 AND V7513 <= -1) THEN V7513 = .;
   IF (V7514 >= -5 AND V7514 <= -1) THEN V7514 = .;
   IF (V7515 >= -5 AND V7515 <= -1) THEN V7515 = .;
   IF (V7516 >= -5 AND V7516 <= -1) THEN V7516 = .;
   IF (V7517 >= -5 AND V7517 <= -1) THEN V7517 = .;
   IF (V7518 >= -5 AND V7518 <= -1) THEN V7518 = .;
   IF (V7519 >= -5 AND V7519 <= -1) THEN V7519 = .;
   IF (V7520 >= -5 AND V7520 <= -1) THEN V7520 = .;
   IF (V7521 >= -5 AND V7521 <= -1) THEN V7521 = .;
   IF (V7522 >= -5 AND V7522 <= -1) THEN V7522 = .;
   IF (V7523 >= -5 AND V7523 <= -1) THEN V7523 = .;
   IF (V7524 >= -5 AND V7524 <= -1) THEN V7524 = .;
   IF (V7525 >= -5 AND V7525 <= -1) THEN V7525 = .;
   IF (V7526 >= -5 AND V7526 <= -1) THEN V7526 = .;
   IF (V7527 >= -5 AND V7527 <= -1) THEN V7527 = .;
   IF (V7528 >= -5 AND V7528 <= -1) THEN V7528 = .;
   IF (V7529 >= -5 AND V7529 <= -1) THEN V7529 = .;
   IF (V7530 >= -5 AND V7530 <= -1) THEN V7530 = .;
   IF (V7531 >= -5 AND V7531 <= -1) THEN V7531 = .;
   IF (V7532 >= -5 AND V7532 <= -1) THEN V7532 = .;
   IF (V7533 >= -5 AND V7533 <= -1) THEN V7533 = .;
   IF (V7534 >= -5 AND V7534 <= -1) THEN V7534 = .;
   IF (V7535 >= -5 AND V7535 <= -1) THEN V7535 = .;
   IF (V7536 >= -5 AND V7536 <= -1) THEN V7536 = .;
   IF (V7537 >= -5 AND V7537 <= -1) THEN V7537 = .;
   IF (V7538 >= -5 AND V7538 <= -1) THEN V7538 = .;
   IF (V7539 >= -5 AND V7539 <= -1) THEN V7539 = .;
   IF (V7540 >= -5 AND V7540 <= -1) THEN V7540 = .;
   IF (V7541 >= -5 AND V7541 <= -1) THEN V7541 = .;
   IF (V7542 >= -5 AND V7542 <= -1) THEN V7542 = .;
   IF (V7543 >= -5 AND V7543 <= -1) THEN V7543 = .;
   IF (V7544 >= -5 AND V7544 <= -1) THEN V7544 = .;
   IF (V7545 >= -5 AND V7545 <= -1) THEN V7545 = .;
   IF (V7546 >= -5 AND V7546 <= -1) THEN V7546 = .;
   IF (V7547 >= -5 AND V7547 <= -1) THEN V7547 = .;
   IF (V7548 >= -5 AND V7548 <= -1) THEN V7548 = .;
   IF (V7549 >= -5 AND V7549 <= -1) THEN V7549 = .;
   IF (V7550 >= -5 AND V7550 <= -1) THEN V7550 = .;
   IF (V7551 >= -5 AND V7551 <= -1) THEN V7551 = .;
   IF (V7552 >= -5 AND V7552 <= -1) THEN V7552 = .;
   IF (V7553 >= -5 AND V7553 <= -1) THEN V7553 = .;
   IF (V7554 >= -5 AND V7554 <= -1) THEN V7554 = .;
   IF (V7555 >= -5 AND V7555 <= -1) THEN V7555 = .;
   IF (V7556 >= -5 AND V7556 <= -1) THEN V7556 = .;
   IF (V7557 >= -5 AND V7557 <= -1) THEN V7557 = .;
   IF (V7558 >= -5 AND V7558 <= -1) THEN V7558 = .;
   IF (V7559 >= -5 AND V7559 <= -1) THEN V7559 = .;
   IF (V7560 >= -5 AND V7560 <= -1) THEN V7560 = .;
   IF (V7561 >= -5 AND V7561 <= -1) THEN V7561 = .;
   IF (V7562 >= -5 AND V7562 <= -1) THEN V7562 = .;
   IF (V7563 >= -5 AND V7563 <= -1) THEN V7563 = .;
   IF (V7564 >= -5 AND V7564 <= -1) THEN V7564 = .;
   IF (V7565 >= -5 AND V7565 <= -1) THEN V7565 = .;
   IF (V7566 >= -5 AND V7566 <= -1) THEN V7566 = .;
   IF (V7567 >= -5 AND V7567 <= -1) THEN V7567 = .;
   IF (V7568 >= -5 AND V7568 <= -1) THEN V7568 = .;
   IF (V7569 >= -5 AND V7569 <= -1) THEN V7569 = .;
   IF (V7570 >= -5 AND V7570 <= -1) THEN V7570 = .;
   IF (V7571 >= -5 AND V7571 <= -1) THEN V7571 = .;
   IF (V7572 >= -5 AND V7572 <= -1) THEN V7572 = .;
   IF (V7573 >= -5 AND V7573 <= -1) THEN V7573 = .;
   IF (V7574 >= -5 AND V7574 <= -1) THEN V7574 = .;
   IF (V7575 >= -5 AND V7575 <= -1) THEN V7575 = .;
   IF (V7576 >= -5 AND V7576 <= -1) THEN V7576 = .;
   IF (V7577 >= -5 AND V7577 <= -1) THEN V7577 = .;
   IF (V7578 >= -5 AND V7578 <= -1) THEN V7578 = .;
   IF (V7579 >= -5 AND V7579 <= -1) THEN V7579 = .;
   IF (V7580 >= -5 AND V7580 <= -1) THEN V7580 = .;
   IF (V7581 >= -5 AND V7581 <= -1) THEN V7581 = .;
   IF (V7582 >= -5 AND V7582 <= -1) THEN V7582 = .;
   IF (V7583 >= -5 AND V7583 <= -1) THEN V7583 = .;
   IF (V7584 >= -5 AND V7584 <= -1) THEN V7584 = .;
   IF (V7585 >= -5 AND V7585 <= -1) THEN V7585 = .;
   IF (V7586 >= -5 AND V7586 <= -1) THEN V7586 = .;
   IF (V7587 >= -5 AND V7587 <= -1) THEN V7587 = .;
   IF (V7588 >= -5 AND V7588 <= -1) THEN V7588 = .;
   IF (V7589 >= -5 AND V7589 <= -1) THEN V7589 = .;
   IF (V7590 >= -5 AND V7590 <= -1) THEN V7590 = .;
   IF (V7591 >= -5 AND V7591 <= -1) THEN V7591 = .;
   IF (V7592 >= -5 AND V7592 <= -1) THEN V7592 = .;
   IF (V7593 >= -5 AND V7593 <= -1) THEN V7593 = .;
   IF (V7594 >= -5 AND V7594 <= -1) THEN V7594 = .;
   IF (V7595 >= -5 AND V7595 <= -1) THEN V7595 = .;
   IF (V7596 >= -5 AND V7596 <= -1) THEN V7596 = .;
   IF (V7597 >= -5 AND V7597 <= -1) THEN V7597 = .;
   IF (V7598 >= -5 AND V7598 <= -1) THEN V7598 = .;
   IF (V7599 >= -5 AND V7599 <= -1) THEN V7599 = .;
   IF (V7600 >= -5 AND V7600 <= -1) THEN V7600 = .;
   IF (V7601 >= -5 AND V7601 <= -1) THEN V7601 = .;
   IF (V7602 >= -5 AND V7602 <= -1) THEN V7602 = .;
   IF (V7603 >= -5 AND V7603 <= -1) THEN V7603 = .;
   IF (V7604 >= -5 AND V7604 <= -1) THEN V7604 = .;
   IF (V7605 >= -5 AND V7605 <= -1) THEN V7605 = .;
   IF (V7606 >= -5 AND V7606 <= -1) THEN V7606 = .;
   IF (V7607 >= -5 AND V7607 <= -1) THEN V7607 = .;
   IF (V7608 >= -5 AND V7608 <= -1) THEN V7608 = .;
   IF (V7609 >= -5 AND V7609 <= -1) THEN V7609 = .;
   IF (V7610 >= -5 AND V7610 <= -1) THEN V7610 = .;
   IF (V7611 >= -5 AND V7611 <= -1) THEN V7611 = .;
   IF (V7612 >= -5 AND V7612 <= -1) THEN V7612 = .;
   IF (V7613 >= -5 AND V7613 <= -1) THEN V7613 = .;
   IF (V7614 >= -5 AND V7614 <= -1) THEN V7614 = .;
   IF (V7615 >= -5 AND V7615 <= -1) THEN V7615 = .;
   IF (V7616 >= -5 AND V7616 <= -1) THEN V7616 = .;
   IF (V7617 >= -5 AND V7617 <= -1) THEN V7617 = .;
   IF (V7618 >= -5 AND V7618 <= -1) THEN V7618 = .;
   IF (V7619 >= -5 AND V7619 <= -1) THEN V7619 = .;
   IF (V7620 >= -5 AND V7620 <= -1) THEN V7620 = .;
   IF (V7621 >= -5 AND V7621 <= -1) THEN V7621 = .;
   IF (V7622 >= -5 AND V7622 <= -1) THEN V7622 = .;
   IF (V7623 >= -5 AND V7623 <= -1) THEN V7623 = .;
   IF (V7624 >= -5 AND V7624 <= -1) THEN V7624 = .;
   IF (V7625 >= -5 AND V7625 <= -1) THEN V7625 = .;
   IF (V7626 >= -5 AND V7626 <= -1) THEN V7626 = .;
   IF (V7627 >= -5 AND V7627 <= -1) THEN V7627 = .;
   IF (V7628 >= -5 AND V7628 <= -1) THEN V7628 = .;
   IF (V7629 >= -5 AND V7629 <= -1) THEN V7629 = .;
   IF (V7630 >= -5 AND V7630 <= -1) THEN V7630 = .;
   IF (V7631 >= -5 AND V7631 <= -1) THEN V7631 = .;
   IF (V7632 >= -5 AND V7632 <= -1) THEN V7632 = .;
   IF (V7633 >= -5 AND V7633 <= -1) THEN V7633 = .;
   IF (V7634 >= -5 AND V7634 <= -1) THEN V7634 = .;
   IF (V7635 >= -5 AND V7635 <= -1) THEN V7635 = .;
   IF (V7636 >= -5 AND V7636 <= -1) THEN V7636 = .;
   IF (V7637 >= -5 AND V7637 <= -1) THEN V7637 = .;
   IF (V7638 >= -5 AND V7638 <= -1) THEN V7638 = .;
   IF (V7639 >= -5 AND V7639 <= -1) THEN V7639 = .;
   IF (V7640 >= -5 AND V7640 <= -1) THEN V7640 = .;
   IF (V7641 >= -5 AND V7641 <= -1) THEN V7641 = .;
   IF (V7642 >= -5 AND V7642 <= -1) THEN V7642 = .;
   IF (V7643 >= -5 AND V7643 <= -1) THEN V7643 = .;
   IF (V7644 >= -5 AND V7644 <= -1) THEN V7644 = .;
   IF (V7645 >= -5 AND V7645 <= -1) THEN V7645 = .;
   IF (V7646 >= -5 AND V7646 <= -1) THEN V7646 = .;
   IF (V7647 >= -5 AND V7647 <= -1) THEN V7647 = .;
   IF (V7648 >= -5 AND V7648 <= -1) THEN V7648 = .;
   IF (V7649 >= -5 AND V7649 <= -1) THEN V7649 = .;
   IF (V7650 >= -5 AND V7650 <= -1) THEN V7650 = .;
   IF (V7651 >= -5 AND V7651 <= -1) THEN V7651 = .;
   IF (V7652 >= -5 AND V7652 <= -1) THEN V7652 = .;
   IF (V7653 >= -5 AND V7653 <= -1) THEN V7653 = .;
   IF (V7654 >= -5 AND V7654 <= -1) THEN V7654 = .;
   IF (V7655 >= -5 AND V7655 <= -1) THEN V7655 = .;
   IF (V7656 >= -5 AND V7656 <= -1) THEN V7656 = .;
   IF (V7657 >= -5 AND V7657 <= -1) THEN V7657 = .;
   IF (V7658 >= -5 AND V7658 <= -1) THEN V7658 = .;
   IF (V7659 >= -5 AND V7659 <= -1) THEN V7659 = .;
   IF (V7660 >= -5 AND V7660 <= -1) THEN V7660 = .;
   IF (V7661 >= -5 AND V7661 <= -1) THEN V7661 = .;
   IF (V7662 >= -5 AND V7662 <= -1) THEN V7662 = .;
   IF (V7663 >= -5 AND V7663 <= -1) THEN V7663 = .;
   IF (V7664 >= -5 AND V7664 <= -1) THEN V7664 = .;
   IF (V7665 >= -5 AND V7665 <= -1) THEN V7665 = .;
   IF (V7666 >= -5 AND V7666 <= -1) THEN V7666 = .;
   IF (V7667 >= -5 AND V7667 <= -1) THEN V7667 = .;
   IF (V7668 >= -5 AND V7668 <= -1) THEN V7668 = .;
   IF (V7669 >= -5 AND V7669 <= -1) THEN V7669 = .;
   IF (V8004 >= -5 AND V8004 <= -1) THEN V8004 = .;
   IF (V8005 >= -5 AND V8005 <= -1) THEN V8005 = .;
   IF (V8006 >= -5 AND V8006 <= -1) THEN V8006 = .;
   IF (V8007 >= -5 AND V8007 <= -1) THEN V8007 = .;
   IF (V8008 >= -5 AND V8008 <= -1) THEN V8008 = .;
   IF (V8009 >= -5 AND V8009 <= -1) THEN V8009 = .;
   IF (V8010 >= -5 AND V8010 <= -1) THEN V8010 = .;
   IF (V8011 >= -5 AND V8011 <= -1) THEN V8011 = .;
   IF (V8012 >= -5 AND V8012 <= -1) THEN V8012 = .;
   IF (V8013 >= -5 AND V8013 <= -1) THEN V8013 = .;
   IF (V8014 >= -5 AND V8014 <= -1) THEN V8014 = .;
   IF (V8015 >= -5 AND V8015 <= -1) THEN V8015 = .;
   IF (V8016 >= -5 AND V8016 <= -1) THEN V8016 = .;
   IF (V8017 >= -5 AND V8017 <= -1) THEN V8017 = .;
   IF (V8018 >= -5 AND V8018 <= -1) THEN V8018 = .;
   IF (V8019 >= -5 AND V8019 <= -1) THEN V8019 = .;
   IF (V8020 >= -5 AND V8020 <= -1) THEN V8020 = .;
   IF (V8021 >= -5 AND V8021 <= -1) THEN V8021 = .;
   IF (V8022 >= -5 AND V8022 <= -1) THEN V8022 = .;
   IF (V8023 >= -5 AND V8023 <= -1) THEN V8023 = .;
   IF (V8024 >= -5 AND V8024 <= -1) THEN V8024 = .;
   IF (V8025 >= -5 AND V8025 <= -1) THEN V8025 = .;
   IF (V8026 >= -5 AND V8026 <= -1) THEN V8026 = .;
   IF (V8027 >= -5 AND V8027 <= -1) THEN V8027 = .;
   IF (V8028 >= -5 AND V8028 <= -1) THEN V8028 = .;
   IF (V8029 >= -5 AND V8029 <= -1) THEN V8029 = .;
   IF (V8030 >= -5 AND V8030 <= -1) THEN V8030 = .;
   IF (V8031 >= -5 AND V8031 <= -1) THEN V8031 = .;
   IF (V8032 >= -5 AND V8032 <= -1) THEN V8032 = .;
   IF (V8033 >= -5 AND V8033 <= -1) THEN V8033 = .;
   IF (V8034 >= -5 AND V8034 <= -1) THEN V8034 = .;
   IF (V8035 >= -5 AND V8035 <= -1) THEN V8035 = .;
   IF (V8036 >= -5 AND V8036 <= -1) THEN V8036 = .;
   IF (V8037 >= -5 AND V8037 <= -1) THEN V8037 = .;
   IF (V8038 >= -5 AND V8038 <= -1) THEN V8038 = .;
   IF (V8039 >= -5 AND V8039 <= -1) THEN V8039 = .;
   IF (V8040 >= -5 AND V8040 <= -1) THEN V8040 = .;
   IF (V8041 >= -5 AND V8041 <= -1) THEN V8041 = .;
   IF (V8042 >= -5 AND V8042 <= -1) THEN V8042 = .;
   IF (V8043 >= -5 AND V8043 <= -1) THEN V8043 = .;
   IF (V8044 >= -5 AND V8044 <= -1) THEN V8044 = .;
   IF (V8045 >= -5 AND V8045 <= -1) THEN V8045 = .;
   IF (V8046 >= -5 AND V8046 <= -1) THEN V8046 = .;
   IF (V8047 >= -5 AND V8047 <= -1) THEN V8047 = .;
   IF (V8048 >= -5 AND V8048 <= -1) THEN V8048 = .;
   IF (V8049 >= -5 AND V8049 <= -1) THEN V8049 = .;
   IF (V8050 >= -5 AND V8050 <= -1) THEN V8050 = .;
   IF (V8051 >= -5 AND V8051 <= -1) THEN V8051 = .;
   IF (V8052 >= -5 AND V8052 <= -1) THEN V8052 = .;
   IF (V8053 >= -5 AND V8053 <= -1) THEN V8053 = .;
   IF (V8054 >= -5 AND V8054 <= -1) THEN V8054 = .;
   IF (V8055 >= -5 AND V8055 <= -1) THEN V8055 = .;
   IF (V8056 >= -5 AND V8056 <= -1) THEN V8056 = .;
   IF (V8057 >= -5 AND V8057 <= -1) THEN V8057 = .;
   IF (V8058 >= -5 AND V8058 <= -1) THEN V8058 = .;
   IF (V8059 >= -5 AND V8059 <= -1) THEN V8059 = .;
   IF (V8060 >= -5 AND V8060 <= -1) THEN V8060 = .;
   IF (V8061 >= -5 AND V8061 <= -1) THEN V8061 = .;
   IF (V8062 >= -5 AND V8062 <= -1) THEN V8062 = .;
   IF (V8063 >= -5 AND V8063 <= -1) THEN V8063 = .;
   IF (V8064 >= -5 AND V8064 <= -1) THEN V8064 = .;
   IF (V8065 >= -5 AND V8065 <= -1) THEN V8065 = .;
   IF (V8066 >= -5 AND V8066 <= -1) THEN V8066 = .;
   IF (V8067 >= -5 AND V8067 <= -1) THEN V8067 = .;
   IF (V8068 >= -5 AND V8068 <= -1) THEN V8068 = .;
   IF (V8069 >= -5 AND V8069 <= -1) THEN V8069 = .;
   IF (V8070 >= -5 AND V8070 <= -1) THEN V8070 = .;
   IF (V8071 >= -5 AND V8071 <= -1) THEN V8071 = .;
   IF (V8072 >= -5 AND V8072 <= -1) THEN V8072 = .;
   IF (V8073 >= -5 AND V8073 <= -1) THEN V8073 = .;
   IF (V8074 >= -5 AND V8074 <= -1) THEN V8074 = .;
   IF (V8075 >= -5 AND V8075 <= -1) THEN V8075 = .;
   IF (V8076 >= -5 AND V8076 <= -1) THEN V8076 = .;
   IF (V8077 >= -5 AND V8077 <= -1) THEN V8077 = .;
   IF (V8078 >= -5 AND V8078 <= -1) THEN V8078 = .;
   IF (V8079 >= -5 AND V8079 <= -1) THEN V8079 = .;
   IF (V8080 >= -5 AND V8080 <= -1) THEN V8080 = .;
   IF (V8081 >= -5 AND V8081 <= -1) THEN V8081 = .;
   IF (V8082 >= -5 AND V8082 <= -1) THEN V8082 = .;
   IF (V8083 >= -5 AND V8083 <= -1) THEN V8083 = .;
   IF (V8084 >= -5 AND V8084 <= -1) THEN V8084 = .;
   IF (V8085 >= -5 AND V8085 <= -1) THEN V8085 = .;
   IF (V8086 >= -5 AND V8086 <= -1) THEN V8086 = .;
   IF (V8087 >= -5 AND V8087 <= -1) THEN V8087 = .;
   IF (V8088 >= -5 AND V8088 <= -1) THEN V8088 = .;
   IF (V8089 >= -5 AND V8089 <= -1) THEN V8089 = .;
   IF (V8090 >= -5 AND V8090 <= -1) THEN V8090 = .;
   IF (V8091 >= -5 AND V8091 <= -1) THEN V8091 = .;
   IF (V8092 >= -5 AND V8092 <= -1) THEN V8092 = .;
   IF (V8093 >= -5 AND V8093 <= -1) THEN V8093 = .;
   IF (V8094 >= -5 AND V8094 <= -1) THEN V8094 = .;
   IF (V8095 >= -5 AND V8095 <= -1) THEN V8095 = .;
   IF (V8096 >= -5 AND V8096 <= -1) THEN V8096 = .;
   IF (V8097 >= -5 AND V8097 <= -1) THEN V8097 = .;
   IF (V8098 >= -5 AND V8098 <= -1) THEN V8098 = .;
   IF (V8099 >= -5 AND V8099 <= -1) THEN V8099 = .;
   IF (V8100 >= -5 AND V8100 <= -1) THEN V8100 = .;
   IF (V8101 >= -5 AND V8101 <= -1) THEN V8101 = .;
   IF (V8102 >= -5 AND V8102 <= -1) THEN V8102 = .;
   IF (V8103 >= -5 AND V8103 <= -1) THEN V8103 = .;
   IF (V8104 >= -5 AND V8104 <= -1) THEN V8104 = .;
   IF (V8105 >= -5 AND V8105 <= -1) THEN V8105 = .;
   IF (V8106 >= -5 AND V8106 <= -1) THEN V8106 = .;
   IF (V8107 >= -5 AND V8107 <= -1) THEN V8107 = .;
   IF (V8108 >= -5 AND V8108 <= -1) THEN V8108 = .;
   IF (V8109 >= -5 AND V8109 <= -1) THEN V8109 = .;
   IF (V8110 >= -5 AND V8110 <= -1) THEN V8110 = .;
   IF (V8111 >= -5 AND V8111 <= -1) THEN V8111 = .;
   IF (V8112 >= -5 AND V8112 <= -1) THEN V8112 = .;
   IF (V8113 >= -5 AND V8113 <= -1) THEN V8113 = .;
   IF (V8114 >= -5 AND V8114 <= -1) THEN V8114 = .;
   IF (V8115 >= -5 AND V8115 <= -1) THEN V8115 = .;
   IF (V8116 >= -5 AND V8116 <= -1) THEN V8116 = .;
   IF (V8117 >= -5 AND V8117 <= -1) THEN V8117 = .;
   IF (V8118 >= -5 AND V8118 <= -1) THEN V8118 = .;
   IF (V8119 >= -5 AND V8119 <= -1) THEN V8119 = .;
   IF (V8120 >= -5 AND V8120 <= -1) THEN V8120 = .;
   IF (V8121 >= -5 AND V8121 <= -1) THEN V8121 = .;
   IF (V8122 >= -5 AND V8122 <= -1) THEN V8122 = .;
   IF (V8123 >= -5 AND V8123 <= -1) THEN V8123 = .;
   IF (V8124 >= -5 AND V8124 <= -1) THEN V8124 = .;
   IF (V8125 >= -5 AND V8125 <= -1) THEN V8125 = .;
   IF (V8126 >= -5 AND V8126 <= -1) THEN V8126 = .;
   IF (V8127 >= -5 AND V8127 <= -1) THEN V8127 = .;
   IF (V8128 >= -5 AND V8128 <= -1) THEN V8128 = .;
   IF (V8129 >= -5 AND V8129 <= -1) THEN V8129 = .;
   IF (V8130 >= -5 AND V8130 <= -1) THEN V8130 = .;
   IF (V8131 >= -5 AND V8131 <= -1) THEN V8131 = .;
   IF (V8132 >= -5 AND V8132 <= -1) THEN V8132 = .;
   IF (V8133 >= -5 AND V8133 <= -1) THEN V8133 = .;
   IF (V8134 >= -5 AND V8134 <= -1) THEN V8134 = .;
   IF (V8135 >= -5 AND V8135 <= -1) THEN V8135 = .;
   IF (V8136 >= -5 AND V8136 <= -1) THEN V8136 = .;
   IF (V8137 >= -5 AND V8137 <= -1) THEN V8137 = .;
   IF (V8138 >= -5 AND V8138 <= -1) THEN V8138 = .;
   IF (V8139 >= -5 AND V8139 <= -1) THEN V8139 = .;
   IF (V8140 >= -5 AND V8140 <= -1) THEN V8140 = .;
   IF (V8141 >= -5 AND V8141 <= -1) THEN V8141 = .;
   IF (V8142 >= -5 AND V8142 <= -1) THEN V8142 = .;
   IF (V8143 >= -5 AND V8143 <= -1) THEN V8143 = .;
   IF (V8144 >= -5 AND V8144 <= -1) THEN V8144 = .;
   IF (V8145 >= -5 AND V8145 <= -1) THEN V8145 = .;
   IF (V8146 >= -5 AND V8146 <= -1) THEN V8146 = .;
   IF (V8147 >= -5 AND V8147 <= -1) THEN V8147 = .;
   IF (V8148 >= -5 AND V8148 <= -1) THEN V8148 = .;
   IF (V8149 >= -5 AND V8149 <= -1) THEN V8149 = .;
   IF (V8150 >= -5 AND V8150 <= -1) THEN V8150 = .;
   IF (V8151 >= -5 AND V8151 <= -1) THEN V8151 = .;
   IF (V8152 >= -5 AND V8152 <= -1) THEN V8152 = .;
   IF (V8153 >= -5 AND V8153 <= -1) THEN V8153 = .;
   IF (V8154 >= -5 AND V8154 <= -1) THEN V8154 = .;
   IF (V8155 >= -5 AND V8155 <= -1) THEN V8155 = .;
   IF (V8156 >= -5 AND V8156 <= -1) THEN V8156 = .;
   IF (V8157 >= -5 AND V8157 <= -1) THEN V8157 = .;
   IF (V8158 >= -5 AND V8158 <= -1) THEN V8158 = .;
   IF (V8159 >= -5 AND V8159 <= -1) THEN V8159 = .;
   IF (V8160 >= -5 AND V8160 <= -1) THEN V8160 = .;
   IF (V8161 >= -5 AND V8161 <= -1) THEN V8161 = .;
   IF (V8162 >= -5 AND V8162 <= -1) THEN V8162 = .;
   IF (V8163 >= -5 AND V8163 <= -1) THEN V8163 = .;
   IF (V8164 >= -5 AND V8164 <= -1) THEN V8164 = .;
   IF (V8165 >= -5 AND V8165 <= -1) THEN V8165 = .;
   IF (V8166 >= -5 AND V8166 <= -1) THEN V8166 = .;
   IF (V8167 >= -5 AND V8167 <= -1) THEN V8167 = .;
   IF (V8168 >= -5 AND V8168 <= -1) THEN V8168 = .;
   IF (V8169 >= -5 AND V8169 <= -1) THEN V8169 = .;
   IF (V8170 >= -5 AND V8170 <= -1) THEN V8170 = .;
   IF (V8171 >= -5 AND V8171 <= -1) THEN V8171 = .;
   IF (V8172 >= -5 AND V8172 <= -1) THEN V8172 = .;
   IF (V8173 >= -5 AND V8173 <= -1) THEN V8173 = .;
   IF (V8174 >= -5 AND V8174 <= -1) THEN V8174 = .;
   IF (V8175 >= -5 AND V8175 <= -1) THEN V8175 = .;
   IF (V8176 >= -5 AND V8176 <= -1) THEN V8176 = .;
   IF (V8177 >= -5 AND V8177 <= -1) THEN V8177 = .;
   IF (V8178 >= -5 AND V8178 <= -1) THEN V8178 = .;
   IF (V8179 >= -5 AND V8179 <= -1) THEN V8179 = .;
   IF (V8180 >= -5 AND V8180 <= -1) THEN V8180 = .;
   IF (V8181 >= -6 AND V8181 <= -1) THEN V8181 = .;
   IF (V8182 >= -5 AND V8182 <= -1) THEN V8182 = .;
   IF (V8183 >= -5 AND V8183 <= -1) THEN V8183 = .;
   IF (V8184 >= -5 AND V8184 <= -1) THEN V8184 = .;
   IF (V8185 >= -5 AND V8185 <= -1) THEN V8185 = .;
   IF (V8186 >= -5 AND V8186 <= -1) THEN V8186 = .;
   IF (V8187 >= -5 AND V8187 <= -1) THEN V8187 = .;
   IF (V8188 >= -5 AND V8188 <= -1) THEN V8188 = .;
   IF (V8189 >= -5 AND V8189 <= -1) THEN V8189 = .;
   IF (V8190 >= -5 AND V8190 <= -1) THEN V8190 = .;
   IF (V8191 >= -5 AND V8191 <= -1) THEN V8191 = .;
   IF (V8192 >= -5 AND V8192 <= -1) THEN V8192 = .;
   IF (V8193 >= -5 AND V8193 <= -1) THEN V8193 = .;
   IF (V8194 >= -5 AND V8194 <= -1) THEN V8194 = .;
   IF (V8195 >= -5 AND V8195 <= -1) THEN V8195 = .;
   IF (V8196 >= -5 AND V8196 <= -1) THEN V8196 = .;
   IF (V8197 >= -5 AND V8197 <= -1) THEN V8197 = .;
   IF (V8198 >= -5 AND V8198 <= -1) THEN V8198 = .;
   IF (V8199 >= -5 AND V8199 <= -1) THEN V8199 = .;
   IF (V8200 >= -5 AND V8200 <= -1) THEN V8200 = .;
   IF (V8201 >= -5 AND V8201 <= -1) THEN V8201 = .;
   IF (V8202 >= -5 AND V8202 <= -1) THEN V8202 = .;
   IF (V8203 >= -5 AND V8203 <= -1) THEN V8203 = .;
   IF (V8204 >= -5 AND V8204 <= -1) THEN V8204 = .;
   IF (V8205 >= -5 AND V8205 <= -1) THEN V8205 = .;
   IF (V8206 >= -5 AND V8206 <= -1) THEN V8206 = .;
   IF (V8207 >= -5 AND V8207 <= -1) THEN V8207 = .;
   IF (V8208 >= -5 AND V8208 <= -1) THEN V8208 = .;
   IF (V8209 >= -5 AND V8209 <= -1) THEN V8209 = .;
   IF (V8210 >= -5 AND V8210 <= -1) THEN V8210 = .;
   IF (V8211 >= -5 AND V8211 <= -1) THEN V8211 = .;
   IF (V8212 >= -5 AND V8212 <= -1) THEN V8212 = .;
   IF (V8213 >= -5 AND V8213 <= -1) THEN V8213 = .;
   IF (V8214 >= -5 AND V8214 <= -1) THEN V8214 = .;
   IF (V8215 >= -5 AND V8215 <= -1) THEN V8215 = .;
   IF (V8216 >= -5 AND V8216 <= -1) THEN V8216 = .;
   IF (V8217 >= -5 AND V8217 <= -1) THEN V8217 = .;
   IF (V8218 >= -5 AND V8218 <= -1) THEN V8218 = .;
   IF (V8219 >= -5 AND V8219 <= -1) THEN V8219 = .;
   IF (V8220 >= -5 AND V8220 <= -1) THEN V8220 = .;
   IF (V8221 >= -5 AND V8221 <= -1) THEN V8221 = .;
   IF (V8222 >= -5 AND V8222 <= -1) THEN V8222 = .;
   IF (V8223 >= -5 AND V8223 <= -1) THEN V8223 = .;
   IF (V8224 >= -5 AND V8224 <= -1) THEN V8224 = .;
   IF (V8225 >= -5 AND V8225 <= -1) THEN V8225 = .;
   IF (V8226 >= -5 AND V8226 <= -1) THEN V8226 = .;
   IF (V8227 >= -5 AND V8227 <= -1) THEN V8227 = .;
   IF (V8228 >= -5 AND V8228 <= -1) THEN V8228 = .;
   IF (V8229 >= -5 AND V8229 <= -1) THEN V8229 = .;
   IF (V8230 >= -5 AND V8230 <= -1) THEN V8230 = .;
   IF (V8231 >= -5 AND V8231 <= -1) THEN V8231 = .;
   IF (V8232 >= -5 AND V8232 <= -1) THEN V8232 = .;
   IF (V8233 >= -5 AND V8233 <= -1) THEN V8233 = .;
   IF (V8234 >= -5 AND V8234 <= -1) THEN V8234 = .;
   IF (V8235 >= -5 AND V8235 <= -1) THEN V8235 = .;
   IF (V8236 >= -5 AND V8236 <= -1) THEN V8236 = .;
   IF (V8237 >= -5 AND V8237 <= -1) THEN V8237 = .;
   IF (V8238 >= -5 AND V8238 <= -1) THEN V8238 = .;
   IF (V8239 >= -5 AND V8239 <= -1) THEN V8239 = .;
   IF (V8240 >= -5 AND V8240 <= -1) THEN V8240 = .;
   IF (V8241 >= -5 AND V8241 <= -1) THEN V8241 = .;
   IF (V8242 >= -5 AND V8242 <= -1) THEN V8242 = .;
   IF (V8243 >= -5 AND V8243 <= -1) THEN V8243 = .;
   IF (V8244 >= -5 AND V8244 <= -1) THEN V8244 = .;
   IF (V8245 >= -5 AND V8245 <= -1) THEN V8245 = .;
   IF (V8246 >= -5 AND V8246 <= -1) THEN V8246 = .;
   IF (V8247 >= -5 AND V8247 <= -1) THEN V8247 = .;
   IF (V8248 >= -5 AND V8248 <= -1) THEN V8248 = .;
   IF (V8249 >= -5 AND V8249 <= -1) THEN V8249 = .;
   IF (V8250 >= -5 AND V8250 <= -1) THEN V8250 = .;
   IF (V8251 >= -5 AND V8251 <= -1) THEN V8251 = .;
   IF (V8252 >= -5 AND V8252 <= -1) THEN V8252 = .;
   IF (V8253 >= -5 AND V8253 <= -1) THEN V8253 = .;
   IF (V8254 >= -5 AND V8254 <= -1) THEN V8254 = .;
   IF (V8255 >= -5 AND V8255 <= -1) THEN V8255 = .;
   IF (V8256 >= -5 AND V8256 <= -1) THEN V8256 = .;
   IF (V8257 >= -5 AND V8257 <= -1) THEN V8257 = .;
   IF (V8258 >= -5 AND V8258 <= -1) THEN V8258 = .;
   IF (V8259 >= -5 AND V8259 <= -1) THEN V8259 = .;
   IF (V8260 >= -5 AND V8260 <= -1) THEN V8260 = .;
   IF (V8261 >= -5 AND V8261 <= -1) THEN V8261 = .;
   IF (V8262 >= -5 AND V8262 <= -1) THEN V8262 = .;
   IF (V8263 >= -5 AND V8263 <= -1) THEN V8263 = .;
   IF (V8264 >= -5 AND V8264 <= -1) THEN V8264 = .;
   IF (V8265 >= -5 AND V8265 <= -1) THEN V8265 = .;
   IF (V8266 >= -5 AND V8266 <= -1) THEN V8266 = .;
   IF (V8267 >= -5 AND V8267 <= -1) THEN V8267 = .;
   IF (V8268 >= -5 AND V8268 <= -1) THEN V8268 = .;
   IF (V8269 >= -5 AND V8269 <= -1) THEN V8269 = .;
   IF (V8270 >= -5 AND V8270 <= -1) THEN V8270 = .;
   IF (V8271 >= -5 AND V8271 <= -1) THEN V8271 = .;
   IF (V8272 >= -5 AND V8272 <= -1) THEN V8272 = .;
   IF (V8273 >= -5 AND V8273 <= -1) THEN V8273 = .;
   IF (V8274 >= -5 AND V8274 <= -1) THEN V8274 = .;
   IF (V8275 >= -5 AND V8275 <= -1) THEN V8275 = .;
   IF (V8276 >= -5 AND V8276 <= -1) THEN V8276 = .;
   IF (V8277 >= -5 AND V8277 <= -1) THEN V8277 = .;
   IF (V8278 >= -5 AND V8278 <= -1) THEN V8278 = .;
   IF (V8279 >= -5 AND V8279 <= -1) THEN V8279 = .;
   IF (V8280 >= -5 AND V8280 <= -1) THEN V8280 = .;
   IF (V8281 >= -5 AND V8281 <= -1) THEN V8281 = .;
   IF (V8282 >= -5 AND V8282 <= -1) THEN V8282 = .;
   IF (V8283 >= -5 AND V8283 <= -1) THEN V8283 = .;
   IF (V8284 >= -5 AND V8284 <= -1) THEN V8284 = .;
   IF (V8285 >= -5 AND V8285 <= -1) THEN V8285 = .;
   IF (V8286 >= -5 AND V8286 <= -1) THEN V8286 = .;
   IF (V8287 >= -5 AND V8287 <= -1) THEN V8287 = .;
   IF (V8288 >= -5 AND V8288 <= -1) THEN V8288 = .;
   IF (V8289 >= -5 AND V8289 <= -1) THEN V8289 = .;
   IF (V8290 >= -5 AND V8290 <= -1) THEN V8290 = .;
   IF (V8291 >= -5 AND V8291 <= -1) THEN V8291 = .;
   IF (V8292 >= -5 AND V8292 <= -1) THEN V8292 = .;
   IF (V8293 >= -5 AND V8293 <= -1) THEN V8293 = .;
   IF (V8294 >= -5 AND V8294 <= -1) THEN V8294 = .;
   IF (V8295 >= -5 AND V8295 <= -1) THEN V8295 = .;
   IF (V8296 >= -5 AND V8296 <= -1) THEN V8296 = .;
   IF (V8297 >= -5 AND V8297 <= -1) THEN V8297 = .;
   IF (V8298 >= -5 AND V8298 <= -1) THEN V8298 = .;
   IF (V8299 >= -5 AND V8299 <= -1) THEN V8299 = .;
   IF (V8300 >= -5 AND V8300 <= -1) THEN V8300 = .;
   IF (V8301 >= -5 AND V8301 <= -1) THEN V8301 = .;
   IF (V8302 >= -5 AND V8302 <= -1) THEN V8302 = .;
   IF (V8303 >= -5 AND V8303 <= -1) THEN V8303 = .;
   IF (V8304 >= -5 AND V8304 <= -1) THEN V8304 = .;
   IF (V8305 >= -5 AND V8305 <= -1) THEN V8305 = .;
   IF (V8306 >= -5 AND V8306 <= -1) THEN V8306 = .;
   IF (V8307 >= -5 AND V8307 <= -1) THEN V8307 = .;
   IF (V8308 >= -5 AND V8308 <= -1) THEN V8308 = .;
   IF (V8309 >= -5 AND V8309 <= -1) THEN V8309 = .;
   IF (V8310 >= -5 AND V8310 <= -1) THEN V8310 = .;
   IF (V8311 >= -5 AND V8311 <= -1) THEN V8311 = .;
   IF (V8312 >= -5 AND V8312 <= -1) THEN V8312 = .;
   IF (V8313 >= -5 AND V8313 <= -1) THEN V8313 = .;
   IF (V8314 >= -5 AND V8314 <= -1) THEN V8314 = .;
   IF (V8315 >= -5 AND V8315 <= -1) THEN V8315 = .;
   IF (V8316 >= -5 AND V8316 <= -1) THEN V8316 = .;
   IF (V8317 >= -5 AND V8317 <= -1) THEN V8317 = .;
   IF (V8318 >= -5 AND V8318 <= -1) THEN V8318 = .;
   IF (V8319 >= -5 AND V8319 <= -1) THEN V8319 = .;
   IF (V8320 >= -5 AND V8320 <= -1) THEN V8320 = .;
   IF (V8321 >= -5 AND V8321 <= -1) THEN V8321 = .;
   IF (V8322 >= -5 AND V8322 <= -1) THEN V8322 = .;
   IF (V8323 >= -5 AND V8323 <= -1) THEN V8323 = .;
   IF (V8324 >= -5 AND V8324 <= -1) THEN V8324 = .;
   IF (V8325 >= -5 AND V8325 <= -1) THEN V8325 = .;
   IF (V8326 >= -5 AND V8326 <= -1) THEN V8326 = .;
   IF (V8327 >= -5 AND V8327 <= -1) THEN V8327 = .;
   IF (V8328 >= -5 AND V8328 <= -1) THEN V8328 = .;
   IF (V8329 >= -5 AND V8329 <= -1) THEN V8329 = .;
   IF (V8330 >= -5 AND V8330 <= -1) THEN V8330 = .;
   IF (V8331 >= -5 AND V8331 <= -1) THEN V8331 = .;
   IF (V8332 >= -5 AND V8332 <= -1) THEN V8332 = .;
   IF (V8333 >= -5 AND V8333 <= -1) THEN V8333 = .;
   IF (V8334 >= -5 AND V8334 <= -1) THEN V8334 = .;
   IF (V8335 >= -5 AND V8335 <= -1) THEN V8335 = .;
   IF (V8336 >= -5 AND V8336 <= -1) THEN V8336 = .;
   IF (V8337 >= -5 AND V8337 <= -1) THEN V8337 = .;
   IF (V8338 >= -5 AND V8338 <= -1) THEN V8338 = .;
   IF (V8339 >= -5 AND V8339 <= -1) THEN V8339 = .;
   IF (V8340 >= -5 AND V8340 <= -1) THEN V8340 = .;
   IF (V8341 >= -5 AND V8341 <= -1) THEN V8341 = .;
   IF (V8342 >= -5 AND V8342 <= -1) THEN V8342 = .;
   IF (V8343 >= -5 AND V8343 <= -1) THEN V8343 = .;
   IF (V8344 >= -5 AND V8344 <= -1) THEN V8344 = .;
   IF (V8345 >= -5 AND V8345 <= -1) THEN V8345 = .;
   IF (V8346 >= -5 AND V8346 <= -1) THEN V8346 = .;
   IF (V8347 >= -5 AND V8347 <= -1) THEN V8347 = .;
   IF (V8348 >= -5 AND V8348 <= -1) THEN V8348 = .;
   IF (V8349 >= -5 AND V8349 <= -1) THEN V8349 = .;
   IF (V8350 >= -5 AND V8350 <= -1) THEN V8350 = .;
   IF (V8351 >= -5 AND V8351 <= -1) THEN V8351 = .;
   IF (V8352 >= -5 AND V8352 <= -1) THEN V8352 = .;
   IF (V8353 >= -5 AND V8353 <= -1) THEN V8353 = .;
   IF (V8354 >= -5 AND V8354 <= -1) THEN V8354 = .;
   IF (V8355 >= -5 AND V8355 <= -1) THEN V8355 = .;
   IF (V8356 >= -5 AND V8356 <= -1) THEN V8356 = .;
   IF (V8357 >= -5 AND V8357 <= -1) THEN V8357 = .;
   IF (V8358 >= -5 AND V8358 <= -1) THEN V8358 = .;
   IF (V8359 >= -5 AND V8359 <= -1) THEN V8359 = .;
   IF (V8360 >= -5 AND V8360 <= -1) THEN V8360 = .;
   IF (V8361 >= -5 AND V8361 <= -1) THEN V8361 = .;
   IF (V8362 >= -5 AND V8362 <= -1) THEN V8362 = .;
   IF (V8363 >= -5 AND V8363 <= -1) THEN V8363 = .;
   IF (V8364 >= -5 AND V8364 <= -1) THEN V8364 = .;
   IF (V8365 >= -5 AND V8365 <= -1) THEN V8365 = .;
   IF (V8366 >= -5 AND V8366 <= -1) THEN V8366 = .;
   IF (V8367 >= -5 AND V8367 <= -1) THEN V8367 = .;
   IF (V8368 >= -5 AND V8368 <= -1) THEN V8368 = .;
   IF (V8369 >= -5 AND V8369 <= -1) THEN V8369 = .;
   IF (V8370 >= -5 AND V8370 <= -1) THEN V8370 = .;
   IF (V8371 >= -5 AND V8371 <= -1) THEN V8371 = .;
   IF (V8372 >= -5 AND V8372 <= -1) THEN V8372 = .;
   IF (V8373 >= -5 AND V8373 <= -1) THEN V8373 = .;
   IF (V8374 >= -5 AND V8374 <= -1) THEN V8374 = .;
   IF (V8375 >= -5 AND V8375 <= -1) THEN V8375 = .;
   IF (V8376 >= -5 AND V8376 <= -1) THEN V8376 = .;
   IF (V8377 >= -5 AND V8377 <= -1) THEN V8377 = .;
   IF (V8378 >= -5 AND V8378 <= -1) THEN V8378 = .;
   IF (V8379 >= -5 AND V8379 <= -1) THEN V8379 = .;
   IF (V8380 >= -5 AND V8380 <= -1) THEN V8380 = .;
   IF (V8381 >= -5 AND V8381 <= -1) THEN V8381 = .;
   IF (V8382 >= -5 AND V8382 <= -1) THEN V8382 = .;
   IF (V8383 >= -5 AND V8383 <= -1) THEN V8383 = .;
   IF (V8384 >= -5 AND V8384 <= -1) THEN V8384 = .;
   IF (V8385 >= -5 AND V8385 <= -1) THEN V8385 = .;
   IF (V8386 >= -5 AND V8386 <= -1) THEN V8386 = .;
   IF (V8387 >= -5 AND V8387 <= -1) THEN V8387 = .;
   IF (V8388 >= -5 AND V8388 <= -1) THEN V8388 = .;
   IF (V8389 >= -5 AND V8389 <= -1) THEN V8389 = .;
   IF (V8390 >= -5 AND V8390 <= -1) THEN V8390 = .;
   IF (V8391 >= -5 AND V8391 <= -1) THEN V8391 = .;
   IF (V8392 >= -5 AND V8392 <= -1) THEN V8392 = .;
   IF (V8393 >= -5 AND V8393 <= -1) THEN V8393 = .;
   IF (V8394 >= -5 AND V8394 <= -1) THEN V8394 = .;
   IF (V8395 >= -5 AND V8395 <= -1) THEN V8395 = .;
   IF (V8396 >= -5 AND V8396 <= -1) THEN V8396 = .;
   IF (V8397 >= -5 AND V8397 <= -1) THEN V8397 = .;
   IF (V8398 >= -5 AND V8398 <= -1) THEN V8398 = .;
   IF (V8399 >= -5 AND V8399 <= -1) THEN V8399 = .;
   IF (V8400 >= -5 AND V8400 <= -1) THEN V8400 = .;
   IF (V8401 >= -5 AND V8401 <= -1) THEN V8401 = .;
   IF (V8402 >= -5 AND V8402 <= -1) THEN V8402 = .;
   IF (V8403 >= -5 AND V8403 <= -1) THEN V8403 = .;
   IF (V8404 >= -5 AND V8404 <= -1) THEN V8404 = .;
   IF (V8405 >= -5 AND V8405 <= -1) THEN V8405 = .;
   IF (V8406 >= -5 AND V8406 <= -1) THEN V8406 = .;
   IF (V8407 >= -5 AND V8407 <= -1) THEN V8407 = .;
   IF (V8408 >= -5 AND V8408 <= -1) THEN V8408 = .;
   IF (V8409 >= -5 AND V8409 <= -1) THEN V8409 = .;
   IF (V8410 >= -5 AND V8410 <= -1) THEN V8410 = .;
   IF (V8411 >= -5 AND V8411 <= -1) THEN V8411 = .;
   IF (V8412 >= -5 AND V8412 <= -1) THEN V8412 = .;
   IF (V8413 >= -5 AND V8413 <= -1) THEN V8413 = .;
   IF (V8414 >= -5 AND V8414 <= -1) THEN V8414 = .;
   IF (V8415 >= -5 AND V8415 <= -1) THEN V8415 = .;
   IF (V8416 >= -5 AND V8416 <= -1) THEN V8416 = .;
   IF (V8417 >= -5 AND V8417 <= -1) THEN V8417 = .;
   IF (V8418 >= -5 AND V8418 <= -1) THEN V8418 = .;
   IF (V8419 >= -5 AND V8419 <= -1) THEN V8419 = .;
   IF (V8420 >= -5 AND V8420 <= -1) THEN V8420 = .;
   IF (V8421 >= -5 AND V8421 <= -1) THEN V8421 = .;
   IF (V8422 >= -5 AND V8422 <= -1) THEN V8422 = .;
   IF (V8423 >= -5 AND V8423 <= -1) THEN V8423 = .;
   IF (V8424 >= -5 AND V8424 <= -1) THEN V8424 = .;
   IF (V8425 >= -5 AND V8425 <= -1) THEN V8425 = .;
   IF (V8426 >= -5 AND V8426 <= -1) THEN V8426 = .;
   IF (V8427 >= -5 AND V8427 <= -1) THEN V8427 = .;
   IF (V8428 >= -5 AND V8428 <= -1) THEN V8428 = .;
   IF (V8429 >= -5 AND V8429 <= -1) THEN V8429 = .;
   IF (V8430 >= -5 AND V8430 <= -1) THEN V8430 = .;
   IF (V8431 >= -5 AND V8431 <= -1) THEN V8431 = .;
   IF (V8432 >= -5 AND V8432 <= -1) THEN V8432 = .;
   IF (V8433 >= -5 AND V8433 <= -1) THEN V8433 = .;
   IF (V8434 >= -5 AND V8434 <= -1) THEN V8434 = .;
   IF (V8435 >= -5 AND V8435 <= -1) THEN V8435 = .;
   IF (V8436 >= -5 AND V8436 <= -1) THEN V8436 = .;
   IF (V8437 >= -5 AND V8437 <= -1) THEN V8437 = .;
   IF (V8438 >= -5 AND V8438 <= -1) THEN V8438 = .;
   IF (V8439 >= -5 AND V8439 <= -1) THEN V8439 = .;
   IF (V8440 >= -5 AND V8440 <= -1) THEN V8440 = .;
   IF (V8441 >= -5 AND V8441 <= -1) THEN V8441 = .;
   IF (V8442 >= -5 AND V8442 <= -1) THEN V8442 = .;
   IF (V8443 >= -5 AND V8443 <= -1) THEN V8443 = .;
   IF (V8444 >= -5 AND V8444 <= -1) THEN V8444 = .;
   IF (V8445 >= -5 AND V8445 <= -1) THEN V8445 = .;
   IF (V8446 >= -5 AND V8446 <= -1) THEN V8446 = .;
   IF (V8447 >= -5 AND V8447 <= -1) THEN V8447 = .;
   IF (V8448 >= -5 AND V8448 <= -1) THEN V8448 = .;
   IF (V8449 >= -5 AND V8449 <= -1) THEN V8449 = .;
   IF (V8450 >= -5 AND V8450 <= -1) THEN V8450 = .;
   IF (V8451 >= -5 AND V8451 <= -1) THEN V8451 = .;
   IF (V8452 >= -5 AND V8452 <= -1) THEN V8452 = .;
   IF (V8453 >= -5 AND V8453 <= -1) THEN V8453 = .;
   IF (V8454 >= -5 AND V8454 <= -1) THEN V8454 = .;
   IF (V8455 >= -5 AND V8455 <= -1) THEN V8455 = .;
   IF (V8456 >= -5 AND V8456 <= -1) THEN V8456 = .;
   IF (V8457 >= -5 AND V8457 <= -1) THEN V8457 = .;
   IF (V8458 >= -5 AND V8458 <= -1) THEN V8458 = .;
   IF (V8459 >= -5 AND V8459 <= -1) THEN V8459 = .;
   IF (V8460 >= -5 AND V8460 <= -1) THEN V8460 = .;
   IF (V8461 >= -5 AND V8461 <= -1) THEN V8461 = .;
   IF (V8462 >= -5 AND V8462 <= -1) THEN V8462 = .;
   IF (V8463 >= -5 AND V8463 <= -1) THEN V8463 = .;
   IF (V8464 >= -5 AND V8464 <= -1) THEN V8464 = .;
   IF (V8465 >= -5 AND V8465 <= -1) THEN V8465 = .;
   IF (V8466 >= -5 AND V8466 <= -1) THEN V8466 = .;
   IF (V8467 >= -5 AND V8467 <= -1) THEN V8467 = .;
   IF (V8468 >= -5 AND V8468 <= -1) THEN V8468 = .;
   IF (V8469 >= -5 AND V8469 <= -1) THEN V8469 = .;
   IF (V8470 >= -5 AND V8470 <= -1) THEN V8470 = .;
   IF (V8471 >= -5 AND V8471 <= -1) THEN V8471 = .;
   IF (V8472 >= -5 AND V8472 <= -1) THEN V8472 = .;
   IF (V8473 >= -5 AND V8473 <= -1) THEN V8473 = .;
   IF (V8474 >= -5 AND V8474 <= -1) THEN V8474 = .;
   IF (V8475 >= -5 AND V8475 <= -1) THEN V8475 = .;
   IF (V8476 >= -5 AND V8476 <= -1) THEN V8476 = .;
   IF (V8477 >= -5 AND V8477 <= -1) THEN V8477 = .;
   IF (V8478 >= -5 AND V8478 <= -1) THEN V8478 = .;
   IF (V8479 >= -5 AND V8479 <= -1) THEN V8479 = .;
   IF (V8480 >= -5 AND V8480 <= -1) THEN V8480 = .;
   IF (V8481 >= -5 AND V8481 <= -1) THEN V8481 = .;
   IF (V8482 >= -5 AND V8482 <= -1) THEN V8482 = .;
   IF (V8483 >= -5 AND V8483 <= -1) THEN V8483 = .;
   IF (V8484 >= -5 AND V8484 <= -1) THEN V8484 = .;
   IF (V8485 >= -5 AND V8485 <= -1) THEN V8485 = .;
   IF (V8486 >= -5 AND V8486 <= -1) THEN V8486 = .;
   IF (V8487 >= -5 AND V8487 <= -1) THEN V8487 = .;
   IF (V8488 >= -5 AND V8488 <= -1) THEN V8488 = .;
   IF (V8489 >= -5 AND V8489 <= -1) THEN V8489 = .;
   IF (V8490 >= -5 AND V8490 <= -1) THEN V8490 = .;
   IF (V8491 >= -5 AND V8491 <= -1) THEN V8491 = .;
   IF (V8492 >= -5 AND V8492 <= -1) THEN V8492 = .;
   IF (V8493 >= -5 AND V8493 <= -1) THEN V8493 = .;
   IF (V8494 >= -5 AND V8494 <= -1) THEN V8494 = .;
   IF (V8495 >= -5 AND V8495 <= -1) THEN V8495 = .;
   IF (V8496 >= -5 AND V8496 <= -1) THEN V8496 = .;
   IF (V8497 >= -5 AND V8497 <= -1) THEN V8497 = .;
   IF (V8498 >= -5 AND V8498 <= -1) THEN V8498 = .;
   IF (V8499 >= -5 AND V8499 <= -1) THEN V8499 = .;
   IF (V8500 >= -5 AND V8500 <= -1) THEN V8500 = .;
   IF (V8501 >= -5 AND V8501 <= -1) THEN V8501 = .;
   IF (V8502 >= -5 AND V8502 <= -1) THEN V8502 = .;
   IF (V8503 >= -5 AND V8503 <= -1) THEN V8503 = .;
   IF (V8504 >= -5 AND V8504 <= -1) THEN V8504 = .;
   IF (V8505 >= -5 AND V8505 <= -1) THEN V8505 = .;
   IF (V8506 >= -5 AND V8506 <= -1) THEN V8506 = .;
   IF (V8507 >= -5 AND V8507 <= -1) THEN V8507 = .;
   IF (V8508 >= -5 AND V8508 <= -1) THEN V8508 = .;
   IF (V8509 >= -5 AND V8509 <= -1) THEN V8509 = .;
   IF (V8510 >= -5 AND V8510 <= -1) THEN V8510 = .;
   IF (V8511 >= -5 AND V8511 <= -1) THEN V8511 = .;
   IF (V8512 >= -5 AND V8512 <= -1) THEN V8512 = .;
   IF (V8513 >= -5 AND V8513 <= -1) THEN V8513 = .;
   IF (V8514 >= -5 AND V8514 <= -1) THEN V8514 = .;
   IF (V8515 >= -5 AND V8515 <= -1) THEN V8515 = .;
   IF (V8516 >= -5 AND V8516 <= -1) THEN V8516 = .;
   IF (V8517 >= -5 AND V8517 <= -1) THEN V8517 = .;
   IF (V8518 >= -5 AND V8518 <= -1) THEN V8518 = .;
   IF (V8519 >= -5 AND V8519 <= -1) THEN V8519 = .;
   IF (V8520 >= -5 AND V8520 <= -1) THEN V8520 = .;
   IF (V8521 >= -5 AND V8521 <= -1) THEN V8521 = .;
   IF (V8522 >= -5 AND V8522 <= -1) THEN V8522 = .;
   IF (V8523 >= -5 AND V8523 <= -1) THEN V8523 = .;
   IF (V8524 >= -5 AND V8524 <= -1) THEN V8524 = .;
   IF (V8525 >= -5 AND V8525 <= -1) THEN V8525 = .;
   IF (V8526 >= -5 AND V8526 <= -1) THEN V8526 = .;
   IF (V8527 >= -5 AND V8527 <= -1) THEN V8527 = .;
   IF (V8528 >= -5 AND V8528 <= -1) THEN V8528 = .;
   IF (V8529 >= -5 AND V8529 <= -1) THEN V8529 = .;
   IF (V8530 >= -5 AND V8530 <= -1) THEN V8530 = .;
   IF (V8531 >= -5 AND V8531 <= -1) THEN V8531 = .;
   IF (V8532 >= -5 AND V8532 <= -1) THEN V8532 = .;
   IF (V8533 >= -5 AND V8533 <= -1) THEN V8533 = .;
   IF (V8534 >= -5 AND V8534 <= -1) THEN V8534 = .;
   IF (V8535 >= -5 AND V8535 <= -1) THEN V8535 = .;
   IF (V8536 >= -5 AND V8536 <= -1) THEN V8536 = .;
   IF (V8537 >= -5 AND V8537 <= -1) THEN V8537 = .;
   IF (V8538 >= -5 AND V8538 <= -1) THEN V8538 = .;
   IF (V8539 >= -5 AND V8539 <= -1) THEN V8539 = .;
   IF (V8540 >= -5 AND V8540 <= -1) THEN V8540 = .;
   IF (V8541 >= -5 AND V8541 <= -1) THEN V8541 = .;
   IF (V8542 >= -5 AND V8542 <= -1) THEN V8542 = .;
   IF (V8543 >= -5 AND V8543 <= -1) THEN V8543 = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT V7004 v7004fff. V7005 v7005fff. V7006 v7006fff.
         V7007 v7007fff. V7008 v7008fff. V7009 v7009fff.
         V7010 v7010fff. V7011 v7011fff. V7012 v7012fff.
         V7013 v7013fff. V7014 v7014fff. V7015 v7015fff.
         V7016 v7016fff. V7017 v7017fff. V7018 v7018fff.
         V7019 v7019fff. V7020 v7020fff. V7021 v7021fff.
         V7022 v7022fff. V7023 v7023fff. V7024 v7024fff.
         V7025 v7025fff. V7026 v7026fff. V7027 v7027fff.
         V7028 v7028fff. V7029 v7029fff. V7030 v7030fff.
         V7031 v7031fff. V7032 v7032fff. V7033 v7033fff.
         V7034 v7034fff. V7035 v7035fff. V7036 v7036fff.
         V7037 v7037fff. V7038 v7038fff. V7039 v7039fff.
         V7040 v7040fff. V7041 v7041fff. V7042 v7042fff.
         V7043 v7043fff. V7044 v7044fff. V7045 v7045fff.
         V7046 v7046fff. V7047 v7047fff. V7048 v7048fff.
         V7049 v7049fff. V7050 v7050fff. V7051 v7051fff.
         V7052 v7052fff. V7053 v7053fff. V7054 v7054fff.
         V7055 v7055fff. V7056 v7056fff. V7057 v7057fff.
         V7058 v7058fff. V7059 v7059fff. V7060 v7060fff.
         V7061 v7061fff. V7062 v7062fff. V7063 v7063fff.
         V7064 v7064fff. V7065 v7065fff. V7066 v7066fff.
         V7067 v7067fff. V7068 v7068fff. V7069 v7069fff.
         V7070 v7070fff. V7071 v7071fff. V7072 v7072fff.
         V7073 v7073fff. V7074 v7074fff. V7075 v7075fff.
         V7076 v7076fff. V7077 v7077fff. V7078 v7078fff.
         V7079 v7079fff. V7080 v7080fff. V7081 v7081fff.
         V7082 v7082fff. V7083 v7083fff. V7084 v7084fff.
         V7085 v7085fff. V7086 v7086fff. V7087 v7087fff.
         V7088 v7088fff. V7089 v7089fff. V7090 v7090fff.
         V7091 v7091fff. V7092 v7092fff. V7093 v7093fff.
         V7094 v7094fff. V7095 v7095fff. V7096 v7096fff.
         V7097 v7097fff. V7098 v7098fff. V7099 v7099fff.
         V7100 v7100fff. V7101 v7101fff. V7102 v7102fff.
         V7103 v7103fff. V7104 v7104fff. V7105 v7105fff.
         V7106 v7106fff. V7107 v7107fff. V7108 v7108fff.
         V7109 v7109fff. V7110 v7110fff. V7111 v7111fff.
         V7112 v7112fff. V7113 v7113fff. V7114 v7114fff.
         V7115 v7115fff. V7116 v7116fff. V7117 v7117fff.
         V7118 v7118fff. V7119 v7119fff. V7120 v7120fff.
         V7121 v7121fff. V7122 v7122fff. V7123 v7123fff.
         V7124 v7124fff. V7125 v7125fff. V7126 v7126fff.
         V7127 v7127fff. V7128 v7128fff. V7129 v7129fff.
         V7130 v7130fff. V7131 v7131fff. V7132 v7132fff.
         V7133 v7133fff. V7134 v7134fff. V7135 v7135fff.
         V7136 v7136fff. V7137 v7137fff. V7138 v7138fff.
         V7139 v7139fff. V7140 v7140fff. V7141 v7141fff.
         V7142 v7142fff. V7143 v7143fff. V7144 v7144fff.
         V7145 v7145fff. V7146 v7146fff. V7147 v7147fff.
         V7148 v7148fff. V7149 v7149fff. V7150 v7150fff.
         V7151 v7151fff. V7152 v7152fff. V7153 v7153fff.
         V7154 v7154fff. V7155 v7155fff. V7156 v7156fff.
         V7157 v7157fff. V7158 v7158fff. V7159 v7159fff.
         V7160 v7160fff. V7161 v7161fff. V7162 v7162fff.
         V7163 v7163fff. V7164 v7164fff. V7165 v7165fff.
         V7166 v7166fff. V7167 v7167fff. V7168 v7168fff.
         V7169 v7169fff. V7170 v7170fff. V7171 v7171fff.
         V7172 v7172fff. V7173 v7173fff. V7174 v7174fff.
         V7175 v7175fff. V7176 v7176fff. V7177 v7177fff.
         V7178 v7178fff. V7179 v7179fff. V7180 v7180fff.
         V7181 v7181fff. V7182 v7182fff. V7183 v7183fff.
         V7184 v7184fff. V7185 v7185fff. V7186 v7186fff.
         V7187 v7187fff. V7188 v7188fff. V7189 v7189fff.
         V7190 v7190fff. V7191 v7191fff. V7192 v7192fff.
         V7193 v7193fff. V7194 v7194fff. V7195 v7195fff.
         V7196 v7196fff. V7197 v7197fff. V7198 v7198fff.
         V7199 v7199fff. V7200 v7200fff. V7201 v7201fff.
         V7202 v7202fff. V7203 v7203fff. V7204 v7204fff.
         V7205 v7205fff. V7206 v7206fff. V7207 v7207fff.
         V7208 v7208fff. V7209 v7209fff. V7210 v7210fff.
         V7211 v7211fff. V7212 v7212fff. V7213 v7213fff.
         V7214 v7214fff. V7215 v7215fff. V7216 v7216fff.
         V7217 v7217fff. V7218 v7218fff. V7219 v7219fff.
         V7220 v7220fff. V7221 v7221fff. V7222 v7222fff.
         V7223 v7223fff. V7224 v7224fff. V7225 v7225fff.
         V7226 v7226fff. V7227 v7227fff. V7228 v7228fff.
         V7229 v7229fff. V7230 v7230fff. V7231 v7231fff.
         V7232 v7232fff. V7233 v7233fff. V7234 v7234fff.
         V7235 v7235fff. V7236 v7236fff. V7237 v7237fff.
         V7238 v7238fff. V7239 v7239fff. V7240 v7240fff.
         V7241 v7241fff. V7242 v7242fff. V7243 v7243fff.
         V7244 v7244fff. V7245 v7245fff. V7246 v7246fff.
         V7247 v7247fff. V7248 v7248fff. V7249 v7249fff.
         V7250 v7250fff. V7251 v7251fff. V7252 v7252fff.
         V7253 v7253fff. V7254 v7254fff. V7255 v7255fff.
         V7256 v7256fff. V7257 v7257fff. V7258 v7258fff.
         V7259 v7259fff. V7260 v7260fff. V7261 v7261fff.
         V7262 v7262fff. V7263 v7263fff. V7264 v7264fff.
         V7265 v7265fff. V7266 v7266fff. V7267 v7267fff.
         V7268 v7268fff. V7269 v7269fff. V7270 v7270fff.
         V7271 v7271fff. V7272 v7272fff. V7273 v7273fff.
         V7274 v7274fff. V7275 v7275fff. V7276 v7276fff.
         V7277 v7277fff. V7278 v7278fff. V7279 v7279fff.
         V7280 v7280fff. V7281 v7281fff. V7282 v7282fff.
         V7283 v7283fff. V7284 v7284fff. V7285 v7285fff.
         V7286 v7286fff. V7287 v7287fff. V7288 v7288fff.
         V7289 v7289fff. V7290 v7290fff. V7291 v7291fff.
         V7292 v7292fff. V7293 v7293fff. V7294 v7294fff.
         V7295 v7295fff. V7296 v7296fff. V7297 v7297fff.
         V7298 v7298fff. V7299 v7299fff. V7300 v7300fff.
         V7301 v7301fff. V7302 v7302fff. V7303 v7303fff.
         V7304 v7304fff. V7305 v7305fff. V7306 v7306fff.
         V7307 v7307fff. V7308 v7308fff. V7309 v7309fff.
         V7310 v7310fff. V7311 v7311fff. V7312 v7312fff.
         V7313 v7313fff. V7314 v7314fff. V7315 v7315fff.
         V7316 v7316fff. V7317 v7317fff. V7318 v7318fff.
         V7319 v7319fff. V7320 v7320fff. V7321 v7321fff.
         V7322 v7322fff. V7323 v7323fff. V7324 v7324fff.
         V7325 v7325fff. V7326 v7326fff. V7327 v7327fff.
         V7328 v7328fff. V7329 v7329fff. V7330 v7330fff.
         V7331 v7331fff. V7332 v7332fff. V7333 v7333fff.
         V7334 v7334fff. V7335 v7335fff. V7336 v7336fff.
         V7337 v7337fff. V7338 v7338fff. V7339 v7339fff.
         V7340 v7340fff. V7341 v7341fff. V7342 v7342fff.
         V7343 v7343fff. V7344 v7344fff. V7345 v7345fff.
         V7346 v7346fff. V7347 v7347fff. V7348 v7348fff.
         V7349 v7349fff. V7350 v7350fff. V7351 v7351fff.
         V7352 v7352fff. V7353 v7353fff. V7354 v7354fff.
         V7355 v7355fff. V7356 v7356fff. V7357 v7357fff.
         V7358 v7358fff. V7359 v7359fff. V7360 v7360fff.
         V7361 v7361fff. V7362 v7362fff. V7363 v7363fff.
         V7364 v7364fff. V7365 v7365fff. V7366 v7366fff.
         V7367 v7367fff. V7368 v7368fff. V7369 v7369fff.
         V7370 v7370fff. V7371 v7371fff. V7372 v7372fff.
         V7373 v7373fff. V7374 v7374fff. V7375 v7375fff.
         V7376 v7376fff. V7377 v7377fff. V7378 v7378fff.
         V7379 v7379fff. V7380 v7380fff. V7381 v7381fff.
         V7382 v7382fff. V7383 v7383fff. V7384 v7384fff.
         V7385 v7385fff. V7386 v7386fff. V7387 v7387fff.
         V7388 v7388fff. V7389 v7389fff. V7390 v7390fff.
         V7391 v7391fff. V7392 v7392fff. V7393 v7393fff.
         V7394 v7394fff. V7395 v7395fff. V7396 v7396fff.
         V7397 v7397fff. V7398 v7398fff. V7399 v7399fff.
         V7400 v7400fff. V7401 v7401fff. V7402 v7402fff.
         V7403 v7403fff. V7404 v7404fff. V7405 v7405fff.
         V7406 v7406fff. V7407 v7407fff. V7408 v7408fff.
         V7409 v7409fff. V7410 v7410fff. V7411 v7411fff.
         V7412 v7412fff. V7413 v7413fff. V7414 v7414fff.
         V7415 v7415fff. V7416 v7416fff. V7417 v7417fff.
         V7418 v7418fff. V7419 v7419fff. V7420 v7420fff.
         V7421 v7421fff. V7422 v7422fff. V7423 v7423fff.
         V7424 v7424fff. V7425 v7425fff. V7426 v7426fff.
         V7427 v7427fff. V7428 v7428fff. V7429 v7429fff.
         V7430 v7430fff. V7431 v7431fff. V7432 v7432fff.
         V7433 v7433fff. V7434 v7434fff. V7435 v7435fff.
         V7436 v7436fff. V7437 v7437fff. V7438 v7438fff.
         V7439 v7439fff. V7440 v7440fff. V7441 v7441fff.
         V7442 v7442fff. V7443 v7443fff. V7444 v7444fff.
         V7445 v7445fff. V7446 v7446fff. V7447 v7447fff.
         V7448 v7448fff. V7449 v7449fff. V7450 v7450fff.
         V7451 v7451fff. V7452 v7452fff. V7453 v7453fff.
         V7454 v7454fff. V7455 v7455fff. V7456 v7456fff.
         V7457 v7457fff. V7458 v7458fff. V7459 v7459fff.
         V7460 v7460fff. V7461 v7461fff. V7462 v7462fff.
         V7463 v7463fff. V7464 v7464fff. V7465 v7465fff.
         V7466 v7466fff. V7467 v7467fff. V7468 v7468fff.
         V7469 v7469fff. V7470 v7470fff. V7471 v7471fff.
         V7472 v7472fff. V7473 v7473fff. V7474 v7474fff.
         V7475 v7475fff. V7476 v7476fff. V7477 v7477fff.
         V7478 v7478fff. V7479 v7479fff. V7480 v7480fff.
         V7481 v7481fff. V7482 v7482fff. V7483 v7483fff.
         V7484 v7484fff. V7485 v7485fff. V7486 v7486fff.
         V7487 v7487fff. V7488 v7488fff. V7489 v7489fff.
         V7490 v7490fff. V7491 v7491fff. V7492 v7492fff.
         V7493 v7493fff. V7494 v7494fff. V7495 v7495fff.
         V7496 v7496fff. V7497 v7497fff. V7498 v7498fff.
         V7499 v7499fff. V7500 v7500fff. V7501 v7501fff.
         V7502 v7502fff. V7503 v7503fff. V7504 v7504fff.
         V7505 v7505fff. V7506 v7506fff. V7507 v7507fff.
         V7508 v7508fff. V7509 v7509fff. V7510 v7510fff.
         V7511 v7511fff. V7512 v7512fff. V7513 v7513fff.
         V7514 v7514fff. V7515 v7515fff. V7516 v7516fff.
         V7517 v7517fff. V7518 v7518fff. V7519 v7519fff.
         V7520 v7520fff. V7521 v7521fff. V7522 v7522fff.
         V7523 v7523fff. V7524 v7524fff. V7525 v7525fff.
         V7526 v7526fff. V7527 v7527fff. V7528 v7528fff.
         V7529 v7529fff. V7530 v7530fff. V7531 v7531fff.
         V7532 v7532fff. V7533 v7533fff. V7534 v7534fff.
         V7535 v7535fff. V7536 v7536fff. V7537 v7537fff.
         V7538 v7538fff. V7539 v7539fff. V7540 v7540fff.
         V7541 v7541fff. V7542 v7542fff. V7543 v7543fff.
         V7544 v7544fff. V7545 v7545fff. V7546 v7546fff.
         V7547 v7547fff. V7548 v7548fff. V7549 v7549fff.
         V7550 v7550fff. V7551 v7551fff. V7552 v7552fff.
         V7553 v7553fff. V7554 v7554fff. V7555 v7555fff.
         V7556 v7556fff. V7557 v7557fff. V7558 v7558fff.
         V7559 v7559fff. V7560 v7560fff. V7561 v7561fff.
         V7562 v7562fff. V7563 v7563fff. V7564 v7564fff.
         V7565 v7565fff. V7566 v7566fff. V7567 v7567fff.
         V7568 v7568fff. V7569 v7569fff. V7570 v7570fff.
         V7571 v7571fff. V7572 v7572fff. V7573 v7573fff.
         V7574 v7574fff. V7575 v7575fff. V7576 v7576fff.
         V7577 v7577fff. V7578 v7578fff. V7579 v7579fff.
         V7580 v7580fff. V7581 v7581fff. V7582 v7582fff.
         V7583 v7583fff. V7584 v7584fff. V7585 v7585fff.
         V7586 v7586fff. V7587 v7587fff. V7588 v7588fff.
         V7589 v7589fff. V7590 v7590fff. V7591 v7591fff.
         V7592 v7592fff. V7593 v7593fff. V7594 v7594fff.
         V7595 v7595fff. V7596 v7596fff. V7597 v7597fff.
         V7598 v7598fff. V7599 v7599fff. V7600 v7600fff.
         V7601 v7601fff. V7602 v7602fff. V7603 v7603fff.
         V7604 v7604fff. V7605 v7605fff. V7606 v7606fff.
         V7607 v7607fff. V7608 v7608fff. V7609 v7609fff.
         V7610 v7610fff. V7611 v7611fff. V7612 v7612fff.
         V7613 v7613fff. V7614 v7614fff. V7615 v7615fff.
         V7616 v7616fff. V7617 v7617fff. V7618 v7618fff.
         V7619 v7619fff. V7620 v7620fff. V7621 v7621fff.
         V7622 v7622fff. V7623 v7623fff. V7624 v7624fff.
         V7625 v7625fff. V7626 v7626fff. V7627 v7627fff.
         V7628 v7628fff. V7629 v7629fff. V7630 v7630fff.
         V7631 v7631fff. V7632 v7632fff. V7633 v7633fff.
         V7634 v7634fff. V7635 v7635fff. V7636 v7636fff.
         V7637 v7637fff. V7638 v7638fff. V7639 v7639fff.
         V7640 v7640fff. V7641 v7641fff. V7642 v7642fff.
         V7643 v7643fff. V7644 v7644fff. V7645 v7645fff.
         V7646 v7646fff. V7647 v7647fff. V7648 v7648fff.
         V7649 v7649fff. V7650 v7650fff. V7651 v7651fff.
         V7652 v7652fff. V7653 v7653fff. V7654 v7654fff.
         V7655 v7655fff. V7656 v7656fff. V7657 v7657fff.
         V7658 v7658fff. V7659 v7659fff. V7660 v7660fff.
         V7661 v7661fff. V7662 v7662fff. V7663 v7663fff.
         V7664 v7664fff. V7665 v7665fff. V7666 v7666fff.
         V7667 v7667fff. V7668 v7668fff. V7669 v7669fff.
         V8004 v8004fff. V8005 v8005fff. V8006 v8006fff.
         V8007 v8007fff. V8008 v8008fff. V8009 v8009fff.
         V8010 v8010fff. V8011 v8011fff. V8012 v8012fff.
         V8013 v8013fff. V8014 v8014fff. V8015 v8015fff.
         V8016 v8016fff. V8017 v8017fff. V8018 v8018fff.
         V8019 v8019fff. V8020 v8020fff. V8021 v8021fff.
         V8022 v8022fff. V8023 v8023fff. V8024 v8024fff.
         V8025 v8025fff. V8026 v8026fff. V8027 v8027fff.
         V8028 v8028fff. V8029 v8029fff. V8030 v8030fff.
         V8031 v8031fff. V8032 v8032fff. V8033 v8033fff.
         V8034 v8034fff. V8035 v8035fff. V8036 v8036fff.
         V8037 v8037fff. V8038 v8038fff. V8039 v8039fff.
         V8040 v8040fff. V8041 v8041fff. V8042 v8042fff.
         V8043 v8043fff. V8044 v8044fff. V8045 v8045fff.
         V8046 v8046fff. V8047 v8047fff. V8048 v8048fff.
         V8049 v8049fff. V8050 v8050fff. V8051 v8051fff.
         V8052 v8052fff. V8053 v8053fff. V8054 v8054fff.
         V8055 v8055fff. V8056 v8056fff. V8057 v8057fff.
         V8058 v8058fff. V8059 v8059fff. V8060 v8060fff.
         V8061 v8061fff. V8062 v8062fff. V8063 v8063fff.
         V8064 v8064fff. V8065 v8065fff. V8066 v8066fff.
         V8067 v8067fff. V8068 v8068fff. V8069 v8069fff.
         V8070 v8070fff. V8071 v8071fff. V8072 v8072fff.
         V8073 v8073fff. V8074 v8074fff. V8075 v8075fff.
         V8076 v8076fff. V8077 v8077fff. V8078 v8078fff.
         V8079 v8079fff. V8080 v8080fff. V8081 v8081fff.
         V8082 v8082fff. V8083 v8083fff. V8084 v8084fff.
         V8085 v8085fff. V8086 v8086fff. V8087 v8087fff.
         V8088 v8088fff. V8089 v8089fff. V8090 v8090fff.
         V8091 v8091fff. V8092 v8092fff. V8093 v8093fff.
         V8094 v8094fff. V8095 v8095fff. V8096 v8096fff.
         V8097 v8097fff. V8098 v8098fff. V8099 v8099fff.
         V8100 v8100fff. V8101 v8101fff. V8102 v8102fff.
         V8103 v8103fff. V8104 v8104fff. V8105 v8105fff.
         V8106 v8106fff. V8107 v8107fff. V8108 v8108fff.
         V8109 v8109fff. V8110 v8110fff. V8111 v8111fff.
         V8112 v8112fff. V8113 v8113fff. V8114 v8114fff.
         V8115 v8115fff. V8116 v8116fff. V8117 v8117fff.
         V8118 v8118fff. V8119 v8119fff. V8120 v8120fff.
         V8121 v8121fff. V8122 v8122fff. V8123 v8123fff.
         V8124 v8124fff. V8125 v8125fff. V8126 v8126fff.
         V8127 v8127fff. V8128 v8128fff. V8129 v8129fff.
         V8130 v8130fff. V8131 v8131fff. V8132 v8132fff.
         V8133 v8133fff. V8134 v8134fff. V8135 v8135fff.
         V8136 v8136fff. V8137 v8137fff. V8138 v8138fff.
         V8139 v8139fff. V8140 v8140fff. V8141 v8141fff.
         V8142 v8142fff. V8143 v8143fff. V8144 v8144fff.
         V8145 v8145fff. V8146 v8146fff. V8147 v8147fff.
         V8148 v8148fff. V8149 v8149fff. V8150 v8150fff.
         V8151 v8151fff. V8152 v8152fff. V8153 v8153fff.
         V8154 v8154fff. V8155 v8155fff. V8156 v8156fff.
         V8157 v8157fff. V8158 v8158fff. V8159 v8159fff.
         V8160 v8160fff. V8161 v8161fff. V8162 v8162fff.
         V8163 v8163fff. V8164 v8164fff. V8165 v8165fff.
         V8166 v8166fff. V8167 v8167fff. V8168 v8168fff.
         V8169 v8169fff. V8170 v8170fff. V8171 v8171fff.
         V8172 v8172fff. V8173 v8173fff. V8174 v8174fff.
         V8175 v8175fff. V8176 v8176fff. V8177 v8177fff.
         V8178 v8178fff. V8179 v8179fff. V8180 v8180fff.
         V8181 v8181fff. V8182 v8182fff. V8183 v8183fff.
         V8184 v8184fff. V8185 v8185fff. V8186 v8186fff.
         V8187 v8187fff. V8188 v8188fff. V8189 v8189fff.
         V8190 v8190fff. V8191 v8191fff. V8192 v8192fff.
         V8193 v8193fff. V8194 v8194fff. V8195 v8195fff.
         V8196 v8196fff. V8197 v8197fff. V8198 v8198fff.
         V8199 v8199fff. V8200 v8200fff. V8201 v8201fff.
         V8202 v8202fff. V8203 v8203fff. V8204 v8204fff.
         V8205 v8205fff. V8206 v8206fff. V8207 v8207fff.
         V8208 v8208fff. V8209 v8209fff. V8210 v8210fff.
         V8211 v8211fff. V8212 v8212fff. V8213 v8213fff.
         V8214 v8214fff. V8215 v8215fff. V8216 v8216fff.
         V8217 v8217fff. V8218 v8218fff. V8219 v8219fff.
         V8220 v8220fff. V8221 v8221fff. V8222 v8222fff.
         V8223 v8223fff. V8224 v8224fff. V8225 v8225fff.
         V8226 v8226fff. V8227 v8227fff. V8228 v8228fff.
         V8229 v8229fff. V8230 v8230fff. V8231 v8231fff.
         V8232 v8232fff. V8233 v8233fff. V8234 v8234fff.
         V8235 v8235fff. V8236 v8236fff. V8237 v8237fff.
         V8238 v8238fff. V8239 v8239fff. V8240 v8240fff.
         V8241 v8241fff. V8242 v8242fff. V8243 v8243fff.
         V8244 v8244fff. V8245 v8245fff. V8246 v8246fff.
         V8247 v8247fff. V8248 v8248fff. V8249 v8249fff.
         V8250 v8250fff. V8251 v8251fff. V8252 v8252fff.
         V8253 v8253fff. V8254 v8254fff. V8255 v8255fff.
         V8256 v8256fff. V8257 v8257fff. V8258 v8258fff.
         V8259 v8259fff. V8260 v8260fff. V8261 v8261fff.
         V8262 v8262fff. V8263 v8263fff. V8264 v8264fff.
         V8265 v8265fff. V8266 v8266fff. V8267 v8267fff.
         V8268 v8268fff. V8269 v8269fff. V8270 v8270fff.
         V8271 v8271fff. V8272 v8272fff. V8273 v8273fff.
         V8274 v8274fff. V8275 v8275fff. V8276 v8276fff.
         V8277 v8277fff. V8278 v8278fff. V8279 v8279fff.
         V8280 v8280fff. V8281 v8281fff. V8282 v8282fff.
         V8283 v8283fff. V8284 v8284fff. V8285 v8285fff.
         V8286 v8286fff. V8287 v8287fff. V8288 v8288fff.
         V8289 v8289fff. V8290 v8290fff. V8291 v8291fff.
         V8292 v8292fff. V8293 v8293fff. V8294 v8294fff.
         V8295 v8295fff. V8296 v8296fff. V8297 v8297fff.
         V8298 v8298fff. V8299 v8299fff. V8300 v8300fff.
         V8301 v8301fff. V8302 v8302fff. V8303 v8303fff.
         V8304 v8304fff. V8305 v8305fff. V8306 v8306fff.
         V8307 v8307fff. V8308 v8308fff. V8309 v8309fff.
         V8310 v8310fff. V8311 v8311fff. V8312 v8312fff.
         V8313 v8313fff. V8314 v8314fff. V8315 v8315fff.
         V8316 v8316fff. V8317 v8317fff. V8318 v8318fff.
         V8319 v8319fff. V8320 v8320fff. V8321 v8321fff.
         V8322 v8322fff. V8323 v8323fff. V8324 v8324fff.
         V8325 v8325fff. V8326 v8326fff. V8327 v8327fff.
         V8328 v8328fff. V8329 v8329fff. V8330 v8330fff.
         V8331 v8331fff. V8332 v8332fff. V8333 v8333fff.
         V8334 v8334fff. V8335 v8335fff. V8336 v8336fff.
         V8337 v8337fff. V8338 v8338fff. V8339 v8339fff.
         V8340 v8340fff. V8341 v8341fff. V8342 v8342fff.
         V8343 v8343fff. V8344 v8344fff. V8345 v8345fff.
         V8346 v8346fff. V8347 v8347fff. V8348 v8348fff.
         V8349 v8349fff. V8350 v8350fff. V8351 v8351fff.
         V8352 v8352fff. V8353 v8353fff. V8354 v8354fff.
         V8355 v8355fff. V8356 v8356fff. V8357 v8357fff.
         V8358 v8358fff. V8359 v8359fff. V8360 v8360fff.
         V8361 v8361fff. V8362 v8362fff. V8363 v8363fff.
         V8364 v8364fff. V8365 v8365fff. V8366 v8366fff.
         V8367 v8367fff. V8368 v8368fff. V8369 v8369fff.
         V8370 v8370fff. V8371 v8371fff. V8372 v8372fff.
         V8373 v8373fff. V8374 v8374fff. V8375 v8375fff.
         V8376 v8376fff. V8377 v8377fff. V8378 v8378fff.
         V8379 v8379fff. V8380 v8380fff. V8381 v8381fff.
         V8382 v8382fff. V8383 v8383fff. V8384 v8384fff.
         V8385 v8385fff. V8386 v8386fff. V8387 v8387fff.
         V8388 v8388fff. V8389 v8389fff. V8390 v8390fff.
         V8391 v8391fff. V8392 v8392fff. V8393 v8393fff.
         V8394 v8394fff. V8395 v8395fff. V8396 v8396fff.
         V8397 v8397fff. V8398 v8398fff. V8399 v8399fff.
         V8400 v8400fff. V8401 v8401fff. V8402 v8402fff.
         V8403 v8403fff. V8404 v8404fff. V8405 v8405fff.
         V8406 v8406fff. V8407 v8407fff. V8408 v8408fff.
         V8409 v8409fff. V8410 v8410fff. V8411 v8411fff.
         V8412 v8412fff. V8413 v8413fff. V8414 v8414fff.
         V8415 v8415fff. V8416 v8416fff. V8417 v8417fff.
         V8418 v8418fff. V8419 v8419fff. V8420 v8420fff.
         V8421 v8421fff. V8422 v8422fff. V8423 v8423fff.
         V8424 v8424fff. V8425 v8425fff. V8426 v8426fff.
         V8427 v8427fff. V8428 v8428fff. V8429 v8429fff.
         V8430 v8430fff. V8431 v8431fff. V8432 v8432fff.
         V8433 v8433fff. V8434 v8434fff. V8435 v8435fff.
         V8436 v8436fff. V8437 v8437fff. V8438 v8438fff.
         V8439 v8439fff. V8440 v8440fff. V8441 v8441fff.
         V8442 v8442fff. V8443 v8443fff. V8444 v8444fff.
         V8445 v8445fff. V8446 v8446fff. V8447 v8447fff.
         V8448 v8448fff. V8449 v8449fff. V8450 v8450fff.
         V8451 v8451fff. V8452 v8452fff. V8453 v8453fff.
         V8454 v8454fff. V8455 v8455fff. V8456 v8456fff.
         V8457 v8457fff. V8458 v8458fff. V8459 v8459fff.
         V8460 v8460fff. V8461 v8461fff. V8462 v8462fff.
         V8463 v8463fff. V8464 v8464fff. V8465 v8465fff.
         V8466 v8466fff. V8467 v8467fff. V8468 v8468fff.
         V8469 v8469fff. V8470 v8470fff. V8471 v8471fff.
         V8472 v8472fff. V8473 v8473fff. V8474 v8474fff.
         V8475 v8475fff. V8476 v8476fff. V8477 v8477fff.
         V8478 v8478fff. V8479 v8479fff. V8480 v8480fff.
         V8481 v8481fff. V8482 v8482fff. V8483 v8483fff.
         V8484 v8484fff. V8485 v8485fff. V8486 v8486fff.
         V8487 v8487fff. V8488 v8488fff. V8489 v8489fff.
         V8490 v8490fff. V8491 v8491fff. V8492 v8492fff.
         V8493 v8493fff. V8494 v8494fff. V8495 v8495fff.
         V8496 v8496fff. V8497 v8497fff. V8498 v8498fff.
         V8499 v8499fff. V8500 v8500fff. V8501 v8501fff.
         V8502 v8502fff. V8503 v8503fff. V8504 v8504fff.
         V8505 v8505fff. V8506 v8506fff. V8507 v8507fff.
         V8508 v8508fff. V8509 v8509fff. V8510 v8510fff.
         V8511 v8511fff. V8512 v8512fff. V8513 v8513fff.
         V8514 v8514fff. V8515 v8515fff. V8516 v8516fff.
         V8517 v8517fff. V8518 v8518fff. V8519 v8519fff.
         V8520 v8520fff. V8521 v8521fff. V8522 v8522fff.
         V8523 v8523fff. V8524 v8524fff. V8525 v8525fff.
         V8526 v8526fff. V8527 v8527fff. V8528 v8528fff.
         V8529 v8529fff. V8530 v8530fff. V8531 v8531fff.
         V8532 v8532fff. V8533 v8533fff. V8534 v8534fff.
         V8535 v8535fff. V8536 v8536fff. V8537 v8537fff.
         V8538 v8538fff. V8539 v8539fff. V8540 v8540fff.
         V8541 v8541fff. V8542 v8542fff. V8543 v8543fff.
          ;
*/

RUN ;
